# Installation

1) cd to project folder
2) composer install
3) cp .env.example .env
4) php artisan migrate
5) cd to spa folder
6) yarn install
7) cp .env.example .env
8) yarn run dev

В папке spa_full полный шаблон со всеми его возможностями
В папке spa рабочий фронтенд

# Уведомления

## Деплой уведомлений

### Supervisor

1. `sudo apt install -y supervisor`
2. `cd /etc/supervisor/conf.d`
3. `sudo vim crm-queue.conf`
4. записать в файл:
``` ini
[program:crm-queue]
process_name=%(program_name)s_%(process_num)02d
command=php /var/www/crm/artisan queue:work --sleep=3 --tries=3 --max-time=3600
autostart=true
autorestart=true
stopasgroup=true
killasgroup=true
user=root
numprocs=8
redirect_stderr=true
stdout_logfile=/var/www/crm/storage/logs/queue.log
stopwaitsecs=3600
```
5. `sudo vim crm-websockets.conf`
6. записать в файл:
``` ini
[program:crm-websockets]
process_name=%(program_name)s_%(process_num)02d
command=php /var/www/crm/artisan websockets:serve --host=127.0.0.1
numprocs=1
autostart=true
autorestart=true
user=root
```

### Nginx

1. добавить в начало:
``` nginx
map $http_upgrade $type {
    default "web";
    websocket "ws";
}    
```
2. удалить текущее правило для `location / { ... }`
3. добавить:
``` nginx
location / {
    try_files /nonexistent @$type;
}

location @web {
    try_files $uri $uri/ /index.html?$query_string;
}

location @ws {
    proxy_pass http://127.0.0.1:6001;
    proxy_set_header Host $host;
    proxy_read_timeout 60;
    proxy_connect_timeout 60;
    proxy_redirect off;

    proxy_http_version 1.1;
    proxy_set_header Upgrade $http_upgrade;
    proxy_set_header Connection 'upgrade';
    proxy_set_header Host $host;
    proxy_cache_bypass $http_upgrade;
}
```

<details>
<summary>Пример готового конфига</summary>

``` nginx
map $http_upgrade $type {
    default "web";
    websocket "ws";
}

server {
    listen 80;
    server_name crm.dev.hgtp12tests.com;
    return 301 https://$host$request_uri;
}

server {
    listen 443 ssl;
    listen [::]:443 ssl;
    server_name crm.dev.hgtp12tests.com;

    ssl_certificate /etc/ssl/certs/nginx-crm.crt;
    ssl_certificate_key /etc/ssl/private/nginx-crm.key;

    charset utf-8;

    root /var/www/crm/spa/dist/;

    index index.html index.htm index.php;

    location /api {
        alias /var/www/crm/public/;
        index index.php;
        try_files $uri $uri/ /index.php?$query_string;
    }

    location ~ \.php$ {
        alias /var/www/crm/public;
        try_files $uri = 404;
        include fastcgi_params;
        fastcgi_pass unix:/run/php/php8.1-fpm.sock;
        fastcgi_index index.php;
        fastcgi_param SCRIPT_FILENAME $document_root$fastcgi_script_name;
    }

    location / {
        try_files /nonexistent @$type;
    }

    location @web {
        try_files $uri $uri/ /index.html?$query_string;
    }

    location @ws {
        proxy_pass http://127.0.0.1:6001;
        proxy_set_header Host $host;
        proxy_read_timeout 60;
        proxy_connect_timeout 60;
        proxy_redirect off;

        proxy_http_version 1.1;
        proxy_set_header Upgrade $http_upgrade;
        proxy_set_header Connection 'upgrade';
        proxy_set_header Host $host;
        proxy_cache_bypass $http_upgrade;
    }

    error_log  /var/log/nginx/crm-error.log;
    access_log /var/log/nginx/crm-access.log;
}
```
</details>

### Backend

1. `cd /var/www/crm`
2. `sudo git pull`
3. `sudo composer install`
4. `sudo php artisan migrate`
5. добавить значения в `.env`
   * `BROADCAST_DRIVER`=pusher
   * `QUEUE_CONNECTION`=database
   * `PUSHER_APP_ID`=целочисленное значение (например, результат `php -r "echo rand();"`)
   * `PUSHER_APP_KEY`=строковое значение (например, результат `php -r "echo uniqid();"`)
   * `PUSHER_APP_SECRET`=строковое значение (например, результат `php -r "echo uniqid();"`)
   * `PUSHER_HOST`=localhost
   * `PUSHER_PORT`=6001
   * `PUSHER_SCHEME`=http
   * `PUSHER_APP_CLUSTER`=mt1
6. `sudo php artisan optimize:clear`
7. `sudo php artisan queue:restart`

### Frontend

1. `cd /var/www/crm/spa`
2. `sudo yarn install`
3. добавить значения в `.env`
   * `VITE_PUSHER_APP_KEY`=значение `PUSHER_APP_KEY` из `/var/www/crm/.env`
   * `VITE_PUSHER_APP_CLUSTER`=mt1
   * `VITE_PUSHER_WS_HOST`=доменное имя сервера
   * `VITE_PUSHER_WS_PORT`=443
   * `VITE_PUSHER_FORCE_TLS`=1
4. `sudo yarn run build`

### Запуск

1. `sudo crontab -l 2> /dev/null | { cat; echo "* * * * * cd /var/www/crm && php artisan schedule:run >> /dev/null 2>&1"; } | sudo crontab -`
2. `sudo supervisorctl reread`
3. `sudo supervisorctl update`
4. `sudo supervisorctl start crm-queue:*`
5. `sudo supervisorctl start crm-websockets:*`
6. `sudo systemctl reload nginx`
7. `sudo systemctl restart nginx`

## Уведомления в среде разработки

### Запуск

Попытка соединиться с websocket-сервером активируется на фронте проставлением непустого значения параметра 
`VITE_PUSHER_APP_KEY` в `spa/.env`. Если ключ отсутствует или имеет пустое значение, то попытки соединения 
выполняться не будут.

Для корректной работы уведомлений в локальной среде разработки, требуется выполнение каждого из следующих пунктов:

* сконфигурирован `.env` на бэкенде
    * <details>
        <summary>Пример</summary>

        ``` ini
        ...
        BROADCAST_DRIVER=pusher
        ...
        QUEUE_CONNECTION=database
        ...
        PUSHER_APP_ID=CRM
        PUSHER_APP_KEY=CRM
        PUSHER_APP_SECRET=CRM
        PUSHER_HOST=127.0.0.1
        PUSHER_PORT=6001
        PUSHER_SCHEME=http
        PUSHER_APP_CLUSTER=mt1
        ...
        ```
    </details>
* сконфигурирован `spa/.env` для соединения с websocket-сервером по http на localhost
    * <details>
        <summary>Пример</summary>
        
        ``` ini
        VITE_PUSHER_APP_KEY=CRM
        VITE_PUSHER_APP_CLUSTER=mt1
        VITE_PUSHER_WS_HOST=localhost
        VITE_PUSHER_WS_PORT=6001
        VITE_PUSHER_FORCE_TLS=0
        ```
    </details>
* запущен http-сервер (`php artisan serve`)
* запущена обработка очереди (`php artisan queue:listen`)
* запущен websocket-сервер (`php artisan websockets:serve`)
* запущен фронт (`yarn run dev`)

Уведомления о приближающихся взаимодействиях отправляются командой `php artisan schedule:run` .

# Docker

## Команды для первичного запуска

1. `cd to project folder`
2. `./docker/install`

## Повторный запуск

1. `alias sail='[ -f sail ] && sh sail || sh vendor/bin/sail'`
2. `sail up -d`
