import axios from 'axios';
import { useAppStore } from "../stores/app";
import router from '../router';
import { metaEnv } from "@/utils/helper";
import {useUserStore} from "@/stores/user";
import {RouteLocationRaw} from "vue-router";

const baseURL = metaEnv.VITE_APP_API_URL
axios.defaults.baseURL = baseURL
axios.defaults.withCredentials = true
axios.defaults.headers.common['Content-Type'] = 'application/json'
axios.defaults.headers.common['Accept'] = 'application/json'

axios.interceptors.request.use((config) => {
  const app = useAppStore()
  app.setLoading(true)
  return config
}, (error) => {
  return Promise.reject(error)
})

axios.interceptors.response.use((response) => {
  const app = useAppStore()
  app.setLoading(false)
  return response;
}, async (error) => {
  const app = useAppStore()

  app.setLoading(false)

  if (error.response.status === 401 || error.response.status === 419) {
    const pathname = window.location.pathname

    if (pathname === '/reset-password' || pathname === '/login') {
      return Promise.resolve()
    }

    localStorage.setItem('axiosRedirect', window.location.pathname)
    useUserStore().setLoggedIn(false)

    const location: RouteLocationRaw = {
      name: 'login'
    }
    const axiosRedirect = localStorage.getItem('axiosRedirect')

    if (axiosRedirect) {
      location.query = {
        redirect: axiosRedirect,
      }
    }

    router.push(location)

    return Promise.resolve()
  }

  return Promise.reject(error)
});

export default axios
