import tinymce, {Editor, TinyMCE} from "tinymce";
import axios from "@/axios";
import {metaEnv} from "@/utils/helper";

const EDITOR_CONTAINER_CLASS_NAME = 'tag'

export const getTagsFromContent = (content: string) => {
  const tags = [] as { id: number, name: string }[]

  const $html = document.createElement('div')
  $html.innerHTML = content

  $html.querySelectorAll('.' + EDITOR_CONTAINER_CLASS_NAME).forEach($tagDom => tags.push({
    id: Number(($tagDom as HTMLElement).dataset.id),
    name: $tagDom.textContent as string,
  }))

  return tags
}

(function init(tinymce: TinyMCE) {
  if (metaEnv.VITE_TAGS_ENABLED !== '1') {
    return
  }

  const pluginManager = tinymce.util.Tools.resolve('tinymce.PluginManager');

  const data = {
    items: []
  } as {
    items: { value: number, text: string, color: string }[],
  }

  const getContrastYIQ = (hexcolor: string) => {
    const r = parseInt(hexcolor.substring(1,3),16);
    const g = parseInt(hexcolor.substring(3,5),16);
    const b = parseInt(hexcolor.substring(5,7),16);
    const yiq = ((r*299)+(g*587)+(b*114))/1000;

    return (yiq >= 128) ? '#000000' : '#ffffff';
  }

  pluginManager.add('tags', function (editor: Editor) {
    editor.ui.registry.addMenuButton('tags', {
      text: 'Теги',
      tooltip: 'Paragraph Line Height',
      icon: 'Bookmark',
      search: true,
      // @ts-ignore
      onSetup: function () {
        axios.get('api/selectable/all').then(response => data.items = response.data)
      },
      fetch: async function (callback, fetchContext) {
        let menuItems = [...data.items];

        if (fetchContext.pattern.length > 0) {
          menuItems = menuItems.filter(item => (new RegExp(fetchContext.pattern, 'i')).test(item.text))

          if (!menuItems.length) {
            menuItems.push({value: 0, text: 'No results found', color: ''})
          }
        }

        callback(menuItems.map((tag) => ({
          type: 'menuitem',
          text: (tag.value !== 0 ? '#' : '') + tag.text,
          onAction: function () {
            if (tag.value === 0) {
              return;
            }

            const $span = document.createElement('span');

            $span.contentEditable = 'false'
            $span.classList.add(EDITOR_CONTAINER_CLASS_NAME)
            $span.style.backgroundColor = tag.color
            $span.style.color = getContrastYIQ(tag.color)

            $span.dataset.id = tag.value.toString()
            $span.innerHTML = tag.text + "&nbsp;"

            editor?.insertContent($span.outerHTML)
          }
        })))
      }
    });
  });
})(tinymce)
