import tinymce, {Editor, TinyMCE, Ui} from "tinymce";
import {i18n} from "@/utils/i18n";

const {t} = i18n.global;

(function init(tinymce: TinyMCE) {
  const pluginManager = tinymce.util.Tools.resolve('tinymce.PluginManager');

  pluginManager.add('toc', function (editor: Editor) {
    editor.ui.registry.addMenuButton('toc', {
      icon: 'toc',
      tooltip: t('Table of contents'),
      fetch: async (callback) => {
        const $html = document.createElement('div')
        $html.innerHTML = editor.getContent()

        const items = [
          {
            type: 'menuitem',
            text: t('Create / Update'),
            onAction: () => {
              const $headers = Array.from($html.querySelectorAll('h1,h2,h3,h4,h5,h6'))
              let toc = '<div class="mce-toc"><h2 contenteditable="true">' + t('Table of contents') + '</h2>'
              let level = 0;

              for (const $header of $headers) {
                if ($header.parentElement?.classList?.contains('mce-toc')) continue

                const anchor = $header.textContent?.replace(/[\s\.]/g, "_")?.replace(/&nbsp;/g, "_");

                if (anchor) {
                  $header.setAttribute('id', anchor)
                }
              }

              $html.innerHTML.replace(
                /<h([\d])[^<]*>(.*)<\/h([\d])>/gi,
                function (str, openLevel, titleText, closeLevel) {
                  titleText = titleText.replace(/<[^<]+>/g, '')

                  if (!titleText || titleText == t('Table of contents')) return ''

                  if (openLevel != closeLevel) {
                    return str + ' - ' + openLevel
                  }

                  if (openLevel > level) {
                    toc += (new Array(openLevel - level + 1)).join('<ul>')
                  } else if (openLevel < level) {
                    toc += (new Array(level - openLevel + 1)).join("</ul>")
                  }

                  level = parseInt(openLevel);
                  const anchor = titleText.replace(/[\s\.]/g, "_")?.replace(/&nbsp;/g, "_");

                  toc += "<li><a href=\"#" + anchor + "\">" + titleText
                    + "</a></li>"

                  return "<h" + openLevel + "><a name=\"" + anchor + "\">"
                    + titleText + "</a></h" + closeLevel + ">"
                }
              )

              if (level) {
                toc += (new Array(level + 1)).join("</ul>");
              }

              toc += '</div>'

              $html.querySelector(".mce-toc")?.remove()

              editor.setContent(toc + $html.innerHTML)
            }
          },
          {
            type: 'menuitem',
            text: t('Remove'),
            onAction: () => {
              $html.querySelector(".mce-toc")?.remove()
              editor.setContent($html.innerHTML)
            }
          },
        ] as Ui.Menu.NestedMenuItemContents[]

        callback(items)
      },
    });
  });
})(tinymce)
