import { Router, RouteLocationNormalizedLoaded } from "vue-router";
import { Icon } from "@/base-components/Lucide";
import { slideUp, slideDown } from "@/utils/helper";
import { useUserStore } from "@/stores/user";

interface Route extends RouteLocationNormalizedLoaded {
  forceActiveMenu?: string;
}

interface Menu {
  icon?: Icon;
  title: string;
  pageName?: string;
  subMenu?: Menu[];
  ignore?: boolean;
  table?: string;
  action?: string;
}

interface FormattedMenu extends Menu {
  active?: boolean;
  activeDropdown?: boolean;
  subMenu?: FormattedMenu[];
}

type RawMenuList = Array<Menu | "devider">;
type FormattedMenuList = Array<FormattedMenu | "devider">;

const findActiveMenu = (subMenu: Menu[], route: Route): boolean => {
  let match = false;
  subMenu.forEach((item) => {
    if (match) return;

    if (
      ((route.forceActiveMenu !== undefined &&
        item.pageName === route.forceActiveMenu) ||
        (route.forceActiveMenu === undefined &&
          item.pageName === route.name)) &&
      !item.ignore
    ) {
      match = true;
    } else if (!match && item.subMenu) {
      match = findActiveMenu(item.subMenu, route);
    }
  });
  return match;
};

const nestedMenu = (menu: RawMenuList, route: Route) => {
  const user = useUserStore();
  const formattedMenu: Array<FormattedMenu | "devider"> = [];
  menu.forEach((item) => {
    if (typeof item !== "string") {
      const menuItem: FormattedMenu = {
        ...item,
      };
      menuItem.active =
        ((route.forceActiveMenu !== undefined &&
          menuItem.pageName === route.forceActiveMenu) ||
          (route.forceActiveMenu === undefined &&
            menuItem.pageName === route.name) ||
          (menuItem.subMenu && findActiveMenu(menuItem.subMenu, route))) &&
        !menuItem.ignore;

      if (menuItem.subMenu) {
        menuItem.activeDropdown = (menuItem.active && !!menuItem.subMenu) || findActiveMenu(menuItem.subMenu, route);

        // Nested menu
        const subMenu: Array<FormattedMenu> = [];
        nestedMenu(menuItem.subMenu, route).map(
          (menu) => typeof menu !== "string" && subMenu.push(menu)
        );
        menuItem.subMenu = subMenu;
      }
      if(menuItem.table === undefined || menuItem.action === undefined || user.isUserHasPermission(menuItem.table, menuItem.action)) {
        formattedMenu.push(menuItem)
      }
    } else {
      formattedMenu.push(item);
    }
  });

  return formattedMenu;
};

const linkTo = (menu: FormattedMenu, router: Router) => {
  if (menu.subMenu) {
    menu.activeDropdown = !menu.activeDropdown;
  } else {
    if (menu.pageName !== undefined) {
      router.push({
        name: menu.pageName,
      });
    }
  }
};

const enter = (el: Element) => {
  const htmlEl = el as HTMLElement;
  slideDown(htmlEl, 300);
};

const leave = (el: Element) => {
  const htmlEl = el as HTMLElement;
  slideUp(htmlEl, 300);
};

export { nestedMenu, linkTo, enter, leave };
export type { Menu, RawMenuList, FormattedMenuList, FormattedMenu };
