import {usePassThrough} from "primevue/passthrough";
import Tailwind from "primevue/passthrough/tailwind";
import {TreeSelectProps} from "primevue/treeselect";
import {TreeContext} from "primevue/tree";
import {
  TriStateCheckboxContext,
  TriStateCheckboxProps
} from "primevue/tristatecheckbox";
import {RadioButtonProps} from "primevue/radiobutton";

const TRANSITIONS = {
  overlay: {
    enterFromClass: 'opacity-0 scale-75',
    enterActiveClass: 'transition-transform transition-opacity duration-150 ease-in',
    leaveActiveClass: 'transition-opacity duration-150 ease-linear',
    leaveToClass: 'opacity-0'
  },
  toggleable: {
    enterFromClass: 'max-h-0',
    enterActiveClass: 'overflow-hidden transition-all duration-500 ease-in-out',
    enterToClass: 'max-h-40	',
    leaveFromClass: 'max-h-40',
    leaveActiveClass: 'overflow-hidden transition-all duration-500 ease-in',
    leaveToClass: 'max-h-0'
  }
};

/**
 * Configs for styling the Prime components for Tailwind.css
 *
 * Steps:
 * 1. Select a component (ex. https://primevue.org/calendar/)
 * 2. Go to theming tab
 * 3. Copy tailwind section to pt2 param
 * 4. Correct styles for the current theme
 *
 * @see https://primevue.org
 * @see https://primevue.org/tailwind/
 *
 */
const CRMPrimeConfig = usePassThrough(Tailwind, {
  treeselect: {
    root: ({props}: { props: TreeSelectProps }) => ({
      class: [
        'inline-flex cursor-pointer select-none relative',
        'bg-white dark:bg-darkmode-800 border-[1px] border-solid border-slate-200 border border-slate-200 shadow-sm transition-colors duration-200 ease-in-out rounded',
        'w-full min-h-[36px] box-shadow-sm',
        {'select-none pointer-events-none cursor-default bg-slate-50': props?.disabled}
      ]
    }),
    labelContainer: {
      class: ['overflow-hidden flex flex-auto cursor-pointer pr-7']
    },
    label: {
      class: ['overflow-hidden whitespace-nowrap cursor-pointer overflow-ellipsis', 'text-slate-400 dark:text-white/80', 'p-2 pl-3 transition duration-200']
    },
    trigger: {
      class: ['flex items-center justify-center shrink-0', 'bg-transparent text-gray-600 dark:text-white/70 w-9 rounded-tr-lg rounded-br-lg']
    },
    panel: {
      class: ['bg-white dark:bg-darkmode-700 text-gray-700 dark:text-white/80 border-0 rounded-md shadow-lg']
    },
    wrapper: {
      class: ['bg-white dark:bg-darkmode-600 text-gray-700 dark:text-white/80 border-0 rounded-md shadow-lg']
    },
    emptymessage: {
      class: ['p-3']
    },
    transition: TRANSITIONS.overlay,
    token: {
      class: ['bg-slate-200 dark:bg-darkmode-600 p-1 px-1.5 m-0.5 rounded'],
    },
    tokenLabel: {
      class: ['whitespace-normal break-all'],
    },
  },
  tree: {
    root: {
      class: [
        'rounded',
        'bg-white dark:bg-darkmode-700 text-gray-700 dark:text-white/80 pb-1',
      ]
    },
    container: 'pt-1 list-none max-h-[450px] overflow-y-auto',
    node: 'outline-none relative treeitem',
    content: ({context, props}: { context: TreeContext, props: TreeSelectProps }) => ({
      class: [
        'flex items-center',
        'transition-shadow duration-200 p-2',
        'hover:bg-slate-100 dark:hover:bg-darkmode-600 dark:hover:text-white hover:cursor-pointer hover:text-gray-800',
        'focus:outline-none focus:outline-offset-0 focus:shadow-[0_0_0_0.2rem_rgba(191,219,254,1)] dark:focus:shadow-[0_0_0_0.2rem_rgba(147,197,253,0.5)]',
        {'!bg-primary !text-white text-slate-50': context.selected},
        {'cursor-pointer select-none': props.selectionMode == 'single' || props.selectionMode == 'multiple'}
      ]
    }),
    toggler: ({context}: { context: TreeContext }) => ({
      class: [
        'cursor-pointer select-none inline-flex items-center justify-center overflow-hidden relative shrink-0 mr-1',
        '-ml-2 w-8 h-8 border-0 bg-transparent rounded-full transition duration-200',
        'hover:border-transparent focus:outline-none focus:outline-offset-0',
        '!absolute right-0',
        {
          'text-gray-500 dark:text-white/80 hover:bg-gray-200 dark:hover:bg-gray-800/80  hover:text-gray-800 dark:hover:text-white/80': !context.selected,
          'hover:bg-white/30 hover:text-gray-800': context.selected
        },
        {
          'hidden': context.leaf,
        }
      ]
    }),
    checkboxcontainer: 'mr-2',
    checkbox: ({context, props}: { context: TreeContext, props: TreeSelectProps }) => ({
      class: [
        'cursor-pointer inline-flex relative select-none align-bottom',
        'w-4 h-4',
        'flex items-center justify-center',
        'border-[1px] rounded w-4 h-4 transition-colors cursor-pointer duration-200 text-white text-base dark:text-gray-900',
        {
          'border-gray-300 bg-white dark:border-primary dark:bg-gray-900': !context.checked,
          'border-primary text-white bg-primary dark:border-primary dark:bg-primary': context.checked,
        },
        {
          'hover:border-primary dark:hover:border-primary focus:outline-none focus:outline-offset-0 focus:shadow-[0_0_0_0.2rem_rgba(191,219,254,1)] dark:focus:shadow-[inset_0_0_0_0.2rem_rgba(147,197,253,0.5)]': !props.disabled,
          'cursor-default opacity-60': props.disabled
        }
      ]
    }),
    nodeicon: 'mr-2 text-gray-600 dark:text-white/70',
    subgroup: {
      class: ['m-0 list-none', 'p-0 pl-4']
    },
    filtercontainer: {
      class: ['mb-2', 'block relative m-2 margin-auto']
    },
    filterinput: {
      class: ['w-full rounded border-[1px] border-solid dark:bg-darkmode-800 border-slate-200 p-1.5 pr-[35px] text-sm focus:border-[1px] focus:border-slate-200 focus:ring-transparent focus:outline-transparent focus:shadow-none ring-offset-0 ring-0']
    },
    input: {
      class: [
        'text-base w-full pr-7',
        'font-sans text-gray-600 dark:text-white/70 bg-white dark:bg-gray-900 border border-gray-300 dark:border-blue-900/40 transition-colors duration-200 appearance-none rounded-lg',
        'hover:border-blue-500 focus:outline-none focus:outline-offset-0 focus:shadow-[0_0_0_0.2rem_rgba(191,219,254,1)] dark:focus:shadow-[0_0_0_0.2rem_rgba(147,197,253,0.5)]'
      ]
    },
    searchicon: 'absolute top-1/2 -mt-2 right-3 text-gray-600 dark:hover:text-white/70',
  },
  image: {
    root: 'relative inline-block',
    button: {
      class: [
        'absolute inset-0 flex items-center justify-center opacity-0 transition-opacity duration-300',
        'bg-transparent text-gray-100',
        'hover:opacity-100 hover:cursor-pointer hover:bg-black hover:bg-opacity-50' //Hover
      ]
    },
    mask: {
      class: ['fixed top-0 left-0 w-full h-full', 'flex items-center justify-center', 'bg-black bg-opacity-90']
    },
    toolbar: {
      class: ['absolute top-0 right-0 z-10 flex', 'p-4']
    },
    rotaterightbutton: {
      class: [
        'flex justify-center items-center',
        'text-white bg-transparent w-12 h-12 rounded-full transition duration-200 ease-in-out mr-2',
        'hover:text-white hover:bg-white/10',
        'focus:outline-none focus:outline-offset-0 focus:shadow-[0_0_0_0.2rem_rgba(191,219,254,1)]'
      ]
    },
    rotaterighticon: 'w-6 h-6',
    rotateleftbutton: {
      class: [
        'flex justify-center items-center',
        'text-white bg-transparent w-12 h-12 rounded-full transition duration-200 ease-in-out mr-2',
        'hover:text-white hover:bg-white/10',
        'focus:outline-none focus:outline-offset-0 focus:shadow-[0_0_0_0.2rem_rgba(191,219,254,1)]'
      ]
    },
    rotatelefticon: 'w-6 h-6',
    zoomoutbutton: {
      class: [
        'flex justify-center items-center',
        'text-white bg-transparent w-12 h-12 rounded-full transition duration-200 ease-in-out mr-2',
        'hover:text-white hover:bg-white/10',
        'focus:outline-none focus:outline-offset-0 focus:shadow-[0_0_0_0.2rem_rgba(191,219,254,1)]'
      ]
    },
    zoomouticon: 'w-6 h-6',
    zoominbutton: {
      class: [
        'flex justify-center items-center',
        'text-white bg-transparent w-12 h-12 rounded-full transition duration-200 ease-in-out mr-2',
        'hover:text-white hover:bg-white/10',
        'focus:outline-none focus:outline-offset-0 focus:shadow-[0_0_0_0.2rem_rgba(191,219,254,1)]'
      ]
    },
    zoominicon: 'w-6 h-6',
    closebutton: {
      class: [
        'flex justify-center items-center',
        'text-white bg-transparent w-12 h-12 rounded-full transition duration-200 ease-in-out mr-2',
        'hover:text-white hover:bg-white/10',
        'focus:outline-none focus:outline-offset-0 focus:shadow-[0_0_0_0.2rem_rgba(191,219,254,1)]'
      ]
    },
    closeicon: 'w-6 h-6',
    transition: {
      enterFromClass: 'opacity-0 scale-75',
      enterActiveClass: 'transition-all duration-150 ease-in-out',
      leaveActiveClass: 'transition-all duration-150 ease-in',
      leaveToClass: 'opacity-0 scale-75'
    }
  },
  card: {
    root: {
      class: [
        'rounded-md',
        'shadow-md',
        'text-surface-700 dark:text-surface-0 bg-white dark:bg-darkmode-600'
      ]
    },
    body: {
      class: 'p-5'
    },
    title: {
      class: 'text-2xl font-bold mb-2'
    },
    subtitle: {
      class: [
        'font-normal',
        'mb-2',
        'text-surface-600 dark:text-surface-0/60'
      ]
    },
    content: {
      class: 'py-5'
    },
    footer: {
      class: 'pt-5'
    }
  },
  tristatecheckbox: {
    root: {
      class: ['cursor-pointer inline-flex relative select-none align-bottom', 'w-4 h-4']
    },
    input: {
      class: ['peer', 'w-full ', 'h-full', 'absolute', 'top-0 left-0', 'z-10', 'p-0', 'm-0', 'opacity-0', 'rounded-md', 'outline-none', 'border-2 border-surface-200 dark:border-surface-700', 'appearance-none', 'cursor-pointer']
    },
    box: ({props, context}: {
      props: TriStateCheckboxProps & { invalid: boolean },
      context: TriStateCheckboxContext
    }) => ({
      class: [
        // Alignment
        'flex',
        'items-center',
        'justify-center',
        // Size
        'w-4',
        'h-4',
        // Shape
        'rounded-md',
        'border-2',
        // Colors
        {
          'border-surface-200 bg-surface-0 dark:border-surface-700 dark:bg-surface-900': !context.active && !props.invalid,
          'border-primary-500 bg-primary-500 dark:border-primary-400 dark:bg-primary-400': context.active
        },
        // Invalid State
        {'border-red-500 dark:border-red-400': props.invalid},
        // States
        {
          'peer-hover:border-primary-500 dark:peer-hover:border-primary-400': !props.disabled && !context.active && !props.invalid,
          'peer-hover:bg-primary-600 dark:peer-hover:bg-primary-300 peer-hover:border-primary-700 dark:peer-hover:border-primary-300': !props.disabled && context.active,
          'peer-focus-visible:border-primary-500 dark:peer-focus-visible:border-primary-400 peer-focus-visible:ring-2 peer-focus-visible:ring-primary-400/20 dark:peer-focus-visible:ring-primary-300/20': !props.disabled,
          'cursor-default opacity-60': props.disabled
        },
        // Transitions
        'transition-colors',
        'duration-200'
      ]
    }),
    checkbox: ({context, props}: { context: TreeContext, props: TreeSelectProps }) => ({
      class: [
        'cursor-pointer inline-flex relative select-none align-bottom',
        'w-4 h-4',
        'flex items-center justify-center',
        'border-[1px] rounded transition-colors cursor-pointer duration-200 text-white text-base dark:text-gray-900',
        {
          'border-gray-300 bg-white dark:border-primary dark:bg-gray-900': !context.checked,
          'border-primary text-white bg-primary dark:border-primary dark:bg-primary': context.checked,
        },
        {
          'hover:border-primary dark:hover:border-primary focus:outline-none focus:outline-offset-0 focus:shadow-[0_0_0_0.2rem_rgba(191,219,254,1)] dark:focus:shadow-[inset_0_0_0_0.2rem_rgba(147,197,253,0.5)]': !props.disabled,
          'cursor-default opacity-60 bg-red-200': props.disabled
        }
      ]
    }),
    checkicon: {
      class: ['text-base leading-none', 'w-4', 'h-4', 'text-primary dark:text-surface-900', 'transition-all', 'duration-200']
    },
    uncheckicon: {
      class: ['text-base leading-none', 'w-4', 'h-4', 'text-primary dark:text-surface-900', 'transition-all', 'duration-200']
    }
  },
  radiobutton: {
    root: {
      class: ['relative', 'inline-flex', 'align-bottom', 'w-4 h-4', 'cursor-pointer', 'select-none']
    },
    box: ({ props }: { props: RadioButtonProps }) => ({
      class: [
        // Flexbox
        'flex justify-center items-center',
        // Size
        'w-4 h-4',
        'text-sm',
        'font-medium',
        // Shape
        'border-2',
        'rounded-full',
        // Transition
        'transition duration-200 ease-in-out',
        // Colors
        {
          'text-surface-700 dark:text-white/80': props.value !== props.modelValue && props.value !== void 0,
          'bg-surface-0 dark:bg-surface-900': props.value !== props.modelValue && props.value !== void 0,
          /// @ts-ignore
          'border-surface-300 dark:border-surface-700': props.value !== props.modelValue && props.value !== void 0 && !props.invalid,
          'border-primary-500 dark:border-primary-400': props.value == props.modelValue && props.value !== void 0
        },
        // Invalid State
        /// @ts-ignore
        { 'border-red-500 dark:border-red-400': props.invalid },
        // States
        {
          'outline-none outline-offset-0': !props.disabled,
          'peer-focus-visible:ring-2 peer-focus-visible:ring-offset-2 peer-focus-visible:ring-offset-surface-0 dark:focus-visible:ring-offset-surface-800 peer-focus-visible:ring-primary-500 dark:peer-focus-visible:ring-primary-400': !props.disabled,
          'opacity-60 cursor-default': props.disabled
        }
      ]
    }),
    input: ({props}: { props: RadioButtonProps }) => ({
      class: [
        'peer', 'w-full ', 'h-full', 'absolute', 'top-0 left-0',
        'z-10', 'p-0', 'm-0', 'rounded-xl', 'outline-none',
        'border-[1px] border-slate-300 dark:border-surface-700',
        'appearance-none',
        'flex justify-center items-center',
        {
          'bg-red-200': props.disabled
        }
      ]
    }),
    icon: ({ props }: { props: RadioButtonProps }) => ({
      class: [
        'block',
        // Shape
        'rounded-full',
        // Size
        'w-2 h-2',
        // Colors
        'bg-surface-0 dark:bg-surface-900',
        // Conditions
        {
          'backface-hidden scale-10 invisible': props.value !== props.modelValue,
          'transform visible scale-1 bg-primary': props.value == props.modelValue
        },
        // Transition
        'transition duration-400'
      ]
    })
  }
})


export default CRMPrimeConfig