import { createApp } from 'vue';
import { createPinia } from "pinia";
import App from "./App.vue";
import router from "./router";
import { Router } from "vue-router";
import "./assets/css/app.css";
import VueAxios from 'vue-axios';
import axios from './axios';
import { i18n } from './utils/i18n';
import { useUserStore } from "@/stores/user";
import Pusher from "./pusher";
import { markRaw } from 'vue';
import VueDatePicker from '@vuepic/vue-datepicker';
import PrimeVueConfig from "primevue/config";
import CrmPrimeVueConfig from "./config/prime.config"
import CrmPrimeVueLocaleRU from "./config/locale/ru.json"
import * as Sentry from "@sentry/vue";
import { metaEnv } from "@/utils/helper";
import VueGridLayout from "vue-grid-layout"

const app = createApp(App);
const pinia = createPinia();

Sentry.init({
  app,
  dsn: metaEnv.VITE_SENTRY_DSN ?? '',
  integrations: [
    new Sentry.BrowserTracing({
      routingInstrumentation: Sentry.vueRouterInstrumentation(router),
    }),
    new Sentry.Replay(),
  ],

  // Set tracesSampleRate to 1.0 to capture 100%
  // of transactions for performance monitoring.
  // We recommend adjusting this value in production
  tracesSampleRate: 1.0,

  // Set `tracePropagationTargets` to control for which URLs distributed tracing should be enabled
  tracePropagationTargets: ["localhost", /^https:\/\/crm\.dev\.hgtp12tests\.com\/api/],

  // Capture Replay for 10% of all sessions,
  // plus for 100% of sessions with an error
  replaysSessionSampleRate: 0.1,
  replaysOnErrorSampleRate: 1.0,
});

pinia.use(({ store }) => {
  store.$router = markRaw(router)
});

app
  .component('DateTimePicker', VueDatePicker);

app.use(router)
  .use(pinia)
  .use(VueAxios, axios)
  .use(PrimeVueConfig, {
    unstyled: true,
    pt: CrmPrimeVueConfig,
    locale: {
      ...CrmPrimeVueLocaleRU
    }
  })
  .use(i18n)
  .use(Pusher)
  .use(VueGridLayout)
  .mount('#app');

app.config.globalProperties.can = function(table: string, action: string, id?: string | number) {
  const user = useUserStore();
  return user.isUserHasPermission(table, action, id)
}

declare module 'vue' {
    interface ComponentCustomProperties {
        can: (table: string, action: string, id?: string | number) => boolean|Array<number>|unknown
    }
}

declare module '@vue/runtime-core' {
  interface ComponentCustomProperties {
    can: (table: string, action: string, id?: string | number) => boolean|Array<number>|unknown
  }
}

declare module 'pinia' {
  export interface PiniaCustomProperties {
    $router: Router
  }
}
