import { Ref, onMounted, onBeforeUnmount } from "vue";

export default function onClickOutside(el: Ref<HTMLElement>, callback: () => void) {  
  const clickHandler = (evt: Event) => {
    if (evt.target !== el.value && !evt.composedPath().includes(el.value)) {      
      callback();
    }
  };

  onMounted(() => {
    document.addEventListener("mousedown", clickHandler);
  });

  onBeforeUnmount(() => {
    document.removeEventListener("mousedown", clickHandler);
  });
}
