import Toastify from "toastify-js";
import { useNotificationStore } from "@/stores/notification/notification";

import { FrontNotificationType } from "@/stores/notification/enums";
import { Icon } from "@/base-components/Lucide/Lucide.vue";
import { h, createApp } from "vue";
import { CustomNotification } from "@/components/Notification";

interface INotificationParams {
  type: FrontNotificationType,
  icon?: Icon,
  color?: string,
  title?: string,
  content?: string,
  persist?: boolean,
  withSound?: boolean,
}

const audioUrl = new URL("@/assets/audio/NotificationSound.mp3", import.meta.url).href;
const audio = new Audio(audioUrl);

export const showNotification = async (params: INotificationParams) => {
  /* eslint-disable @typescript-eslint/no-explicit-any */
  const notificationStore = useNotificationStore();

  let element = {} as Element;
  if (params.type == FrontNotificationType.CUSTOM) {
    element = document.createElement("div");
    createApp(h(CustomNotification as any, params)).mount(element);
    element = element.children[0];
  } else {
    const blueprintElementId = `#v2-${params.type}-notification-content`;

    element = document
      .querySelectorAll(blueprintElementId)[0]
      .cloneNode(true) as HTMLElement;

    const title = element.querySelector(`${blueprintElementId}-title`);
    const content = element.querySelector(`${blueprintElementId}-content`);
  
    (title as HTMLElement).innerHTML = params.title ?? "";
    (content as HTMLElement).innerHTML = params.content ?? "";
  }

  element.classList.remove("hidden");

  const options: Toastify.Options = {
    node: element,
    duration: 3000,
    newWindow: true,
    close: true,
    gravity: "top",
    position: "right",
    stopOnFocus: true,
  };

  if (params.persist) {
    options.duration = -1;
  }

  Toastify(options).showToast();

  if (params.withSound && notificationStore.soundOn) {
    audio.play();
  }
  
};
