import { onMounted, ref, Ref, watch } from "vue";
import { useI18n } from "vue-i18n";

export default () => {
  const { t } = useI18n();

  interface IFilter {
    filter_field: string,
    filter_value: string,
    communication_type: string,
    "status[]": Array<string>,
    "responsible_user[]": Array<string>,
    date_begin: string,
    date_end: string,
  }

  const filter: Ref<IFilter> = ref({
    filter_field: "",
    filter_value: "",
    communication_type: "",
    "status[]": [],
    "responsible_user[]": [],
    date_begin: "",
    date_end: "",
  } as IFilter);

  const filterDate: Ref<string> = ref("");

  const fillFilterDates = () => {
    const inputDates: Array<string> = filterDate.value.split(" - ");
    if (inputDates.length > 1) {
      filter.value.date_begin = inputDates[0];
      filter.value.date_end = inputDates[1];
    } else {
      filter.value.date_begin = "";
      filter.value.date_end = "";
    }
  };

  watch(filterDate, () => {
    fillFilterDates();
  });

  const initFilterDate = () => {
    const currentDate = new Date();
    const currentDateString = ("0" + currentDate.getDate()).slice(-2)
      + "."
      + ("0"+(currentDate.getMonth() + 1)).slice(-2)
      + "."
      + currentDate.getFullYear();
    filterDate.value = `${currentDateString} - ${currentDateString}`;
    fillFilterDates();
  };


  const searchFields = [
    {
      text: t("ServiceProvider"),
      value: "ServiceProvider",
    },
    {
      text: t("Lead"),
      value: "Lead",
    },
    {
      text: t("Client"),
      value: "Client",
    },
    {
      text: t("Trader"),
      value: "Trader",
    },
  ];

  onMounted(() => {
    initFilterDate();
  });

  return {
    filter,
    filterDate,
    searchFields,
    initFilterDate,
  };
}
