import { IClient, IClientType } from "./interfaces";
import { IComment, ICommentable, IPage } from "@/utils/interfaces";
import { ICountry } from "../countries/interfaces";
import { ISalesChannel } from "../sales_channels/interfaces";
import { IUserShort } from "../users/interfaces";
import { ContactPerson as IContact } from "@/stores/contact_person/interfaces";
import { IGnuVpnClient, IPayportAgent, IPayportMerchant, IProduct} from "@/pages/products/interfaces";
import { useCommentStore } from "@/stores/comment";
import {
  IAssociationType,
  IHolding,
} from "@/stores/association/interfaces";
import {IAdditionalProductInfo, ILeadShortWithStatus} from "../leads/interfaces";
import {ICoefficientClient} from "@/pages/coefficients/interfaces";
import {IProductAutomationAssignment} from "@/pages/product_assignments/interfaces";

class Client implements IClient, ICommentable {
  id: number
  name: string
  email: string
  phone: string
  telegram: string
  client_type: IClientType
  creator_user_id: number
  responsible_user_ids: Array<number>
  status: number
  sales_channel_id: number | null
  creator_user: IUserShort
  created_at: string
  responsible_users: Array<IUserShort>
  countries: Array<ICountry>
  sales_channel: ISalesChannel | null
  contacts: Array<IContact>
  product?: Array<IProduct<IPayportMerchant|IPayportAgent|IGnuVpnClient>>
  product_types?: Array<{ id: number, name: string }>
  has_aggregator_participants: boolean
  has_holding_participants: boolean
  holding: IHolding
  association_type_id: number | null
  association_type: IAssociationType | null
  status_name: string
  switch_types: Array<IAssociationType>
  lead: ILeadShortWithStatus | null;
  is_in_blacklist: boolean;
  updated_blocks: Array<string>;
  user_favorite_id: number | null;
  coefficient: ICoefficientClient | null;
  additional_product_information: IAdditionalProductInfo
  product_assignment?: IProductAutomationAssignment;

  static commentStore = useCommentStore();

  constructor(attrs: IClient) {
    this.id = attrs.id;
    this.name = attrs.name;
    this.email = attrs.email;
    this.phone = attrs.phone;
    this.telegram = attrs.telegram;
    this.client_type = attrs.client_type;
    this.creator_user_id = attrs.creator_user_id;
    this.responsible_user_ids = attrs.responsible_user_ids;
    this.status = attrs.status;
    this.sales_channel_id = attrs.sales_channel_id;
    this.creator_user = attrs.creator_user;
    this.created_at = attrs.created_at;
    this.responsible_users = attrs.responsible_users;
    this.countries = attrs.countries;
    this.sales_channel = attrs.sales_channel;
    this.contacts = attrs.contacts;
    this.product = attrs.product;
    this.has_aggregator_participants = attrs.has_aggregator_participants;
    this.has_holding_participants = attrs.has_holding_participants;
    this.holding = attrs.holding;
    this.association_type_id = attrs.association_type_id;
    this.association_type = attrs.association_type;
    this.status_name = attrs.status_name;
    this.switch_types = attrs.switch_types;
    this.lead = attrs.lead;
    this.is_in_blacklist = attrs.is_in_blacklist;
    this.updated_blocks = attrs.updated_blocks;
    this.user_favorite_id = attrs.user_favorite_id;
    this.coefficient = attrs.coefficient;
    this.product_types = attrs.product_types
    this.additional_product_information = attrs.additional_product_information
  }
  // Method to update a property dynamically
  updateField<K extends keyof Client>(field: K, value: Client[K]): void {
    this[field] = value as this[K]; // Type assertion to resolve the error
  }
  async getComments(params?: { page?: string | number | undefined; perPage?: string | number | undefined; }): Promise<IPage<IComment>> {
    return await Client.commentStore.getComments(
      {
        ...params,
        commentable_type: "Client",
        commentable_id: this.id
      }
    );
  }

  async addNewComment(comment: string | null): Promise<IComment> {
    return await Client.commentStore.createComment({
      commentable_type: "Client",
      commentable_id: this.id,
      comment
    });
  }
}

export { Client };
