import { ICountry } from "../countries/interfaces";
import { ISalesChannel } from "../sales_channels/interfaces";
import { IUserShort } from "../users/interfaces";
import { IContactable } from "@/utils/interfaces";
import { ContactPerson as IContact } from "@/stores/contact_person/interfaces";
import { IProduct, IPayportMerchant, IPayportAgent, IGnuVpnClient } from "@/pages/products/interfaces";
import {
  IAssociationType,
  IHolding,
} from "@/stores/association/interfaces";
import {IAdditionalProductInfo, ILeadShortWithStatus} from "../leads/interfaces";
import {ICoefficientClient} from "@/pages/coefficients/interfaces";

interface IClientType {
  id: number,
  name: string
}

interface IClientBase {
  id: number,
  name: string,
  status: number,
  creator_user_id: number,
  responsible_user_ids: Array<number>,
  sales_channel_id: number | null,
  association_type_id: number | null,
  email: string,
  telegram: string,
  creator_user: IUserShort,
  responsible_users: Array<IUserShort>,
  countries: Array<ICountry>,
  sales_channel: ISalesChannel | null,
  association_type: IAssociationType | null,
  created_at: string,
  is_in_blacklist: boolean,
  user_favorite_id: number | null
  coefficient: ICoefficientClient | null,
}

interface IClientForList extends IClientBase {
  product_types: Array<string>,
  is_association: boolean,
  status_name: string,
  telegram_chat: Array<ITelegramChats> | null
}

interface IClient extends IContactable, IClientBase {
  additional_product_information: IAdditionalProductInfo;
  client_type: IClientType,
  has_aggregator_participants: boolean,
  has_holding_participants: boolean,
  holding: IHolding,
  contacts: Array<IContact>,
  product?: Array<IProduct<IPayportMerchant|IPayportAgent|IGnuVpnClient>>,
  status_name: string,
  switch_types: Array<IAssociationType>,
  lead: ILeadShortWithStatus | null,
  updated_blocks: Array<string>,
  product_types?: Array<{ id: number, name: string }>
  phone: string
  telegram: string
  client_id?: number|string

}

interface IClientShort {
  id: number,
  name: string,
  email: string,
  status_name: string,
  created_at: string,
}

interface IClientUpdateForm {
  phone: string;
  countries: Array<string>,
  responsible_user_ids: Array<number>,
  sales_channel_id: string,
  status: string,
  association_type_id: string,
  is_in_blacklist: 1 | 0,
  email: string,
  telegram: string,
  product_types?: Array<string>,
  additional_product_information?: IAdditionalProductInfo
}

enum IClientStatus {
  Active = 1,
  Not_active = 0
}

interface ITelegramChats {
  client_id: number,
  telegram_chat_id: number,
  chat: {
    id: number,
    name: string
  }
}
export type {
  IClientType,
  IClientForList,
  IClient,
  IClientShort,
  IClientUpdateForm,
  IClientStatus
};
