import {useUserStore} from "@/stores/user";

type ManagerTypes =
  'client'
  | 'lead'
  | 'trader'
  | 'service-provider'
  | 'ticket'

export const useComponentManager = (type: ManagerTypes) => {
  const {auth} = useUserStore()

  const toggleHeaderStorage = () => {
    isHeaderStorageEmpty() ? removeFromHeaderStorage() : saveHeaderStateToStorage()
  }

  const toggleShowAllStorage = (): void => {
    isShowAllStorageEmpty() ? removeFromShowAllStorage() : saveShowAllStateToStorage()
  }

  const isShowAllStorageEmpty = (): boolean => {
    return !!localStorage.getItem(getShowAllStorageKey())
  }

  const isHeaderStorageEmpty = (): boolean => {
    return !!localStorage.getItem(getHeaderStorageKey())
  }

  const saveHeaderStateToStorage = (): void => {
    localStorage.setItem(getHeaderStorageKey(), 'true')
  }

  const saveShowAllStateToStorage = (): void => {
    localStorage.setItem(getShowAllStorageKey(), 'true')
  }

  const removeFromHeaderStorage = (): void => {
    localStorage.removeItem(getHeaderStorageKey())
  }

  const removeFromShowAllStorage = (): void => {
    localStorage.removeItem(getShowAllStorageKey())
  }

  const getHeaderStorageKey = (): string => {
    return auth.user.id.toString().concat(':', type, ':', 'hiddenHeader')
  }

  const getShowAllStorageKey = (): string => {
    return  auth.user.id.toString().concat(':', type, ':', 'showAll')
  }

  return {
    isHeaderStorageEmpty,
    toggleHeaderStorage,

    isShowAllStorageEmpty,
    toggleShowAllStorage,
  }
}
