import {email, numeric, required, requiredIf, requiredUnless} from "@/utils/i18n-validators";
import {Ref} from "vue";
import {IProductType} from "@/pages/products/interfaces";

let defaultValidationRules;
export default  defaultValidationRules = function(emailIsOptional: Ref<boolean>, salesChannelIsOptional: Ref<boolean>, productType: Ref<string>, productTypes: Ref<Array<IProductType>>) {
  let defaultRules = {
    name: {
      required
    },
    email: {
      requiredUnless: requiredUnless(emailIsOptional),
      email
    },
    status: {
      required, numeric
    },
    phone: {},
    telegram: {},
    countries: {},
    sales_channel_id: {
      required,
      numeric
    },
    responsible_user_ids: {required, $autoDirty: true},
    product_types: {required},
    contact_persons: {},
    association_type_id: {requiredIf: requiredIf(productType.value ==  import.meta.env.VITE_FAKED_PRODUCT_TYPE_ID)},
    sp_type: {},
  }
  switch ((productTypes.value.find(item => item.id.toString() == productType.value)?.model_class_name)){
    case 'App\\Models\\ProductSalesB2B':
      defaultRules['email'] = {requiredUnless: requiredIf(false), email};
      defaultRules = {...defaultRules, ...{client_type_id: { required }}}
      break;
    case 'App\\Models\\ProductPayportMerchant':
      defaultRules = {...defaultRules, ...{websites: {required}}}
      break;
  }
  return defaultRules;
}
