import {default as TomSelectObject} from "tom-select";
import axios from "axios";
import {ContactPerson as IContact} from "../../../../stores/contact_person/interfaces";
import {IAssociationType} from "../../../../stores/association/interfaces";
import _ from "lodash";
import {useI18n} from "vue-i18n";
import {Ref} from "vue";

let tomSelectOptions;

export default tomSelectOptions = function(selectPage:Ref<number>, params: {
    placeholder: string,
    display_field: string,
    extra_value_field?: string,
    url: string
}){
  const { t } = useI18n();
  return {
    create: false,
    placeholder: t("Choose contact persons"),
    onDelete: () => null,
    valueField: 'data',
    labelField: 'display_field',
    searchField: ['display_field'],
    maxOptions: 10000,
    plugins: {
      'virtual_scroll': {},
      'clear_button': {
        title: t("Clear"),
        html: (data: { className: string, title: string }) => {
          return `<div class="${data.className}" style="right: 35px !important;" title="${data.title}">&times;</div>`
        }
      },
    },
    preload: true,
    firstUrl: (query: string) => {
      selectPage.value = 1;
      return params.url + encodeURIComponent(query);
    },
    load: async function (query: string, callback: (inp?: Array<object>) => void) {
      const url = (this as unknown as TomSelectObject).getUrl(query);

      try {
        const res = await axios.get(url);
        if (res.data.last_page > selectPage.value) {
          const nextUrl = params.url + encodeURIComponent(query) + '&page=' + ++selectPage.value;
          (this as unknown as TomSelectObject).setNextUrl(query, nextUrl);
        }
        const onlyNeededFields: Array<{ data: string, display_field: string }> = (res.data.data as Array<IContact | IAssociationType>)
          .map((el: IContact | IAssociationType) => {
            return {
              data: JSON.stringify({
                id: el.id,
                extra_value_field: params.extra_value_field ? _.get(el, params.extra_value_field) : undefined,
              }),
              display_field: _.get(el, params.display_field),
            };
          });
        callback(onlyNeededFields);
      } catch {
        callback();
      }
    },
    shouldLoadMore: () => true,
    render: {
      loading_more: function () {
        return '<div class="loading-more-results py-2 d-flex align-items-center">'
                + '<div class="spinner"></div>'
                + t("Loading extra values...")
                + '</div>';
      },
      no_more_results: function () {
        return `<div class="no-more-results">${t('All results are shown.')}</div>`;
      }
    },
  }
};
