import {IAdditionalProductInfo, ILead} from "./interfaces";
import { IComment, ICommentable, IPage } from "@/utils/interfaces";
import { ICountry } from "../countries/interfaces";
import { ISalesChannel } from "../sales_channels/interfaces";
import { IUserShort } from "../users/interfaces";
import { IClient } from "@/pages/clients/interfaces";
import { IServiceProvider } from "@/stores/service_providers/interfaces";
import { IProductType } from "../products/interfaces";
import { ContactPerson as IContact } from "@/stores/contact_person/interfaces";
import { useCommentStore } from "@/stores/comment";
import { IAssociationType } from "@/stores/association/interfaces";

class Lead implements ILead, ICommentable {
  id: number;
  name: string;
  email: string;
  status: string;
  phone: string;
  telegram: string;
  sp_type: string;
  creator: IUserShort;
  responsible_user_ids: Array<string>;
  responsible_users: Array<IUserShort>;
  countries: Array<ICountry>;
  sales_channel_id: string;
  sales_channel: ISalesChannel;
  client: IClient;
  created_at: string;
  updated_at: string;
  creator_user_id: number;
  client_id: number | null;
  status_name: string;
  product_types: Array<IProductType>;
  contacts: Array<IContact>;
  association_type_id: number | null;
  association_type: IAssociationType;
  switch_types: Array<IAssociationType>;
  has_aggregator_participants: boolean;
  has_holding_participants: boolean;
  updated_blocks: Array<string>;
  service_provider_id: number | null;
  service_provider: IServiceProvider;
  user_favorite_id: number | null
  additional_product_information: IAdditionalProductInfo | undefined;

  static commentStore = useCommentStore();

  constructor(attrs: ILead) {
    this.id = attrs.id;
    this.name = attrs.name;
    this.email = attrs.email;
    this.status = attrs.status;
    this.phone = attrs.phone;
    this.telegram = attrs.telegram;
    this.sp_type = attrs.sp_type;
    this.creator = attrs.creator;
    this.responsible_user_ids = attrs.responsible_user_ids;
    this.responsible_users = attrs.responsible_users;
    this.countries = attrs.countries;
    this.sales_channel_id = attrs.sales_channel_id;
    this.sales_channel = attrs.sales_channel;
    this.client = attrs.client;
    this.created_at = attrs.created_at;
    this.updated_at = attrs.updated_at;
    this.creator_user_id = attrs.creator_user_id;
    this.client_id = attrs.client_id;
    this.status_name = attrs.status_name;
    this.product_types = attrs.product_types;
    this.contacts = attrs.contacts;
    this.association_type_id = attrs.association_type_id;
    this.association_type = attrs.association_type;
    this.switch_types = attrs.switch_types;
    this.has_aggregator_participants = attrs.has_aggregator_participants;
    this.has_holding_participants = attrs.has_holding_participants;
    this.updated_blocks = attrs.updated_blocks;
    this.service_provider_id = attrs.service_provider_id;
    this.service_provider = attrs.service_provider;
    this.user_favorite_id = attrs.user_favorite_id;
    this.additional_product_information = attrs.additional_product_information
  }
  // Method to update a property dynamically
  updateField<K extends keyof Lead>(field: K, value: Lead[K]): void {
    this[field] = value as this[K]; // Type assertion to resolve the error
  }
  async getComments(params?: { page?: string | number | undefined; perPage?: string | number | undefined; }): Promise<IPage<IComment>> {
    return await Lead.commentStore.getComments(
      {
        ...params,
        commentable_type: "Lead",
        commentable_id: this.id
      }
    );
  }

  async addNewComment(comment: string | null): Promise<IComment> {
    return await Lead.commentStore.createComment({
      commentable_type: "Lead",
      commentable_id: this.id,
      comment
    });
  }
}

export { Lead };
