import { IUserShort } from "@/pages/users/interfaces";
import { ICountry } from "@/pages/countries/interfaces";
import { IClient } from "@/pages/clients/interfaces";
import { IServiceProvider } from "@/stores/service_providers/interfaces";
import { IContactable } from "@/utils/interfaces";
import { ContactPerson as IContact } from "@/stores/contact_person/interfaces";
import { ISalesChannel } from "../sales_channels/interfaces";
import { IProductType } from "../products/interfaces";
import { IAssociationType } from "@/stores/association/interfaces";

interface ILeadBase {
  responsible_user_ids: Array<string>,
  sales_channel_id: string,
  name: string,
  email: string,
  status: string,
  phone: string,
  telegram: string,
  sp_type: string,
}

interface ILead extends ILeadBase, IContactable {
  id: number,
  creator: IUserShort,
  responsible_users: Array<IUserShort>,
  sales_channel: ISalesChannel,
  client: IClient,
  created_at: string,
  updated_at: string,
  creator_user_id: number,
  client_id: number | null,
  status_name: string,
  product_types: Array<IProductType>,
  contacts: Array<IContact>,
  countries: Array<ICountry>,
  association_type_id: number | null,
  association_type: IAssociationType,
  service_provider_id: number | null,
  service_provider: IServiceProvider,
  switch_types: Array<IAssociationType>,
  has_aggregator_participants: boolean,
  has_holding_participants: boolean,
  updated_blocks: Array<string>,
  user_favorite_id: number | null,
  additional_product_information?: IAdditionalProductInfo
}

interface IAdditionalProductInfo {
  inn?: string,
  kpp?: string,
  client_type_name?: string,
  address?: string,
  client_type_id: string
}

interface ILeadShort {
  id: number,
  name: string,
  email: string,
  status: number,
  created_at: string,
  status_name: string,
}

interface ILeadShortWithStatus {
  id: number,
  name: string,
  status: number,
  client_id: number,
  status_name: string,
  product_types?: Array<{ id: number, name: string }>
}

interface ILeadForm extends ILeadBase {
  product_types: Array<string>,
  contact_persons: Array<string>,
  countries?: Array<string>,
  association_type_id?: string | number,
  organisation_address?: string,
  inn?: string,
  kpp?: string,
  client_type_id?: string,
  websites?: Array<String>
}

interface ILeadUpdateForm extends ILeadBase {
  product_types: Array<string>,
  cancel_comment?: string,
  countries?: Array<string>,
  association_type_id?: number | string,
  additional_product_information?: IAdditionalProductInfo
}

enum ILeadStatus {
  Cancelled = 4,
  Converted = 3,
  New = 0
}

enum ILeadEditableStatus {
  Cancelled = 4,
  New = 0
}

export type {
  ILeadBase,
  ILead,
  ILeadShort,
  ILeadShortWithStatus,
  ILeadForm,
  ILeadUpdateForm,
  IAdditionalProductInfo
};

export { ILeadStatus, ILeadEditableStatus };
