import {IPage} from "@/utils/interfaces";
import {IClient} from "@/pages/clients/interfaces";
import {ICoefficientClientProduct} from "@/pages/coefficients/interfaces";
import {IProductAutomationAssignment} from "@/pages/product_assignments/interfaces";

interface IProductType {
  id: number,
  name: string,
  model_class_name: string,
  client: IClient[]
}
interface IPayportMerchant{
    id: number,
    product_id?: number,
    product_type_id?: number,
    merchant_id?: number,
    product_status: number,
    name: string,
    email: string,
    status: number,
    status_name: string,
    product_status_name: string,
    sandbox_merchant_id?: number,
    product?: IProductType,
    sandbox_id?: number
}
interface IPayportAgent{
    id: number,
    product_id?: number,
    product_type_id?: number,
    agent_id?: number,
    product_status: number,
    name: string,
    email: string,
    status: number,
    status_name: string,
    product_status_name: string,
    sandbox_agent_id?: number,
}
interface IGnuVpnClient {
    id: number,
    product_id?: number,
    product_type_id?: number,
    external_user_id?: number,
    name: string,
    email: string,
    status: number,
    product_status: number,
    status_name: string,
    product_status_name: string,
    client_info?: IGnuVpnClientInfo,
}
interface IUTM {
    id: number,
    client_id: number,
    utm_source: string,
    utm_medium: string,
    utm_campaign: string,
    utm_content: string,
    utm_term: string,
    utm_promo: string,
    external_created_at: Date,
    external_updated_at: Date,
    created_at: Date,
    updated_at: Date,
}
interface IGnuVpnClientInfo {
    id: number,
    client_id: number,
    email_verified_at: Date,
    timezone: string,
    is_blocked: boolean,
    is_blocked_temp: boolean,
    user_agent: string,
    ip: string,
    external_created_at: Date,
    external_updated_at: Date,
    created_at: Date,
    updated_at: Date,
}
interface IMerchantUser {
    id: number,
    name: string,
    email: string,
    is_admin: number,
    status: number,
    is_admin_name: string,
    status_name: string,
    created_at: Date
}
interface IProduct<T> {
  id: number,
  creator_user_id?: number,
  responsible_user_id?: number,
  product_type_id: number,
  created_at: string,
  info?: T,
  product_type?: IProductType,
  product_type_relation?: string,
  fiats? : Array<ISelectOtions>
  coefficient: ICoefficientClientProduct | null
  product_assignment?: IProductAutomationAssignment
}

interface ProductFormData {
    product_type_id: string,
    email: string,
    name: string,
    status: string,
    clientId: string
}

export enum IProductStatus {
    NEW = 0,
    SAND = 1,
    PRODUCTIVE = 2,
    OUTFLOW = 3,
    CANCEL = 4,
    CLIENT_CANCEL = 5
}

export enum InactiveProductStatuses {
    NEW = 0,
    SAND = 1,
    OUTFLOW = 3,
    CANCEL = 4,
    CLIENT_CANCEL = 5
}

export enum PayportMerhcantStatuses {
    NEW = 0,
    SAND = 1,
    PRODUCTIVE = 2,
    // CLIENT_CANCEL = 5
}

export enum PayportAgentProductStatuses {
    NEW = 0,
    // SAND = 1,
    PRODUCTIVE = 2,
    // CLIENT_CANCEL = 5
}

export enum GnuVpnClientProductStatuses {
    INACTIVE = 0,
    ACTIVE = 1,
}

enum IPayportMerchantStatus {
    INACTIVE = 0,
    ACTIVE = 1,
}

export enum ProductType {
    "Payport Merchants" = 1,
    "Payport Agents" = 2,
    "GnuVPN Clients" = 3,
}

interface ITransactions {
    id: number;
    created_at: Date;
    usdt_amount: string;
    usdt_amount2pay?: string;
    usdt_amount2grow?: string;
    usdt_amount2service?: string;
    usdt_amount2agent?: string;
    usdt_amount2service_agents?: string;
    merchant_id?: number;
    api_type: number;
    status: number;
    fiat_currency: string;
    fiat_amount: string;
    invoice_type: number;
    payment_id?: string;
    service_provider_id?: number;
    payment_system_id?: number;
    type?: number;
    comment?: string;
    trader_id?: number;
    trader_name?: string;
    deal_status?: number;
    amount2agent_selected?: string;
    amount2service_agent_selected?: string;
    serviceAgentCommision?: number;
    agentCommision?: number;
    merchant?: IMerchant;
    payment_system?: IPaymentSystem;
    service_provider?: IServiceProvider;
}

interface IClientTariff {
    id: number;
    name: string;
    days: number;
    discount: number;
    status: string;
    payment_type: string;
    is_popular: number;
    price: number;
    price_show: number;
    price_show_old: number;
    priority: number;
    external_created_at: Date;
    external_updated_at: Date;
    created_at: Date;
    updated_at: Date;
}

interface IClientSubscription {
    id: number;
    client?: IClient;
    tariff?: IClientTariff;
    activated_at: Date;
    begins_at: Date;
    ends_at: Date;
    tariff_data: object;
    is_enabled: number;
    is_manual: boolean;
    manual_reason: string;
    manual_comment: string;
    in_app: boolean;
    external_created_at: Date;
    external_updated_at: Date;
    external_deleted_at: Date;
    created_at: Date;
    updated_at: Date;
}

interface IClientInvoice {
    id: number;
    client?: IClient;
    tariff?: IClientTariff;
    transaction_id: string;
    subscription_id: number;
    driver: string;
    symbol: string;
    amount: number;
    provider: string;
    amount_paid: number;
    rate: number;
    status: string;
    external_created_at: Date;
    external_updated_at: Date;
    created_at: Date;
    updated_at: Date;
}

interface IMerchant {
    id?:number;
    name?:string;
    email?:string;
    balance?: MerchantBalance
}

interface IMerchantMainInfo {
    product: IProduct<IPayportMerchant>;
    balance_total: number;
    client_chat: string;
    merchant_chat: string;
    client_session_enable: string;
    crypto_withdrawal_minamount: string;
    availavle_currecies_input: string;
    availavle_currecies_output: string;
    id: number;
    name: string;
    theme_api5: string;
    enable_2fa: boolean;
    enable_crypto_withdrawal: boolean;
    enable_recalculate: boolean;
    enable_payout: boolean;
    created_at: string;
    updated_at: string;
    email_verified_at: string;
    merchants_productive: IMerchant[];
    merchants_sandbox: IMerchant[];
    fiats? : Array<ISelectOtions>;
    sandData? : {
        merchant: IMerchant,
        latest_transactions: Array<ITransactions>
    }
    show_recreate_ticket_button: boolean;
}

interface ISubscriptionData {
    subscriptions: Array<IClientSubscription>
}

interface IInvoiceData {
    invoices: Array<IClientInvoice>
}

interface IPaymentSystem{
    name?: string;
}
interface IServiceProvider{
    id?: number;
    name?: string;
    status?: number;
    created_at?: Date;
    updated_at?: Date;
    type?: string;
    chat_name?: string;
}

interface IFiat{
    id?: number;
    asset?: string;
    name?: string;
    precision?: number;
    status?: number;
    created_at?: Date;
    updated_at?: Date;
    pusdt_address_view?: boolean;
}

interface IProductPage<T> extends IPage<T>{
    filters?: ITransactionFilter,
    totals?: ITransactionTotal,
    total_sum?: number,
}

interface ITransactionTotal {
    usdt_amount?: number,
    volume?: number,
    usdt_amount2pay?: number,
    usdt_amount2grow?: number,
    usdt_amount2service?: number,
    usdt_amount2agent?: number,
    usdt_amount2service_agents?: number,
    usdt_amount2agent_selected?: number,
    usdt_amount2service_agent_selected?: number,
    fiat_amount?: number|boolean,
    amount_receive?: number,
    usdt_amount2markup_payport?: number,
    usdt_amount2markup_agents?: number,
}

interface ITransactionFilter{
    status?: Array<ISelectOtions>,
    invoice_types?: Array<ISelectOtions>,
    withdrawal_types?: Array<ISelectOtions>,
    fiats?: Array<ISelectOtions>,
    payment_systems?: Array<ISelectOtions>,
    service_providers?: Array<ISelectOtions>,
    invoice_type: Array<ISelectOtions>,
    merchants?: Array<ISelectOtions>
}
interface ICommissionsFilter{
    status?: Array<ISelectOtions>,
    invoice_types?: Array<ISelectOtions>,
    fiats?: Array<ISelectOtions>,
    payment_systems?: Array<ISelectOtions>,
    service_providers?: Array<ISelectOtions>,
    api_type?: Array<ISelectOtions>
    type_amount?: Array<ISelectOtions>
}
interface IClientTariffsFilter {
    tariff_name: Array<ISelectOtions>,
    is_manual: Array<ISelectOtions>,
}
interface IClientInvoicesFilter {
    tariff_name: Array<ISelectOtions>,
    provider_name: Array<ISelectOtions>,
    currency: Array<ISelectOtions>,
}
interface IMerchantBalanceFilter{
    status?: Array<ISelectOtions>,
    invoice_types?: Array<ISelectOtions>,
    invoice_type: Array<ISelectOtions>,
    fiats?: Array<ISelectOtions>,
    payment_systems?: Array<ISelectOtions>,
    service_providers?: Array<ISelectOtions>
}
interface IMerchantCryptoOperationsFilter{
    status?: Array<ISelectOtions>,
    invoice_types?: Array<ISelectOtions>,
    invoice_type?: Array<ISelectOtions>
    crypto_addresses: Array<CryptoWithdrawalSubtotal>,
    total: number,
}
interface IMerchantAvailableLimitsFilter{
    direction?: Array<ISelectOtions>;
    fiats?: Array<ISelectOtions>;
    payment_systems?: Array<ISelectOtions>;
    payment_system_types?: Array<ISelectOtions>;
}
interface IPayportAgentWithdrawalHistoryFilter{
    status?: Array<ISelectOtions>,
    crypto_addresses: Array<CryptoWithdrawalSubtotal>
}
interface CryptoWithdrawalSubtotal {
    crypto_address:string;
    total_amount: string;
    min_created_at: Date;
    max_created_at: Date;
}
interface IPayportAgentMerchantsFilter{
    status?: Array<ISelectOtions>,
}

interface IMerchantAgents{
    id: number;
    agent_id: number;
    merchant_id: number;
    invoice_type: number;
    agent_type: number;
    created_at: string;
    updated_at: string;
    agent_type_name: string;
    product_id?: number;
    client_id?: number;
    agent: IAgentRelation;
}

interface ISelectOtions{
    value: string
    text: string
}

interface IMerchantBalance{
    balance_total?: number;
    uniqueAgents:Array<IAgentRelation>;
    merchantRevenue?: IRevenues;
    agentRevenues?: IRevenues;
}
interface Payment {
    usdt_amount?: number|string,
    usdt_amount2grow?: number|string,
    usdt_amount2service?: number|string,
    usdt_amount2agent?: number|string,
    usdt_amount2service_agents?: number|string,
}

interface Withdrawal {
    usdt_amount?: number|string,
    usdt_amount2grow?: number|string,
    usdt_amount2service?: number|string,
    usdt_amount2agent?: number|string,
    usdt_amount2service_agents?: number|string,
}

interface IRevenues {
    payment: { [key: string]: Payment };
    withdrawal: { [key: string]: Withdrawal };
}
interface IAgentRelation {
    id?: number;
    product_id?: number;
    product_type_id?: number;
    name?: string;
    email?: string;
    email_verified_at?: string;
    password?: string;
    remember_token?: string;
    status?: number;
    created_at?: Date;
    updated_at?: Date;
    secret_2fa?: string;
    enable_2fa?: boolean;
    enable_crypto_withdrawal?: boolean;
}

interface IUniqueAgents {
    id: number;
    agent_id?: number;
    merchant_id?: number;
    invoice_type?: number;
    agent_type?: number;
    created_at?: Date;
    updated_at?: Date;
    agent?: IAgentRelation;
}

interface IServiceProviderCurrency{
    id?: number;
    merchant_id?: number;
    service_provider_id?: number;
    priority?: number;
    service_provider?: IServiceProvider;
    revolver?: string;
}

interface IMerchantProviders{
    type: string;
    fiat: string;
    sp_list: Array<string>;
    sp_str: string;
    priority: Array<number>;
}

interface IMerchantCommissions {
    id: number;
    api_type: number;
    merchant_id: number;
    property_type: number;
    property: string;
    value: Array<string|number>;
    created_at: Date;
    updated_at: Date;
    service_provider_id: number;
    fiat_id?: any;
    property_id: number;
    percentage: number;
    fixed: number;
    percentage_sum: number;
    commission_direction: string;
    fiat: object;
    service_provider: object;
    percentage_totals: {[key: string]: any};
}
interface ICryptoOperations {
    id: number;
    created_at: Date|string;
    amount: string;
    merchant_id: number;
    status: number;
    invoice_type: number;
    payment_id?: string|number;
    invoice_type_name?: string;
    invoice_status_name?: string;
    crypto_address: string
}
interface IPaymentSystems{
    [key:string]:{
        min: number;
        max: number;
    }
}
interface ICurrencyInfo {
    payment_systems:Array<IPaymentSystems>;
    min: number;
    max: number;
}

interface IMerchantAvailableLimits {
    [key: number]: {
        [key: string]: Array<ICurrencyInfo>
    }
}


interface AgentBalance {
    id: number;
    agent_id: number;
    amount: string;
    created_at: string;
    updated_at: string;
}
interface MerchantBalance {
    id: number;
    merchant_id: number;
    amount: string;
    created_at: string;
    updated_at: string;
}

interface Commission {
    value: {
        fixed: number;
        percentage: number;
    };
    amount: number;
}

interface IAgentMainInfo {
    product: IProduct<IPayportAgent>;
    balance_total: number;
    crypto_withdrawal_minamount: string;
    comms: Commission[];
    id: number;
    balance: AgentBalance;
    show_recreate_ticket_button: boolean;
}
interface IAgentWithdrawalHistory{
    id: number;
    amount: string;
    payment_system: number;
    payment_id: string|number;
    agent_id: number;
    sd_user_id: string|number;
    status: number;
    payed: boolean;
    addition_info: string;
    comment: string;
    created_at: string;
    updated_at: string;
    invoice_status_name: string;
    amount_to_be_received: string;
    invoice_crypto_extend: {
        id: number;
        invoice_id: number;
        invoice_type: number;
        crypto_address: string;
        coin: string;
        currency_id: number;
        address_amount: string;
        amount: string;
        status: number;
        cancelation_reason: string;
        payed: boolean;
        addition_info: string;
        checked_at: Date;
        comment: string;
        created_at: string;
        updated_at: string;
        percent: string;
    }
}

interface IAgentMerchants{
    merchants: Array<{
        id: number;
        name: string;
        email: string;
        created_at: Date;
        status_name: string;
        balance: MerchantBalance;
        product_id?: number;
        client_id?: number;
    }>,
    open_withdrawals: Array<{[key: string]:string}>
}

interface IGnuVpnClientMainInfo {
    client_info: IGnuVpnClientInfo;
    utm: IUTM;
}

interface ImportedProduct {
    id: number;
    name: string;
    email: string;
}
interface IProductsImport {
    clients: Array<ImportedProduct>;
    unImportedAgents: Array<ImportedProduct>;
    unImportedMerchants: Array<ImportedProduct>;
    unImportedGnuVpnClients: Array<ImportedProduct>;
}
interface IKeyValue {
    [key: string]:  string
}
export type {
  IProduct,
  IProductType,
  ProductFormData,
  IPayportMerchant,
  IPayportAgent,
  IGnuVpnClient,
  IGnuVpnClientInfo,
  IPayportMerchantStatus,
  IMerchantUser,
  ITransactions,
  ITransactionTotal,
  ITransactionFilter,
  IProductPage,
  IMerchantBalance,
  ICommissionsFilter,
  IMerchantBalanceFilter,
  IClientTariffsFilter,
  IClientInvoicesFilter,
  IMerchantCryptoOperationsFilter,
  IMerchantCommissions,
  IMerchantProviders,
  IServiceProviderCurrency,
  IFiat,
  IServiceProvider,
  ICryptoOperations,
  IMerchantAvailableLimits,
  IMerchantAvailableLimitsFilter,
  IMerchantMainInfo,
  IMerchantAgents,
  IAgentMainInfo,
  IGnuVpnClientMainInfo,
  IClientTariff,
  IClientSubscription,
  IClientInvoice,
  IInvoiceData,
  ISubscriptionData,
  IPayportAgentWithdrawalHistoryFilter,
  IAgentWithdrawalHistory,
  IPayportAgentMerchantsFilter,
  IAgentMerchants,
  IProductsImport,
  ImportedProduct,
  IKeyValue,
};
