import { ref } from "vue";
import { FilterManager } from "@/mixins/Filter";
import { useRoute } from "vue-router";
import { useReportStore } from "@/stores/reports/reports";
import { getPeriodStr } from "@/utils/helper";

export default () => {
  const route = useRoute();
  const query = ref(route.query);
  const reportStore = useReportStore();

  return {
    ...(new FilterManager({
      stringKeys: [ "arbitrage" ],
      arrayKeys: [
        "fiats[]",
        "types[]",
        "statuses[]",
        "merchants[]",
        "service_providers[]",
        "arbitrage[]",
      ],
      predefined: {
        date_begin: getPeriodStr("2days").split(" - ")[0],
        date_end: getPeriodStr("2days").split(" - ")[1],
        "statuses[]": [ "1" ],
      },
      hasPeriod: true,
      customInitFilterDate: () => {
        if (query.value.date_begin || query.value.date_end) {
          return query.value.date_begin + " - " + query.value.date_end;
        }
        
        return getPeriodStr("2days");
      },
    })).useFilter(),
    typesList: reportStore.typesList,
    statusesList: reportStore.statusesList,
    arbitrageList: reportStore.arbitrageList,
  };
}
