import { ref } from "vue";
import { useRoute } from "vue-router";
import { FilterManager } from "@/mixins/Filter";
import { useReportStore } from "@/stores/reports/reports";
import { getPeriodStr } from "@/utils/helper";

export default () => {
  const route = useRoute();
  const query = ref(route.query);
  const reportStore = useReportStore();

  return {
    ...(new FilterManager({
      stringKeys: [
        "conversion_timeout",
        "conversion_amount",
        "fiat_amount_from",
        "fiat_amount_to"
      ],
      arrayKeys: [
        "service_providers[]",
        "traders[]",
        "merchants[]",
        "fiats[]",
        "types[]",
        "payment_systems[]",
        "responsible_user[]"
      ],
      extraPeriodKeys: [
        {
          name: "creation_prod",
          date_begin_name: "date_created_begin",
          date_end_name: "date_created_end",
        },
      ],
      predefined: {
        'by_permission': 'reports_payport_maintenance_index',
      },
      hasPeriod: true,
      hasDateTimePeriod: true,
    })).useFilter(),
    typesList: reportStore.typesList,
    conversionRangesList: reportStore.conversionRangesList
  };
};
