import { ref } from "vue";
import { FilterManager } from "@/mixins/Filter";
import { useRoute } from "vue-router";
import { useReportStore } from "@/stores/reports/reports";
import { getPeriodStr } from "@/utils/helper";

export default () => {
  const route = useRoute();
  const query = ref(route.query);
  const reportStore = useReportStore();

  return {
    ...(new FilterManager({
      arrayKeys: [
        "status[]",
        "merchants[]",
        "fiats[]",
      ],
      predefined: {
        date_begin: getPeriodStr("week").split(" - ")[0],
        date_end: getPeriodStr("week").split(" - ")[1],
        "status[]": [ "1" ],
      },
      hasPeriod: true,
      customInitFilterDate: () => {
        if (query.value.date_begin || query.value.date_end) {
          return query.value.date_begin + " - " + query.value.date_end;
        }

        return getPeriodStr("week");
      },
    })).useFilter(),
    statusesList: reportStore.statusesList,
  };
}
