import {FilterManager} from "@/mixins/Filter";

export type TFilterCategories = 'claimant_category' | 'defendant_category' | 'compensation_category'

export enum FilterArrays {
  CLAIMANT_IDS_BY_NAME = 'claimant_ids_by_name[]',
  CLAIMANT_IDS_BY_EMAIL = 'claimant_ids_by_email[]',
  DEFENDANT_IDS_BY_NAME = 'defendant_ids_by_name[]',
  DEFENDANT_IDS_BY_EMAIL = 'defendant_ids_by_email[]',
  COMPENSATION_IDS_BY_NAME = 'compensation_ids_by_name[]',
  TICKET_STATUSES = 'ticket_statuses[]',
  FIATS = 'fiats[]'
}

export enum FilterStrings {
  CLAIMANT_CATEGORY = 'claimant_category',
  DEFENDANT_CATEGORY = 'defendant_category',
  COMPENSATION_CATEGORY = 'compensation_category',
}

export default () => {
  return {
    ...(new FilterManager({
      stringKeys: [
        FilterStrings.CLAIMANT_CATEGORY,
        FilterStrings.DEFENDANT_CATEGORY,
        FilterStrings.COMPENSATION_CATEGORY,
      ],
      searchKeys: [
        {
          text: 'ID',
          value: 'ticket_id'
        },
      ],
      arrayKeys: [
        FilterArrays.CLAIMANT_IDS_BY_EMAIL,
        FilterArrays.CLAIMANT_IDS_BY_NAME,
        FilterArrays.DEFENDANT_IDS_BY_EMAIL,
        FilterArrays.DEFENDANT_IDS_BY_NAME,
        FilterArrays.TICKET_STATUSES,
        FilterArrays.COMPENSATION_IDS_BY_NAME,
        FilterArrays.FIATS,
      ],
      predefined: {

      },
      extraPeriodKeys: [
        {
          name: 'invoice_created_at',
          date_begin_name: 'invoice_created_at_from',
          date_end_name: 'invoice_created_at_to',
        },
        {
          name: 'created_at',
          date_begin_name: 'created_at_from',
          date_end_name: 'created_at_to',
        },
      ],
    }))
      .useFilter(),
  };
}
