import { ref } from "vue";
import { FilterManager } from "@/mixins/Filter";
import { useRoute } from "vue-router";
import { useReportStore } from "@/stores/reports/reports";
import { getPeriodStr } from "@/utils/helper";

export default () => {
  const route = useRoute();
  const query = ref(route.query);
  const reportStore = useReportStore();

  return {
    ...(new FilterManager({
      stringKeys: [ "step", "show_fiat_amount", "from_time", "to_time" ],
      arrayKeys: [
        "fiats[]",
        "types[]",
        "statuses[]",
        "merchants[]",
        "type_amount[]",
        "day_of_week[]",
        "day_of_month[]",
        "month[]",
      ],
      predefined: {
        date_begin: getPeriodStr("day").split(" - ")[0],
        date_end: getPeriodStr("day").split(" - ")[1],
        "statuses[]": [ "1" ],
        "step": 'day',
        "perPage": '20',
      },
      hasPeriod: true,
      customInitFilterDate: () => {
        if (query.value.date_begin || query.value.date_end) {
          return query.value.date_begin + " - " + query.value.date_end;
        }
        
        return getPeriodStr("day");
      }
    })).useFilter(),
    typesList: reportStore.typesList,
    statusesList: reportStore.statusesList,
    stepList: reportStore.stepList,
    amountTypesList: reportStore.amountTypesList,
    dayOfWeekList: reportStore.dayOfWeekList,
    monthsList: reportStore.monthsList,
  };
}
