import { ITrader, ITraderBalanceRow } from "@/stores/trader/interfaces";
import { IServiceProvider } from "@/stores/service_providers/interfaces";
import { IComment, ICommentable, IPage } from "@/utils/interfaces";
import { IUserShort } from "../users/interfaces";
import { useCommentStore } from "@/stores/comment";
import { ContactPerson as IContact } from "@/stores/contact_person/interfaces";
import {ITelegramChats} from "@/stores/telegram_chats/interfaces";

class Trader implements ITrader, ICommentable {
  id: number
  id_payport: number
  id_payport_sand: number
  name: string
  email: string
  status: string
  phone: string
  telegram: string
  inputFiats: string
  outputFiats: string
  service_provider: IServiceProvider
  available_balances: ITraderBalanceRow[]
  ads_hidden: string
  environment_type: string
  locale: string
  agent_id: string
  service_provider_id: string
  payport_agent_id: string
  payport_service_provider_id: string
  responsible_users: Array<IUserShort>
  responsible_user_ids: Array<string>
  created_at: string
  contacts: Array<IContact>
  chats: Array<ITelegramChats>|null;

  static commentStore = useCommentStore();

  constructor(attrs: ITrader) {
    this.id = attrs.id;
    this.id_payport = attrs.id_payport;
    this.id_payport_sand = attrs.id_payport_sand;
    this.name = attrs.name;
    this.email = attrs.email;
    this.status = attrs.status;
    this.phone = attrs.phone;
    this.telegram = attrs.telegram;
    this.inputFiats = attrs.inputFiats;
    this.outputFiats = attrs.outputFiats;
    this.service_provider = attrs.service_provider;
    this.available_balances = attrs.available_balances;
    this.ads_hidden = attrs.ads_hidden;
    this.environment_type = attrs.environment_type;
    this.locale = attrs.locale;
    this.agent_id = attrs.agent_id;
    this.service_provider_id = attrs.service_provider_id;
    this.payport_agent_id = attrs.payport_agent_id;
    this.payport_service_provider_id = attrs.payport_service_provider_id;
    this.responsible_users = attrs.responsible_users;
    this.responsible_user_ids = attrs.responsible_user_ids;
    this.created_at = attrs.created_at;
    this.contacts = attrs.contacts;
    this.chats = attrs.chats;
  }

  async getComments(params?: { page?: string | number | undefined; perPage?: string | number | undefined; }): Promise<IPage<IComment>> {
    return await Trader.commentStore.getComments(
      {
        ...params,
        commentable_type: "Trader",
        commentable_id: this.id
      }
    );
  }

  async addNewComment(comment: string | null): Promise<IComment> {
    return await Trader.commentStore.createComment({
      commentable_type: "Trader",
      commentable_id: this.id,
      comment
    });
  }
}

export { Trader };
