import { ref } from "vue";
import { FilterManager } from "@/mixins/Filter";
import { useI18n } from "vue-i18n";
import { useRoute } from "vue-router";
import { getPeriodStr } from "@/utils/helper";

export default () => {
  const { t } = useI18n();
  const route = useRoute();
  const query = ref(route.query);

  return (new FilterManager({
    searchKeys: [
      {
        text: t('Deal ID'),
        value: 'payment_id'
      },
      {
        text: t('Invoice'),
        value: 'id'
      },
    ],
    stringKeys: [ "type", "check", "ad_hidden", "search", "searchField" ],
    arrayKeys: [
      "status[]",
      'merchants[]',
      'payment_system_type_ids[]',
      'payment_system_ids[]',
      'service_provider_ids[]',
      'fiat_ids[]',
    ],
    predefined: {
      date_begin: getPeriodStr("week").split(" - ")[0],
      date_end: getPeriodStr("week").split(" - ")[1],
      filter_field: "name",
    },
    hasPeriod: true,
    customInitFilterDate: () => {
      if (query.value.date_begin != undefined && query.value.date_end != undefined) {
        if (query.value.date_begin && query.value.date_end) {
          return query.value.date_begin + " - " + query.value.date_end;
        } else {
          return "";
        }
      }

      return getPeriodStr("week");
    },
  })).useFilter();
}
