import {IGnuVpnClient, IPayportAgent, IPayportMerchant, IProductType} from "@/pages/products/interfaces";
import {IUser} from "@/pages/users/interfaces";
import {ITrader} from "@/stores/trader/interfaces";
import {IServiceProvider} from "@/stores/service_providers/interfaces";
import {IClient} from "@/pages/clients/interfaces";
import {RouteLocationRaw} from "vue-router";
import {ITraderAdmins} from "@/stores/trader_admins/interfaces";

interface ITicketCustomer {
  id: number,
  name: string,
  email: string,
  status: number,
  type_id: string,
  type_name: string,
  count_open_tickets: number,
  customer_profile_link: RouteLocationRaw,
  customer_coefficient: Array<{[key: string]: string}>,
}

interface ITicketCustomerType<T> {
  id: number,
  name: string,
  created_at: string,
  product_type?: IProductType | null,
  available_customer_ids?: Array<number>,
  available_customers?: Array<{"id": number, "name": string, "product_status"?: number}>,
  model_class_name: TicketCustomerModelClassName
}

export enum TicketCustomerModelClassName {
  ProductPayportAgent = 'App\\Models\\ProductPayportAgent',
  ProductPayportMerchant = 'App\\Models\\ProductPayportMerchant',
  ProductGnuVpnClient = 'App\\Models\\ProductGnuVpnClient',
  User = 'App\\Models\\User',
  Trader = 'App\\Models\\Trader',
  TraderAdmin = 'App\\Models\\TraderAdmin',
  ServiceProvider = 'App\\Models\\ServiceProvider',
  Client = 'App\\Models\\Client',
}

export type ITicketCustomerAvailableType = IPayportMerchant
  | IPayportAgent
  | IGnuVpnClient
  | IUser
  | ITrader
  | ITraderAdmins
  | IServiceProvider
  | IClient

enum TypeId {
  PAYPORT_AGENTS = 1,
  PAYPORT_MERCHANTS = 2,
  GNU_VPN_CLIENTS = 3,
  USERS = 4,
  TRADERS = 5,
  SERVICE_PROVIDERS = 6,
  CLIENTS = 7,
  LEADS = 8,
}

export type {
  ITicketCustomer,
  ITicketCustomerType,
};

export {
  TypeId,
}
