import {IUserShort} from "@/pages/users/interfaces";
import {ITopicShort} from "@/pages/ts/topics/interfaces";
import {IQueueShort} from "@/pages/ts/queues/interfaces";

interface IMailAccountBase {
  id: number
  type: IMailAccountType
  name: string | null
  login: string
  password: string
  host: string
  port: number
  folder: string
  use_ssl: boolean
  queue_topic_id: number
  status: number
  creator_id: number | null
  created_at: string
  updated_at: string
  creator_user: IUserShort
  queue: IQueueShort | null
  topic: ITopicShort | null
}

interface IMailAccountForList extends IMailAccountBase {
  status_name: string
}

interface IMailAccount extends IMailAccountBase {
  status_name: string
}

interface IMailAccountUpdateForm {
  type: string
  name: string
  login: string
  password: string
  host: string
  port: string
  folder: string
  use_ssl: boolean
  queue_id: string
  queue_topic_id: string
  status: string | number
}

interface IMailAccountShort {
  id: string
  name: string
  login: string
}

export enum IMailAccountStatus {
  Inactive = 0,
  Active = 1,
}

export enum IMailAccountType {
  IMAP = 1,
  POP3 = 2,
  SMTP = 3,
}

export const TYPES_INCOME = [IMailAccountType.IMAP, IMailAccountType.POP3];
export const TYPES_OUTCOME = [IMailAccountType.SMTP];

export type {
  IMailAccountForList,
  IMailAccount,
  IMailAccountUpdateForm,
  IMailAccountShort,
};
