import {IUserShort} from "@/pages/users/interfaces";
import {IDepartment} from "@/stores/department/interfaces";
import {IQueueTopic} from "@/pages/ts/queue_topics/interfaces";

interface IQueueBase {
    id: number
    parent_id: number | null
    name: string
    slug: string
    status: number
    creator_id: number | null
    owner_id: number | null
    close_tickets_after: number | null
    created_at: string
    updated_at: string
    creator_user: IUserShort
    owner_user: IUserShort
    name_with_parents: string
    executor_user_ids: Array<string>
    executor_department_ids: Array<string>
    move_queue_ids: Array<string>
    has_tickets: boolean
}

interface IQueueForList extends IQueueBase {
    status_name: string
    parent_queue: IQueue
    executor_users: Array<IUserShort>
    executor_departments: Array<IDepartment>
    executor_users_all: Array<IUserShort>
    move_queues: Array<IQueue>
    queue_topics: Array<IQueueTopic>
}

interface IQueue extends IQueueBase {
    status_name: string
    parent_queue: IQueue
    executor_users: Array<IUserShort>
    executor_departments: Array<IDepartment>
    executor_users_all: Array<IUserShort>
    move_queues: Array<IQueue>
    queue_topics: Array<IQueueTopic>
}

interface IQueueUpdateForm {
    parent_id?: string | number | null;
    name: string;
    slug: string;
    status: string | number;
    is_auto_close_tickets?: boolean | null;
    close_tickets_after?: string | number | null;
    owner_id?: string | number | null;
    executor_user_ids?: Array<string|number> | null;
    executor_department_ids?: Array<string> | null;
    move_queue_ids?: Array<string> | null;
    queue_topics?: Array<IQueueTopic> | null;
    delete_queue_topic_ids?: Array<number> | [];
}

interface IQueueShort {
    id: number
    parent_id: number | null
    name: string
    slug: string
    status: number
    creator_id: number | null
    owner_id: number | null
    close_tickets_after: number | null
    created_at: string
    updated_at: string
    name_with_parents: string
}

interface IGetTreeSelectListParams {
    status?: number | null,
    active_by_tickets?: boolean | null,
    exclude_self_id?: number | null,
    skip_role_check?: boolean | null,
    by_role?: number | null,
    user_id_can_create?: number | null,
    role_can_create?: number | null,
}

enum IQueueStatus {
    Inactive = 0,
    Active = 1,
}

export type {
  IQueueForList,
  IQueue,
  IQueueUpdateForm,
  IQueueShort,
  IGetTreeSelectListParams,
};

export {
  IQueueStatus,
};
