import {IUserShort} from "@/pages/users/interfaces";
import {ITicket, TicketCustomerTypes} from "@/pages/ts/tickets/interfaces";
import {IFile} from "@/stores/file/interfaces";
import {IMailAccount} from "@/pages/ts/mail_accounts/interfaces";
import {DropzoneFile} from "dropzone";

interface ITicketCommentBase {
  id: number
  ticket_id: number
  text: string | null
  status: number
  creator_id: number
  created_at: string
  updated_at: string
  creator_user: IUserShort
  creator_formed: string
  ticket: ITicket
  files: Array<IFile> | null
  mail_account_id: number | null
  recipient_email: string | null
  bind_with_crm_comment: boolean
}

interface ITicketCommentParent {
  id: number
  text: string
  quote: string
  creator_formed: string
  created_at: string
  parent_id: number
}

interface ITicketComment extends ITicketCommentBase {
  mail_account: IMailAccount | null
  parent: ITicketCommentParent | null
  children: ITicketComment[]
  quote: string | null
}

interface ITicketCommentUpdateForm {
  ticket_id: number;
  valid_text?: boolean;
  text: string;
  status: number;
  files?: {name: string, hash: string, file: DropzoneFile} [] | null;
  isLoading?: boolean;
  mail_account_id: string;
  recipient_email: Array<string>;
  send_email?: boolean;
  parent_id?: number | null
  quote?: string | null
}

interface ITicketCommentUpdatePartForm {
  status?: number | null;
  mail_account_id?: string;
  recipient_email?: Array<string>;
  send_email?: boolean;
}

interface ITicketCommentCrmCommentBind {
  customer_type: string,
  customer_id: number,
  ticket_comment_id: number,
  crm_comment_id: number,
  updated_at: string,
  created_at: string,
  id: number,
}

interface ITicketCommentCrmCommentBindForm {
  customer_type: TicketCustomerTypes,
  customer_id: number,
  ticket_comment_id: number,
  crm_comment_id: number
}

export type {
  ITicketComment,
  ITicketCommentParent,
  ITicketCommentUpdateForm,
  ITicketCommentUpdatePartForm,
  ITicketCommentCrmCommentBind,
  ITicketCommentCrmCommentBindForm,
};
