import {IUserShort} from "@/pages/users/interfaces";
import {IQueueTopic} from "@/pages/ts/queue_topics/interfaces";
import {IMailAccountShort} from "@/pages/ts/mail_accounts/interfaces";

interface ITicketTemplateBase {
  id: number
  type: string
  name: string
  text: string
  status: number
  creator_id: number
  created_at: string
  updated_at: string
  creator_user: IUserShort
  queue_topic: IQueueTopic | null
  income_mail_account: IMailAccountShort | null
  outcome_mail_account: IMailAccountShort | null
}

interface ITicketTemplateForList extends ITicketTemplateBase {
  status_name: string
}

interface ITicketTemplate extends ITicketTemplateBase {
  status_name: string
}

interface ITicketTemplateUpdateForm {
  type: string;
  name: string;
  text: string;
  status: string | number;
  queue_id: string | number;
  queue_topic_id: string | number;
  income_mail_account_id: string | number;
  outcome_mail_account_id: string | number;
}

interface ITicketTemplateShort {
  id: string
  name: string
}

export enum ITicketTemplateStatus {
  Inactive = 0,
  Active = 1,
}

export enum ITicketTemplateType {
  AUTO_REPLY = 1,
  COMMENT_REPLY = 2,
  TICKET_TEXT = 3,
}

export const TYPES_WITH_QUEUES = [ITicketTemplateType.COMMENT_REPLY, ITicketTemplateType.TICKET_TEXT];
export const TYPES_WITH_MAIL_ACCOUNTS = [ITicketTemplateType.AUTO_REPLY];

export type {
  ITicketTemplateForList,
  ITicketTemplate,
  ITicketTemplateUpdateForm,
  ITicketTemplateShort,
};
