import {IUserShort} from "@/pages/users/interfaces";
import {ITicketType} from "@/pages/ts/ticket_types/interfaces";
import {IQueueTopic} from "@/pages/ts/queue_topics/interfaces";
import {ITicketComment, ITicketCommentUpdateForm} from "@/pages/ts/ticket_comments/interfaces";
import {ITicketCustomer} from "@/pages/ts/customers/interfaces";
import {IFile} from "@/stores/file/interfaces";
import {IQueue} from "@/pages/ts/queues/interfaces";
import {IPriority} from "@/pages/ts/priorities/interfaces";
import {ILog} from "@/pages/ts/log/interfaces";
import {QueueRolePermissionTypeEnum} from "@/pages/ts/queue_role_permissions/interfaces";
import {InvoiceTypes, ITransactionShow} from "@/stores/transaction/interfaces";
import {ITicketDynamicField} from "@/pages/ts/ticket_dynamic_fields/interfaces";
import {ISelect} from "@/utils/interfaces";
import {Ticket} from "@/pages/ts/tickets/classes";
import {ICriticalityTicket} from "@/pages/criticality/interfaces";
import {ICoefficientTicket} from "@/pages/coefficients/interfaces";
import * as lucideIcons from "lucide-vue-next";
import {IReminder} from "@/stores/reminder/interfaces";

interface ITicketBase {
    id: number
    parent_id: number | null
    type_id: number
    source: number
    source_name: string
    subject: string
    subject_with_id: string
    text: string
    executor_id: number | null
    customer_type: TicketCustomerTypes | null
    customer_id: number | null
    customer: ITicketCustomer | null
    customer_coefficient: ICoefficientTicket | null
    date_execution: string
    date_period_to: string | null
    period_step: number | null
    notify_period: number | null
    date_delayed_to: string
    created_at: string
    updated_at: string
    closed_at: string
    email: string
    creator_formed: string
    creator_user: IUserShort | null
    executor_user: IUserShort | null
    type: ITicketType
    status: IStatus
    status_color: string
    status_transitions: Array<ITicketStatus>
    queue: IQueue
    priority: IPriority
    dynamic_fields: Array<ITicketDynamicField> | null
    queue_topic: IQueueTopic
    time_elapsed: string
    time_eta: string
    time_sla: string
    date_eta: string
    files: Array<IFile> | null
    linked_tickets: Array<ITicket> | null
    children: Array<ITicket> | null
    link_comment: string | null
    history: Array<ILog> | null
    current_user_permissions: Array<QueueRolePermissionTypeEnum> | null
    user_favorite_id: number | null
    user_review_id: number | null
    ticket_otrs: ITicketOtrs | null
    ticket_invoices: ITicketInvoice[]
    criticality?: ICriticalityTicket[]
    theme: string | null
    interaction_type?: InteractionType | null
    is_private: boolean
    reminders: IReminder[]
    disallow_reopen: boolean
    visible_to_client: boolean
}

interface ITicketInvoice {
    id: number
    invoice_created_at: string | null
    created_at: string
    invoice_id: number | null
    payment_id: number | null
    invoice_type: InvoiceTypes | null
    ticket_id: number
    fiat_currency: string | null
    amount: string | null
    fiat_amount: string | null
    claimant: IParticipant | null
    defendant: IParticipant | null
    ticket: Ticket
    compensation: {
        id: number
        sideable: IParticipant
        comment: Pick<ITicketComment, 'text' | 'status'>
    } | null
}

interface IParticipant {
    id: number
    sideable_type: TicketInvoiceCompensationSideable
    participantable_type: TicketInvoiceParticipantable
    participantable: IParticipantable
}

interface IParticipantable {
    id: number
    name: string
    email?: string
    type?: string
    id_payport?: number
    merchant_id?: number
    client?: {
      id: number,
      pivot: {
        product_id: number
      }
    }
}

interface ITicketForList {
  id: number
  parent_id: number | null
  type_id: number
  source: number
  source_name: string
  subject: string
  subject_with_id: string
  executor_id: number | null
  customer_type: TicketCustomerTypes | null
  customer_id: number | null
  customer: ITicketCustomer | null
  customer_coefficient: ICoefficientTicket | null
  date_execution: string
  date_delayed_to: string
  created_at: string
  updated_at: string
  closed_at: string
  email: string
  creator_formed: string
  creator_user: IUserShort
  executor_user: IUserShort | null
  type: ITicketType
  status: IStatus
  status_color: string
  queue: IQueue
  priority: IPriority
  queue_topic: IQueueTopic
  time_elapsed: string
  time_sla: string
  time_eta: string
  date_eta: string
  user_favorite_id: number | null
  user_review_id: number | null
  preview?: string // short text
  comments?: IPreviewComment[]
  files?: IFile[]
  criticality?: ICriticalityTicket[]
  theme: string | null
  interaction_type?: InteractionType | null
  is_private: boolean
  disallow_reopen: boolean
  visible_to_client: boolean
}

interface ITicketForMassActions {
  id: number
  parent_id: number | null
  type_id: number
  source: number
  source_name: string
  subject: string
  subject_with_id: string
  executor_id: number | null
  customer_type: TicketCustomerTypes | null
  customer_id: number | null
  date_execution: string
  date_delayed_to: string
  created_at: string
  updated_at: string
  closed_at: string
  email: string
  type: ITicketType
  status: IStatus
  status_color: string
  status_transitions: Array<ITicketStatus>
  queue: IQueue
  priority: IPriority
  queue_topic: IQueueTopic
  current_user_permissions: Array<QueueRolePermissionTypeEnum> | null
  user_favorite_id: number | null
  user_review_id: number | null
  preview?: string // short text
  comments?: IPreviewComment[]
  files?: IFile[]
  interaction_type?: InteractionType | null
  is_private: boolean
  disallow_reopen: boolean
  visible_to_client: boolean
}

interface ITicket extends ITicketBase {
    parent_ticket: ITicket | null
    addComment(ticketComment: ITicketCommentUpdateForm): Promise<ITicketComment>;
}

interface ITicketLinkedTicket {
    id: number
    ticket: ITicket
    linkedTicket: ITicket
    comment: string
}

interface IPreviewComment {
  id: number
  status: 0 | 1
  created_at: string
  text: string
  output_with_smart_links: string
  files: IFile[]
  creator: {
    id: number
    full_name: string
  }
}

interface ITicketOtrs {
    id: number
    ticket_id: number
    otrs_ticket_id: number
    otrs_ticket_number: number
    created_at: string
    updated_at: string
    otrs_url: string
}

interface ITicketStatus {
    id?: number
    status: IStatus
    color?: string
}

interface ITicketUpdateForm {
    text: string;
    parent_id?: string | number | null;
    ticket_autofill_id?: string | number | null;
    type_id: string | number;
    customer_type?: string;
    customer_id?: string | number;
    queue_id: string | number,
    queue_topic_id: string | number,
    executor_id?: string | number | null,
    files?: {name: string, hash: string} [] | null,
    dynamic_fields?: Array<ITicketDynamicField> | [],
    date_execution: string | null,
    date_period_to: string | null,
    notify_period: string | number | null,
    date_delayed_to: string | null,
    criticality?: Array<string> | null,
    theme?: string | null,
    interaction_type?: string | InteractionType | null,
    is_private?: string | number | null,
    disallow_reopen?: string | number | null,
    visible_to_client?: string | number | null,
}

interface ITicketUpdatePartForm {
    ids?: Array<number> | null,
    status?: string | number | null,
    queue_id?: string | number | null,
    priority_id?: string | number | null,
    executor_id?: string | number | null,
    customer_type?: string | null,
    customer_id?: string | number | null,
    comment_text?: string | null,
    comment_status?: number | null,
    comment_valid_text?: boolean | null,
    link_tickets?: Array<string> | null,
    link_comment?: string | null,
    date_execution?: string | null,
    date_delayed_to?: string | null,
    date_period_to?: string | null,
    notify_period?: string | number | null,
    topic_id?: string | number | null,
    type_id?: string | null,
    theme?: string | null,
    interaction_type?: string | InteractionType | null,
    is_private?: string | number | null,
    disallow_reopen?: string | number | null,
    visible_to_client?: string | number | null,
}

interface ITicketInvoiceOption {
    id: number,
    payment_id: number | null,
    usdt_amount: string,
    invoice_type: InvoiceTypes,
}

interface ISelectableTicketInvoice {
    invoice: string
    payment: string
    select: ISelect[]
}

interface ITicketInvoiceConfirmProps {
    isOpen: boolean
    message: string,
    close: () => void,
    dispatch: (commentData: {comment_text: string, comment_status: number}) => Promise<void>,
}

interface IImportTicketInvoiceFormData {
    claimant: {
        claimant_id: string,
        claimant_type: string,
    },
    defendant: {
        defendant_id: string,
        defendant_type: string,
    },
    transaction: ITransactionShow,
    ticket_id: string,
    status: TicketInvoiceImportStatuses,
    color: string,
    error: string,
}

enum TicketInvoiceImportStatuses {
    PENDING = 1,
    READY = 2,
    PROCESS = 3,
    LOADED = 5,
    ERROR = 6,
}

enum TicketInvoiceParticipantable {
    TRADER = 'App\\Models\\Trader',
    SERVICE_PROVIDER = 'App\\Models\\ServiceProvider',
    MERCHANT = 'App\\Models\\ProductPayportMerchant',
}

enum TicketInvoiceCompensationSideable {
    CLAIMANT = 'App\\Models\\TicketSystem\\TicketInvoiceClaimant',
    DEFENDANT = 'App\\Models\\TicketSystem\\TicketInvoiceDefendant',
    PAYPORT = 'App\\Models\\TicketSystem\\TicketInvoicePayport',
    WITHOUT = 'App\\Models\\TicketSystem\\TicketInvoiceWithoutCompensation',
}

enum IStatus {
    New = 1,
    Processing = 2,
    Closed = 3,
    Canceled = 4,
    Delayed = 5,
}

enum TicketSource {
  CRM = 1,
  EMAIL = 2,
  PAYPORT = 3,
  GNUVPN = 4,
  BITCOINOX = 5,
  COINCHANGE = 6,
  OTRS = 7,
  PAYPORTLK = 8,
}

export enum InteractionType {
  CALL = 1,
  MEETING = 2,
  CORRESPONDENCE = 3,
  NEW_GEO = 4,
  FLOW = 5,
  CONSULTATION = 6,
  ACTIVATION = 7,
  DEACTIVATION = 8,
}

export const InteractionTypeIcons: {[key: number]: keyof typeof lucideIcons} = {
  [InteractionType.CALL]: 'Phone',
  [InteractionType.MEETING]: 'FileEdit',
  [InteractionType.CORRESPONDENCE]: 'Mails',
  [InteractionType.NEW_GEO]: 'MapPin',
  [InteractionType.FLOW]: 'Network',
  [InteractionType.CONSULTATION]: 'MessageSquare',
  [InteractionType.ACTIVATION]: 'ShieldCheck',
  [InteractionType.DEACTIVATION]: 'ShieldClose',
};

enum TicketTypeSlugs {
    PRETENSION = 'pretenziia',
    MAINTENANCE = 'soprovozdenie',
}

enum TicketCustomerTypes {
  PRODUCT_PAYPORT_AGENT = 'App\\Models\\ProductPayportAgent',
  PRODUCT_PAYPORT_MERCHANT = 'App\\Models\\ProductPayportMerchant',
  PRODUCT_GNU_VPN_CLIENT = 'App\\Models\\ProductGnuVpnClient',
  USER = 'App\\Models\\User',
  TRADER = 'App\\Models\\Trader',
  TRADER_ADMIN = 'App\\Models\\TraderAdmin',
  SERVICE_PROVIDER = 'App\\Models\\ServiceProvider',
  CLIENT = 'App\\Models\\Client',
  LEAD = 'App\\Models\\Lead',
}

export type {
  ITicketForList,
  ITicketForMassActions,
  ITicket,
  ITicketOtrs,
  IParticipant,
  ITicketUpdateForm,
  ITicketUpdatePartForm,
  ITicketStatus,
  ITicketLinkedTicket,
  ITicketInvoiceOption,
  ITicketInvoice,
  IPreviewComment,
  ISelectableTicketInvoice,
  ITicketInvoiceConfirmProps,
  IImportTicketInvoiceFormData,
};

export {
  IStatus,
  TicketSource,
  TicketTypeSlugs,
  TicketInvoiceParticipantable,
  TicketInvoiceCompensationSideable,
  TicketInvoiceImportStatuses,
  TicketCustomerTypes,
};
