import {ColumnKeys, TrIndexWithTds} from "@/pages/ts/tickets/settings/interfaces";

export class UiTable {
  private readonly headDummy: HTMLElement | undefined
  private readonly bodyDummy: HTMLElement | undefined
  private readonly headTrDummy: HTMLTableRowElement | undefined | null
  private readonly bodyTrDummy: Element | undefined | null

  private readonly table: HTMLTableElement
  private readonly ths: Array<HTMLElement>
  private readonly trIndexesWithTds: TrIndexWithTds

  private readonly tableDummy: HTMLTableElement

  constructor(tableId: string) {
    this.table = document.getElementById(tableId) as HTMLTableElement

    if (!this.table) {
      throw new Error('Table not found')
    }

    this.tableDummy = this.table.cloneNode() as HTMLTableElement

    const tableHead = this.table.getElementsByTagName('thead').item(0)
    const tableBody = this.table.getElementsByTagName('tbody').item(0)

    this.headDummy = tableHead?.cloneNode(false) as HTMLElement
    this.bodyDummy = tableBody?.cloneNode(false) as HTMLElement
    this.headTrDummy = tableHead?.getElementsByTagName('tr').item(0)?.cloneNode(false) as HTMLTableRowElement
    this.bodyTrDummy = tableBody?.getElementsByTagName('tr')?.item(0)?.cloneNode(false) as HTMLElement
    this.ths = Array.from(this.table.getElementsByTagName('th'))
    this.trIndexesWithTds = this.getTrIndexWithTds()

    this.flush()
  }

  public removeCurrentTable(): UiTable {
    this.table.remove()

    return this
  }

  public createByPreference(columnKeys: ColumnKeys): UiTable {
    if (!columnKeys.length) {
      return this
    }

    columnKeys.forEach(columnKey => {
      const thIndex = this.ths.findIndex(node => node.dataset.column === columnKey)
      thIndex !== -1 && this.headTrDummy?.appendChild(this.ths[thIndex])
    })

    const rows = [] as Node[]

    for (const trIndex in this.trIndexesWithTds) {
      const tr = this.bodyTrDummy?.cloneNode(false) as Node

      columnKeys.forEach(columnKey => {
        const tds = Array.from(this.trIndexesWithTds[trIndex].getElementsByTagName('td'))
        const tdIndex = tds.findIndex(node => node.dataset.column === columnKey)

        if(tdIndex !== -1) {
          tr?.appendChild(tds[tdIndex])
        }
      })

      rows.push(tr)
    }

    if (this.headDummy && this.headTrDummy) {
      this.headDummy.appendChild(this.headTrDummy)
    }

    rows.length && this.bodyDummy?.append(...rows)

    this.headDummy && this.tableDummy.append(this.headDummy)
    this.bodyDummy && this.tableDummy.append(this.bodyDummy)

    return this
  }

  public get() {
    return this.tableDummy
  }

  private getTrIndexWithTds(): TrIndexWithTds {
    const result: TrIndexWithTds = {}

    Array
      .from(this.table.querySelectorAll('tbody > tr'))
      .forEach((row, rowKey) => {
        result[rowKey] = row as HTMLElement
      })

    return result
  }

  private flush() {
    this.tableDummy && (this.tableDummy.innerHTML = "")
    this.headDummy && (this.headDummy.innerHTML = "")
    this.bodyDummy && (this.bodyDummy.innerHTML = "")
    this.headTrDummy && (this.headTrDummy.innerHTML = "")
    this.bodyTrDummy && (this.bodyTrDummy.innerHTML = "")
  }
}