import {ColumnKeys, IColumnPreference} from "@/pages/ts/tickets/settings/interfaces";
import {useUserStore} from "@/stores/user";

const TICKET_FILTER_SETTING_DATA = 'ticketFilterSettingData'
const TICKET_SETTING_OF_COLUMNS = 'ticketSettingOfColumns'
const TICKET_PREVIEW = 'ticketPreview'

export function getTicketSettingOfColumns(): string {
  return useUserStore().auth.user.id
    + ':'
    + TICKET_SETTING_OF_COLUMNS
}

export function getTicketFilterSettingData(): string {
  return TICKET_FILTER_SETTING_DATA
}

export function getFilterRoleId() {
  const data = getFilterSettingData()

  if (!data) {
    return null
  }

  return data[0]
}

export function getSettingId() {
  const data = getFilterSettingData()

  if (!data) {
    return null
  }

  return data[1]
}

export function getFilterSettingData(): number[] | null {
  const storageValue = localStorage.getItem(getTicketFilterSettingData())

  if (!storageValue) {
    return null
  }

  return storageValue.split(':').map(Number)
}

export function getTicketSettingOfColumnsValue(): IColumnPreference[] | null {
  const storageValue = localStorage.getItem(getTicketSettingOfColumns())

  if (!storageValue) {
    return null
  }

  return JSON.parse(storageValue)
}
export function getTicketSettingOfColumnsKeys(): ColumnKeys {
  const storageValue = getTicketSettingOfColumnsValue()

  if (!storageValue) {
    return []
  }

  return storageValue.map(item => item.key)
}

export function removeSettingData() {
  localStorage.removeItem(getTicketFilterSettingData())
}

export function savePreviewMode() {
  localStorage.setItem(TICKET_PREVIEW, '1')
}

export function removePreviewMode() {
  localStorage.removeItem(TICKET_PREVIEW)
}

export function isPreviewActivated() {
  return !!localStorage.getItem(TICKET_PREVIEW)
}