
enum IUserStatus {
  Active = 1,
  Not_active = 0
}

interface IRole {
  id: number,
  name: string
}

interface IDepartment {
  id: number,
  name: string,
  pivot: {
    is_manager_of_department: boolean,
  },
}

interface IAllowedDomain {
  id: number,
  domain: string,
  pivot: {
    domain_id: number,
    allowed_domain_id: number,
    allowed_domain_type: string,
  },
  created_at: string,
  updated_at: string,
}

interface IBaseUser {
  name: string,
  middle_name: string,
  last_name: string,
  email: string,
  status: IUserStatus | string,
  phone_country_code: string | null,
  phone_number: string | null,
  time_zone: string,
}

interface IUser extends IBaseUser {
  id: number,
  full_name: string,
  roles: Array<IRole>,
  departments: Array<IDepartment>,
  allowed_domains: Array<IAllowedDomain>,
  created_at: string
}

interface ICreateUserForm extends IBaseUser {
  password: string,
  password_confirmation: string,
  roles: Array<string>,
  department: Array<string>,
  allowed_domains: Array<string>,
}

interface IUpdateUserForm extends IBaseUser {
  roles: Array<string>,
  department: Array<string>,
  allowed_domains: Array<string>,
}

interface IUserValidationBackendError {
  name: Array<string>,
  middle_name: Array<string>,
  last_name: Array<string>,
  password: Array<string>,
  password_confirmation: Array<string>,
  email: Array<string>,
  roles: Array<string>,
  allowed_domains: Array<string>
  status: Array<string>,
  phone_number: Array<string>,
  department: Array<string>
}

interface IUserShort {
  id: number,
  last_name: string,
  name: string,
  middle_name: string,
  email: string,
  full_name: string
  status: IUserStatus | string
}

export type {
  IUserStatus,
  IUser,
  IRole,
  ICreateUserForm,
  IUpdateUserForm,
  IUserValidationBackendError,
  IUserShort
};

export {
  IUserStatus as IUserStatusEnum,
}
