// external imports
import {defineAsyncComponent} from "vue";

// core imports
import {i18n} from "@/utils/i18n";

// docs package imports
import packageI18n from "../../node_modules/@erp-npm-packages/docs/dist/utils/i18n";

// instances
const {t} = i18n.global;
const packageT = packageI18n.global.t;

// init routes method
const initDocsRoutes = () => {
  if (import.meta.env.VITE_DOCS_ENABLED !== '1') {
    return [];
  }

  const DocsSettings = defineAsyncComponent(() => import("../../node_modules/@erp-npm-packages/docs/dist/pages/settings/Index.vue"))
  const DocsPermissions = defineAsyncComponent(() => import("../../node_modules/@erp-npm-packages/docs/dist/pages/permissions/Index.vue"));
  const DocsCreateProject = defineAsyncComponent(() => import("../../node_modules/@erp-npm-packages/docs/dist/pages/projects/Create.vue"));
  const DocsEditProject = defineAsyncComponent(() => import("../../node_modules/@erp-npm-packages/docs/dist/pages/projects/Edit.vue"));
  const DocsShowProject = defineAsyncComponent(() => import("../../node_modules/@erp-npm-packages/docs/dist/pages/projects/Show.vue"));
  const DocsShowDocument = defineAsyncComponent(() => import("../../node_modules/@erp-npm-packages/docs/dist/pages/documents/Show.vue"));
  const DocsCreateDocument = defineAsyncComponent(() => import("../../node_modules/@erp-npm-packages/docs/dist/pages/documents/Create.vue"));
  const DocsShowFile = defineAsyncComponent(() => import("../../node_modules/@erp-npm-packages/docs/dist/pages/files/Show.vue"));
  const DocsIndex = defineAsyncComponent(() => import("../../node_modules/@erp-npm-packages/docs/dist/pages/Index.vue"));

  return [
    {
      path: "/docs",
      meta: {
        requiresAuth: true,
        table: 'docs',
        action: 'index',
        breadcrumb: {
          title: t("docs"),
        },
      },

      children: [
        {
          path: "",
          name: "docs.index",
          component: DocsIndex,
          props: true,
          meta: {
            breadcrumb: {
              title: t("docs"),
            },
          },
        },

        {
          path: "/docs/settings",
          name: "docs.settings",
          component: DocsSettings,
          meta: {
            breadcrumb: {
              title: t("Settings"),
            },
            table: 'docs_settings',
            action: 'index',
          },
        },

        {
          path: "/docs/permissions",
          name: "docs.permissions",
          component: DocsPermissions,
          meta: {
            breadcrumb: {
              title: t("Privileges"),
            },
          },
        },

        {
          path: "/docs/projects/create",
          name: "docs.projects.create",
          component: DocsCreateProject,
          meta: {
            breadcrumb: {
              title: t("New project"),
            },
          },
        },

        {
          path: "/docs/projects/:id/edit",
          name: "docs.projects.edit",
          component: DocsEditProject,
          meta: {
            breadcrumb: {
              title: t("Edit project"),
            },
          },
        },

        {
          path: "/docs/projects/:id",
          name: "docs.projects.show",
          component: DocsShowProject,
          meta: {
            breadcrumb: {
              title: t("docs"),
            },
          },
        },

        {
          path: "/docs/documents/:id",
          name: 'docs.documents.show',
          component: DocsShowDocument,
          props: true,
          meta: {
            breadcrumb: {
              title: t("docs"),
            },
          },
        },

        {
          path: "/docs/documents/create",
          name: 'docs.documents.create',
          component: DocsCreateDocument,
          meta: {
            breadcrumb: {
              title: t("docs_documents_create"),
            },
          },
        },

        {
          path: "/docs/files/:id",
          name: 'docs.files.show',
          component: DocsShowFile,
          props: true,
          meta: {
            breadcrumb: {
              title: '',
            },
          },
        },
      ],
    },
  ]
}

export {initDocsRoutes};
