import {i18n} from "@/utils/i18n";
import {defineAsyncComponent} from "vue";

const {t} = i18n.global;

const initEducationRoutes = () => {
  if (import.meta.env.VITE_EDUCATION_ENABLED !== '1') {
    return [];
  }

  const EducationSettingsCourseList = defineAsyncComponent(() => import("../../node_modules/@erp-npm-packages/education/dist/pages/settings/courses/List.vue"))
  const EducationSettingsCourseForm = defineAsyncComponent(() => import("../../node_modules/@erp-npm-packages/education/dist/pages/settings/courses/Form.vue"))
  const EducationSettingsCourseView = defineAsyncComponent(() => import("../../node_modules/@erp-npm-packages/education/dist/pages/settings/courses/View.vue"))

  const EducationSettingsTestList = defineAsyncComponent(() => import("../../node_modules/@erp-npm-packages/education/dist/pages/settings/tests/List.vue"))
  const EducationSettingsTestForm = defineAsyncComponent(() => import("../../node_modules/@erp-npm-packages/education/dist/pages/settings/tests/Form.vue"))
  const EducationSettingsTestView = defineAsyncComponent(() => import("../../node_modules/@erp-npm-packages/education/dist/pages/settings/tests/View.vue"))

  const EducationReportingList = defineAsyncComponent(() => import("../../node_modules/@erp-npm-packages/education/dist/pages/reporting/List.vue"))
  const EducationSchedulesList = defineAsyncComponent(() => import("../../node_modules/@erp-npm-packages/education/dist/pages/schedule/List.vue"))

  const EducationSettingsArchiveCourseList = defineAsyncComponent(() => import("../../node_modules/@erp-npm-packages/education/dist/pages/settings/archive/courses/List.vue"))
  const EducationSettingsArchiveTestList = defineAsyncComponent(() => import("../../node_modules/@erp-npm-packages/education/dist/pages/settings/archive/tests/List.vue"))

  const EducationSettingsVerificationTestList = defineAsyncComponent(() => import("../../node_modules/@erp-npm-packages/education/dist/pages/settings/verification/tests/List.vue"))

  const EducationSettingsGroupList = defineAsyncComponent(() => import("../../node_modules/@erp-npm-packages/education/dist/pages/settings/groups/List.vue"))
  const EducationSettingsGroupForm = defineAsyncComponent(() => import("../../node_modules/@erp-npm-packages/education/dist/pages/settings/groups/Form.vue"))
  const EducationSettingsGroupView = defineAsyncComponent(() => import("../../node_modules/@erp-npm-packages/education/dist/pages/settings/groups/View.vue"))

  const EducationPassingList = defineAsyncComponent(() => import("../../node_modules/@erp-npm-packages/education/dist/pages/passing/List.vue"))
  const EducationPassingCourseGroup = defineAsyncComponent(() => import("../../node_modules/@erp-npm-packages/education/dist/pages/passing/courses/Group.vue"))
  const EducationPassingCourseView = defineAsyncComponent(() => import("../../node_modules/@erp-npm-packages/education/dist/pages/passing/courses/View.vue"))
  const EducationPassingTestView = defineAsyncComponent(() => import("../../node_modules/@erp-npm-packages/education/dist/pages/passing/tests/View.vue"))

  return [
    {
      path: "education",
      meta: {
        table: 'education_passing',
        action: 'index',
        breadcrumb: {
          title: t("Education"),
        },
      },
      children: [
        {
          path: "",
          name: "education",
          component: EducationPassingList,
        },
        {
          path: "settings",
          redirect: '/education/settings/courses',
          meta: {
            table: 'education_settings',
            action: 'index',
            breadcrumb: {
              title: t("Administration"),
            },
          },
          children: [
            {
              path: "courses",
              redirect: '/education/settings/courses',
              meta: {
                table: 'education_settings',
                action: 'index',
                breadcrumb: {
                  title: t("Courses"),
                },
              },
              children: [
                {
                  path: "",
                  name: "education.settings.courses",
                  component: EducationSettingsCourseList,
                },
                {
                  path: "create",
                  name: "education.settings.courses.create",
                  component: EducationSettingsCourseForm,
                  meta: {
                    table: 'education_settings',
                    action: 'create',
                    breadcrumb: {
                      title: t("Add course"),
                    },
                  },
                },
                {
                  path: "view/:courseId",
                  name: "education.settings.courses.view",
                  component: EducationSettingsCourseView,
                  meta: {
                    table: 'education_settings',
                    action: 'update',
                    breadcrumb: {
                      dynamic: true,
                      idParam: "courseId",
                      crumbApi: "/api/education/course/breadcrumb",
                    },
                  },
                },
              ],
            },
            {
              path: "tests",
              redirect: '/education/settings/tests',
              meta: {
                table: 'education_settings',
                action: 'index',
                breadcrumb: {
                  title: t("Tests"),
                },
              },
              children: [
                {
                  path: "",
                  name: "education.settings.tests",
                  component: EducationSettingsTestList,
                },
                {
                  path: "create",
                  name: "education.settings.tests.create",
                  component: EducationSettingsTestForm,
                  meta: {
                    table: 'education_settings',
                    action: 'create',
                    breadcrumb: {
                      title: t("Add test"),
                    },
                  },
                },
                {
                  path: "view/:testId",
                  name: "education.settings.tests.view",
                  component: EducationSettingsTestView,
                  meta: {
                    table: 'education_settings',
                    action: 'update',
                    breadcrumb: {
                      dynamic: true,
                      idParam: "testId",
                      crumbApi: "/api/education/test/breadcrumb",
                    },
                  },
                },
              ],
            },
            {
              path: "groups",
              redirect: '/education/settings/groups',
              meta: {
                table: 'education_settings',
                action: 'index',
                breadcrumb: {
                  title: t("Groups of courses and tests"),
                },
              },
              children: [
                {
                  path: "",
                  name: "education.settings.groups",
                  component: EducationSettingsGroupList,
                },
                {
                  path: "create",
                  name: "education.settings.groups.create",
                  component: EducationSettingsGroupForm,
                  meta: {
                    table: 'education_settings',
                    action: 'create',
                    breadcrumb: {
                      title: t("Add group"),
                    },
                  },
                },
                {
                  path: "view/:groupId",
                  name: "education.settings.groups.view",
                  component: EducationSettingsGroupView,
                  meta: {
                    table: 'education_settings',
                    action: 'update',
                    breadcrumb: {
                      dynamic: true,
                      idParam: "groupId",
                      crumbApi: "/api/education/group/breadcrumb",
                    },
                  },
                },
              ],
            },
            {
              path: "verification",
              redirect: '/education/settings/verification/tests',
              meta: {
                table: 'education_settings',
                action: 'index',
                breadcrumb: {
                  title: t("Verification tests"),
                },
              },
              children: [
                {
                  path: "tests",
                  name: "education.settings.verification.tests",
                  component: EducationSettingsVerificationTestList,
                },
              ],
            },
            {
              path: "archive",
              redirect: '/education/settings/archive/courses',
              meta: {
                table: 'education_settings',
                action: 'index',
                breadcrumb: {
                  title: t("Archive"),
                },
              },
              children: [
                {
                  path: "courses",
                  redirect: '/education/settings/archive/courses',
                  meta: {
                    table: 'education_settings',
                    action: 'index',
                    breadcrumb: {
                      title: t("Courses"),
                    },
                  },
                  children: [
                    {
                      path: "",
                      name: "education.settings.archive.courses",
                      component: EducationSettingsArchiveCourseList,
                    },
                    {
                      path: "view/:courseId",
                      name: "education.settings.archive.courses.view",
                      component: EducationSettingsCourseView,
                      meta: {
                        table: 'education_settings',
                        action: 'update',
                        breadcrumb: {
                          dynamic: true,
                          idParam: "courseId",
                          crumbApi: "/api/education/course/breadcrumb",
                        },
                      },
                    },
                  ],
                },
                {
                  path: "tests",
                  redirect: '/education/settings/archive/tests',
                  meta: {
                    table: 'education_settings',
                    action: 'index',
                    breadcrumb: {
                      title: t("Tests"),
                    },
                  },
                  children: [
                    {
                      path: "",
                      name: "education.settings.archive.tests",
                      component: EducationSettingsArchiveTestList,
                    },
                    {
                      path: "view/:testId",
                      name: "education.settings.archive.tests.view",
                      component: EducationSettingsTestView,
                      meta: {
                        table: 'education_settings',
                        action: 'update',
                        breadcrumb: {
                          dynamic: true,
                          idParam: "testId",
                          crumbApi: "/api/education/test/breadcrumb",
                        },
                      },
                    },
                  ],
                },
              ],
            },
          ],
        },
        {
          path: "reporting",
          name: "education.reporting",
          component: EducationReportingList,
          meta: {
            table: 'education_reporting',
            action: 'index',
            breadcrumb: {
              title: t("Reporting"),
            },
          },
        },
        {
          path: "schedule",
          name: "education.schedule",
          component: EducationSchedulesList,
          meta: {
            table: 'education_schedule',
            action: 'index',
            breadcrumb: {
              title: t("Schedule"),
            },
          },
        },
        {
          path: "passing",
          children: [
            {
              path: "courses",
              children: [
                {
                  path: "group/:coursePassingId",
                  name: "education.passing.course.group",
                  component: EducationPassingCourseGroup,
                },
                {
                  path: "view/:coursePassingId",
                  name: "education.passing.courses.view",
                  component: EducationPassingCourseView,
                  meta: {
                    table: 'education_passing',
                    action: 'index',
                    breadcrumb: {
                      dynamic: true,
                      idParam: "coursePassingId",
                      crumbApi: "/api/education/course/passing-breadcrumb",
                    },
                  },
                },
              ],
            },
            {
              path: "tests",
              children: [
                {
                  path: "view/:testPassingId",
                  name: "education.passing.tests.view",
                  component: EducationPassingTestView,
                  meta: {
                    table: 'education_passing',
                    action: 'index',
                    breadcrumb: {
                      dynamic: true,
                      idParam: "testPassingId",
                      crumbApi: "/api/education/test/passing-breadcrumb",
                    },
                  },
                },
              ],
            },
          ],
        },
      ],
    },
  ]
}

export {initEducationRoutes};
