import { createRouter, createWebHistory, LocationQuery, RouteRecord } from "vue-router";
import { useUserStore } from "../stores/user";
import { useBreadcrumbsStore } from "@/stores/breadcrumbs";
import SideMenu from "../layouts/SideMenu/SideMenu.vue";
import SimpleMenu from "../layouts/SimpleMenu/SimpleMenu.vue";
import TopMenu from "../layouts/TopMenu/TopMenu.vue";
import { i18n } from "@/utils/i18n";
import { ProductType } from "@/pages/products/interfaces";
import 'vue-router'
import {IStatus} from "@/pages/ts/tickets/interfaces";
import {useFilterPresetStore} from "@/stores/ts/filter_preset";
import {IQueueStatus} from "@/pages/ts/queues/interfaces";
import {
  getSettingId, isPreviewActivated,
  removeSettingData
} from "@/pages/ts/tickets/settings/utils";
import {
  getSettingId as getSettingIdDashboard,
  removeSettingData as removeSettingDataDashboard,
} from "@/pages/dashboard/settings/utils";
import {initDocsRoutes} from "./docs";
import {initEducationRoutes} from "./education";
import { initTagsRoutes } from "./tags";
import {getErpPackageRoutes} from "@/utils/erp-integration/resolver";

const docsRoutes = initDocsRoutes();
const educationRoutes = initEducationRoutes();
const tagsRoutes = initTagsRoutes();

const erpPackageRoutes: RouteRecord[] = getErpPackageRoutes();

const { t } = i18n.global;

const routes = [
  {
    path: "/",
    name: 'home',
    component: SideMenu,
    children: [
      {
        path: "/",
        name: "dashboard",
        component: () => import("@/pages/Dashboard.vue"),
      },
      {
        path: "/create_widget",
        name: "dashboard.create_widget",
        component: () => import("@/pages/dashboard/widgets/CreateWidget.vue"),
      },
      {
        path: "/edit_dashboard/:dashboard_id",
        name: "dashboard.edit",
        component: () => import("@/pages/dashboard/widgets/DashboardEdit.vue"),
      },
      {
        path: "/manage_dashboards/",
        name: "dashboards",
        children: [
          {
            path: "",
            meta: {
              table: 'dashboard',
              action: 'index',
              breadcrumb: {
                title: t("Manage dashboards"),
              },

            },
            children: [
              {
                path: "",
                children: [
                  {
                    path: "",
                    name: "dashboards.list",
                    meta: {
                      breadcrumb: {
                        title: t("Personal dashboards"),
                      },
                    },
                    children: [
                      {
                        path: "",
                        name: "dashboards.list.personal",
                        component: () => import("@/pages/dashboard/manage/ListPersonal.vue"),
                      },
                      {
                        path: "create/:type",
                        name: "dashboards.list.create_personal",
                        component: () => import("@/pages/dashboard/widgets/DashboardCreate.vue"),
                        props: true,
                        meta: {
                          breadcrumb: {
                            title: t("Add new dashboard"),
                          },
                        }
                      },
                      {
                        path: "edit/:dashboard_id",
                        name: "dashboards.list.edit_personal",
                        component: () => import("@/pages/dashboard/widgets/DashboardEdit.vue"),
                        meta: {
                          breadcrumb: {
                            title: t("Edit dashboard"),
                          },
                        }
                      },
                    ]
                  },
                  {
                    path: "roles",
                    meta: {
                      table: "dashboard_attach_role",
                      action: "index",
                      breadcrumb: {
                        title: t("Attach role to dashboard"),
                      },
                    },
                    children: [
                      {
                        path: "",
                        name: "dashboards.list.roles",
                        component: () => import("@/pages/dashboard/manage/ListRoles.vue"),
                      },
                      {
                        path: "create/:type/:new",
                        name: "dashboards.list.create_role",
                        component: () => import("@/pages/dashboard/widgets/DashboardCreate.vue"),
                        props:true,

                        meta: {
                          table: 'dashboard_attach_role',
                          action: 'index',
                          breadcrumb: {
                            title: t("Add new dashboard"),
                          },
                        }
                      },
                      {
                        path: "/manage_dashboards/attach_role/:dashboard_id",
                        name: "dashboards.list.attach_role",
                        meta: {
                          table: "dashboard_attach_role",
                          action: "update",
                          breadcrumb: {
                            title: t("Attach to role"),
                          },
                        },
                        component: () => import("@/pages/dashboard/widgets/DashboardEdit.vue"),
                      },
                    ]
                  },
                  {
                    path: "public_widgets",
                    meta: {
                      table: "dashboard_attach_role",
                      action: "index",
                      breadcrumb: {
                        title: t("Public widgets"),
                      },
                    },
                    children: [
                      {
                        path: "",
                        name: "dashboards.list.public_widgets",
                        component: () => import("@/pages/dashboard/manage/ListPublicWidgets.vue"),
                      },
                      {
                        path: "/manage_dashboards/public_widgets/:widget_id",
                        name: "dashboards.list.public_widgets.edit",
                        meta: {
                          table: "dashboard_attach_role",
                          action: "update",
                          breadcrumb: {
                            title: t("Edit widget"),
                          },
                        },
                        component: () => import("@/pages/dashboard/widgets/WidgetEdit.vue"),
                      },
                    ]
                  },
                  {
                    path: "personal_widgets",
                    meta: {
                      breadcrumb: {
                        title: t("Personal widgets"),
                      },
                    },
                    children: [
                      {
                        path: "",
                        name: "dashboards.list.personal_widgets",
                        component: () => import("@/pages/dashboard/manage/ListPersonalWidgets.vue"),
                      },
                      {
                        path: "/manage_dashboards/personal_widgets/:widget_id",
                        name: "dashboards.list.personal_widgets.edit",
                        meta: {
                          breadcrumb: {
                            title: t("Edit widget"),
                          },
                        },
                        component: () => import("@/pages/dashboard/widgets/WidgetEdit.vue"),
                      },
                    ]
                  }

                ]
              },
            ]
          },

        ]
      },


      {
        path: "/edit_widget/:widget_id/:dashboard_id",
        name: "dashboard.widget.edit",
        component: () => import("@/pages/dashboard/widgets/WidgetEdit.vue"),
      },
      {
        path: "profile",
        name: "profile",
        component: () => import("@/pages/users/user/tabs/profile/Profile.vue"),
        meta: {
          breadcrumb: {
            title: t("User profile"),
          }
        }
      },
      {
        path: "users",
        name: 'users',
        children: [
          {
            path: "",
            name: "user-list",
            component: () => import("@/pages/users/UserList.vue"),
            meta: {
              table: 'users',
              action: 'index',
            }
          },
          {
            path: "create",
            name: "user-create",
            component: () => import("@/pages/users/user/UserForm.vue"),
            meta: {
              table: 'users',
              action: 'create',
              breadcrumb: {
                title: t("Add user"),
              },
            }
          },
          {
            path: ":userId",
            component: () => import("@/pages/users/user/User.vue"),
            children: [
              {
                path: "",
                name: "user-profile",
                component: () => import("@/pages/users/user/tabs/profile/Profile.vue"),
                meta: {
                  table: 'users',
                  action: 'show',
                  breadcrumb: {
                    title: t("User profile"),
                  }
                }
              },
              {
                path: "changelog",
                name: "user-changelog",
                component: () => import("@/pages/users/user/tabs/changeLog/ChangeLog.vue"),
                props: true,
                meta: {
                  table: 'user_change_logs',
                  action: 'index',
                  breadcrumb: {
                    title: t("Change history"),
                  },
                },
              },
            ],
            meta: {
              table: 'users',
              action: 'show',
              breadcrumb: {
                dynamic: true,
                idParam: "userId",
                crumbApi: "/api/users/breadcrumb",
              }
            },
          },
          {
            path: "password-reset",
            name: "user-password-reset",
            component: () => import("@/pages/users/PasswordResetForm.vue"),
            meta: {
              breadcrumb: {
                title: t("Reset Password"),
              },
            },
          },
          {
            path: "edit/:userId",
            name: "user-edit",
            component: () => import("@/pages/users/user/UserForm.vue"),
            meta: {
              table: 'users',
              action: 'update',
              breadcrumb: {
                title: t("Edit user")
              }
            }
          },
        ],
        meta: {
          breadcrumb: {
            title: t("Users2"),
          }
        }
      },
      {
        path: "/traders",
        children: [
          {
            path: "",
            name: "trader.list",
            component: () => import("@/pages/traders/List.vue"),
            meta: {
              table: 'traders',
              action: 'index',
            }
          },
          {
            path: ":traderId",
            component: () => import("@/pages/traders/TraderProfile.vue"),
            children: [
              {
                path: "transactions",
                name: "traders.transactions",
                component: () => import("@/pages/traders/tabs/transactions/Transactions.vue"),
                props: true,
                meta: {
                  table: 'trader_transactions',
                  action: 'index',
                  breadcrumb: {
                    title: t("Transactions"),
                  },
                },
              },
              {
                path: "adverts",
                name: "traders.adverts",
                component: () => import("@/pages/traders/tabs/ad/Adverts.vue"),
                props: true,
                meta: {
                  breadcrumb: {
                    title: t("Adverts"),
                  },
                },
              },
              {
                path: "cash-flow-statement",
                name: "traders.cash.flow.statement",
                component: () => import("@/pages/traders/tabs/cashFlowStatement/CashFlowStatement.vue"),
                props: true,
                meta: {
                  table: 'trader_inputs',
                  action: 'index',
                  breadcrumb: {
                    title: t("Cash flow statement"),
                  },
                },
              },
              {
                path: "financial-indicators",
                name: "traders.financial.indicators",
                component: () => import("@/pages/traders/tabs/financialIndicators/FinancialIndicators.vue"),
                props: true,
                meta: {
                  table: 'trader_financial_indicators',
                  action: 'index',
                  breadcrumb: {
                    title: t("Financial indicators"),
                  },
                },
              },
              {
                path: "merchants",
                name: "traders.merchants",
                component: () => import("@/pages/traders/tabs/merchants/Merchants.vue"),
                props: true,
                meta: {
                  breadcrumb: {
                    title: t("Merchants"),
                  },
                },
              },
              {
                path: "otrs",
                name: "traders.otrs",
                component: () => import("@/pages/traders/tabs/otrs/Otrs.vue"),
                props: true,
              },
              {
                path: "crmts",
                name: "traders.crmts",
                component: () => import("@/pages/traders/tabs/crmts/Crmts.vue"),
                props: true,
                meta: {
                  breadcrumb: {
                    title: t("ts.Tickets"),
                  },
                },
              },
              {
                path: "",
                name: "traders.profile",
                component: () => import("@/pages/traders/tabs/mainInfo/MainInfo.vue"),
                props: true,
                meta: {
                  breadcrumb: {
                    title: t("Main info"),
                  },
                },
              },
              {
                path: "contacts",
                name: "traders.contacts",
                component: () => import("@/pages/general/Contacts.vue"),
                props: true,
                meta: {
                  breadcrumb: {
                    title: t("Contacts"),
                  },
                  blockName: "CONTACTS"
                },
              },
              {
                path: "documents",
                name: "traders.documents",
                component: () => import("@/pages/traders/tabs/documents/Documents.vue"),
                props: true,
                meta: {
                  table: 'trader_documents',
                  action: 'index',
                  breadcrumb: {
                    title: t("Documents"),
                  },
                  blockName: "DOCUMENTS",
                },
              },
              {
                path: "changelog",
                name: "traders.changelog",
                component: () => import("@/pages/traders/tabs/changeLog/ChangeLog.vue"),
                props: true,
                meta: {
                  breadcrumb: {
                    title: t("Change history"),
                  },
                },
              },
            ],
            meta: {
              table: 'traders',
              action: 'show',
              breadcrumb: {
                dynamic: true,
                idParam: "traderId",
                crumbApi: "/api/traders/breadcrumb",
              }
            }
          },
          {
            path: "create",
            name: "traders.create",
            component: () => import("@/pages/traders/TraderForm.vue"),
            meta: {
              table: 'traders',
              action: 'create',
              breadcrumb: {
                title: t("Add trader"),
              },
            },
          },
          {
            path: "edit/:traderId",
            name: "traders.edit",
            component: () => import("@/pages/traders/TraderForm.vue"),
            meta: {
              table: 'traders',
              action: 'update',
              breadcrumb: {
                title: t("Edit trader"),
              },
            },
          },
        ],
        meta: {
          breadcrumb: {
            title: t("Traders"),
          }
        }
      },
      {
        path: "/trader-admins",
        children: [
          {
            path: "",
            name: "trader-admins.list",
            component: () => import("@/pages/trader-admins/List.vue"),
            meta: {
              table: 'trader_admins',
              action: 'index',
            }
          },
          {
            path: "create",
            name: "trader_admins.create",
            component: () => import("@/pages/trader-admins/TraderAdminForm.vue"),
            meta: {
              table: 'trader_admins',
              action: 'create',
              breadcrumb: {
                title: t("Add trader admin"),
              },
            },
          },
          {
            path: "edit/:traderAdminId",
            name: "trader_admins.edit",
            component: () => import("@/pages/trader-admins/TraderAdminForm.vue"),
            meta: {
              table: 'trader_admins',
              action: 'update',
              breadcrumb: {
                title: t("Edit trader admin"),
              },
            },
          },
        ],
        meta: {
          breadcrumb: {
            title: t("Trader Admins"),
          }
        }
      },
      {
        path: "/service-providers",
        children: [
          {
            path: "",
            name: "service-providers.list",
            component: () => import("@/pages/service_providers/List.vue"),
            meta: {
              table: 'service_providers',
              action: 'index',
            }
          },
          {
            path: ":spId",
            component: () => import("@/pages/service_providers/ServiceProviderProfile.vue"),
            children: [
              {
                path: "",
                name: "service-providers.profile",
                component: () => import("@/pages/service_providers/tabs/mainInfo/MainInfo.vue"),
                props: true,
                meta: {
                  breadcrumb: {
                    title: t("Main info"),
                  },
                },
              },
              {
                path: "transactions",
                name: "service-providers.transactions",
                component: () => import("@/pages/service_providers/tabs/transactions/Transactions.vue"),
                props: true,
                meta: {
                  table: 'service_provider_transactions',
                  action: 'index',
                  breadcrumb: {
                    title: t("Transactions"),
                  },
                },
              },
              {
                path: "financial-indicators",
                name: "service-providers.financial-indicators",
                component: () => import("@/pages/service_providers/tabs/financialIndicators/FinancialIndicators.vue"),
                props: true,
                meta: {
                  table: 'service_provider_financial_indicators',
                  action: 'index',
                  breadcrumb: {
                    title: t("Financial indicators"),
                  },
                },
              },
              {
                path: "traders",
                name: "service-providers.traders",
                component: () => import("@/pages/service_providers/tabs/traders/Traders.vue"),
                props: true,
                meta: {
                  breadcrumb: {
                    title: t("Traders"),
                  },
                },
              },
              {
                path: "merchants",
                name: "service-providers.merchants",
                component: () => import("@/pages/service_providers/tabs/merchants/Merchants.vue"),
                props: true,
                meta: {
                  breadcrumb: {
                    title: t("Merchants"),
                  },
                },
              },
              {
                path: "crmts",
                name: "service-providers.crmts",
                component: () => import("@/pages/traders/tabs/crmts/Crmts.vue"),
                props: true,
                meta: {
                  breadcrumb: {
                    title: t("ts.Tickets"),
                  },
                },
              },
              {
                path: "contacts",
                name: "service-providers.contacts",
                component: () => import("@/pages/general/Contacts.vue"),
                props: true,
                meta: {
                  breadcrumb: {
                    title: t("Contacts"),
                  },
                  blockName: "CONTACTS"
                },
              },
              {
                path: "documents",
                name: "service-providers.documents",
                component: () => import("@/pages/service_providers/tabs/documents/Documents.vue"),
                props: true,
                meta: {
                  table: 'service_provider_documents',
                  action: 'index',
                  breadcrumb: {
                    title: t("Documents"),
                  },
                  blockName: "DOCUMENTS",
                },
              },
              {
                path: "changelog",
                name: "service-providers.changelog",
                component: () => import("@/pages/service_providers/tabs/changeLog/ChangeLog.vue"),
                props: true,
                meta: {
                  breadcrumb: {
                    title: t("Change history"),
                  },
                },
              },
            ],
            meta: {
              table: 'service_providers',
              action: 'show',
              breadcrumb: {
                dynamic: true,
                idParam: "spId",
                crumbApi: "/api/service-providers/breadcrumb",
              }
            },
          },
          {
            path: "create",
            name: "service-providers.create",
            component: () => import("@/pages/service_providers/ServiceProviderForm.vue"),
            meta: {
              table: 'service_providers',
              action: 'create',
              breadcrumb: {
                title: t("Add service provider"),
              },
            },
          },
          {
            path: "edit/:spId",
            name: "service-providers.edit",
            component: () => import("@/pages/service_providers/ServiceProviderForm.vue"),
            meta: {
              table: 'service_providers',
              action: 'update',
              breadcrumb: {
                title: t("Edit service provider"),
              },
            },
          },
        ],
        meta: {
          breadcrumb: {
            title: t("Service providers"),
          }
        }
      },
      {
        path: "/departments",
        children: [
          {
            path: "",
            name: "department.list",
            component: () => import("@/pages/departments/DepartmentsDataList.vue"),
            props: (route: LocationQuery) => ({ query: route.query }),
            meta: {
              table: 'departments',
              action: 'index',
            }
          },
          {
            path: "create",
            name: "department.create",
            component: () => import("@/pages/departments/Form.vue"),
            meta: {
              table: 'departments',
              action: 'create',
              breadcrumb: {
                title: t("Add Department"),
              }
            }
          },
          {
            path: "edit/:id",
            name: "department.edit",
            component: () => import("@/pages/departments/Form.vue"),
            props: true,
            meta: {
              table: 'departments',
              action: 'update',
              breadcrumb: {
                title: t("Edit Department"),
              },
            },
          },
          {
            path: "view/:id",
            meta: {
              breadcrumb: {
                dynamic: true,
                idParam: "id",
                crumbApi: "/api/departments/breadcrumb",
              }
            },
            children: [
              {
                path: "",
                name: "department.view",
                component: () => import("@/pages/departments/View.vue"),
                props: true,
                meta: {
                  table: 'departments',
                  action: 'show'
                },
              },
              {
                path: "grade",
                meta: {
                  breadcrumb: {
                    title: t('Department grade'),
                    table: 'department-grades',
                    action: 'index',
                  },
                },
                children: [
                  {
                    path: "",
                    name: "department.grade",
                    component: () => import("@/pages/departments/grades/DepartmentGradeList.vue"),
                  },
                  {
                    path: "create",
                    name: "department.grade.create",
                    component: () => import("@/pages/departments/grades/Form.vue"),
                  },
                  {
                    path: ":gradeId(\\d+)",
                    name: "department.grade.edit",
                    component: () => import("@/pages/departments/grades/Form.vue"),
                    meta: {
                      breadcrumb: {
                        title: t('Grade edit'),
                        table: 'department-grades',
                        action: 'edit',
                      },
                    }
                  },
                  {
                    path: ":period",
                    name: "department.grade.period",
                    component: () => import("@/pages/departments/grades/DepartmentGradeByPeriod.vue"),
                    meta: {
                      breadcrumb: {
                        dynamic: true,
                        idParam: 'period',
                        crumbApi: "api/department-grades/breadcrumbs",
                        table: 'department-grades',
                        action: 'period'
                      },
                    }
                  },
                ]
              },
            ]
          },
        ],
        meta: {
          breadcrumb: {
            title: t("Departments"),
          },
        },
      },
      {
        path: "/roles",
        children: [
          {
            path: "",
            name: "roles.list",
            component: () => import("@/pages/roles/List.vue"),
            props: (route: LocationQuery) => ({ query: route.query }),
            meta: {
              table: 'roles',
              action: 'index',
            }
          },
          {
            path: "create",
            name: "roles.create",
            component: () => import("@/pages/roles/Form.vue"),
            meta: {
              table: 'roles',
              action: 'create',
              breadcrumb: {
                title: t("Add New Role"),
              },
            }
          },
          {
            path: "edit/:id",
            name: "roles.edit",
            component: () => import("@/pages/roles/Form.vue"),
            props: true,
            meta: {
              table: 'roles',
              action: 'update',
              breadcrumb: {
                title: t("Edit Role"),
              },
            }
          },
        ],
        meta: {
          breadcrumb: {
            title: t("Roles"),
          }
        }
      },
      {
        path: "/general-settings",
        children: [
          {
            path: "",
            name: "general_settings.index",
            component: () => import("@/pages/general_settings/GeneralSettings.vue"),
            props: true,
            meta: {
              table: 'general_settings',
              action: 'index',
            }
          },
        ],
        meta: {
          breadcrumb: {
            title: t("General settings"),
          },
        },
      },
      {
        path: "/permissions",
        component: () => import("@/pages/permissions/Permissions.vue"),
        children: [
          {
            path: "edit",
            name: "permissions.edit",
            component: () => import("@/pages/permissions/tabs/settings/Settings.vue"),
            props: true,
            meta: {
              table: 'access_settings',
              action: 'index',
              breadcrumb: {
                title: t("Privileges"),
              },
            }
          },
          {
            path: "changelog",
            name: "permissions.changelog",
            component: () => import("@/pages/permissions/tabs/changeLog/ChangeLog.vue"),
            props: true,
            meta: {
              breadcrumb: {
                title: t("Change history"),
              },
            },
          },
        ],
        meta: {
          breadcrumb: {
            title: t("Privileges"),
          },
        },
      },
      {
        path: "/contact-persons",
        children: [
          {
            path: "",
            name: "contact.person.list",
            component: () => import("@/pages/contact_persons/List.vue"),
            meta: {
              table: 'contact_persons',
              action: 'index',
            },
          },
          {
            path: "create",
            name: "contact.person.create",
            component: () => import("@/pages/contact_persons/ContactPersonForm.vue"),
            meta: {
              table: 'contact_persons',
              action: 'create',
              breadcrumb: {
                title: t("Add Contact"),
              }
            },
          },
          {
            path: "",
            name: "contact.person.edit",
            component: () => import("@/pages/contact_persons/MainForm.vue"),
            props: true,
            meta: {
              table: 'contact_persons',
              action: 'update',
              breadcrumb: {
                title: t("Edit Contact"),
              },
            },
            children: [
              {
                path: "edit/:id/clients",
                name: "contact.person.edit.clients",
                component: () => import("@/pages/contact_persons/ClientList.vue"),
                meta: {
                  breadcrumb: {
                    title: t("Clients"),
                  },
                },
              },
              {
                path: "edit/:id/leads",
                name: "contact.person.edit.leads",
                component: () => import("@/pages/contact_persons/LeadList.vue"),
                meta: {
                  breadcrumb: {
                    title: t("Leads"),
                  },
                },
              },
              {
                path: "edit/:id/log",
                name: "contact.person.edit.log",
                component: () => import("@/pages/contact_persons/Log.vue"),
                meta: {
                  breadcrumb: {
                    title: t("Change history"),
                  },
                },
              },
            ]
          },
        ],
        meta: {
          breadcrumb: {
            title: t("Contacts"),
          }
        }
      },
      {
        path: "/countries",
        children: [
          {
            path: "",
            name: "country.list",
            component: () => import("@/pages/countries/CountryList.vue"),
            meta: {
              table: 'countries',
              action: 'index',
            },
          },
          {
            path: "create",
            name: "country.create",
            component: () => import("@/pages/countries/CountryForm.vue"),
            meta: {
              table: 'countries',
              action: 'create',
              breadcrumb: {
                title: t("Add country")
              }
            },
          },
          {
            path: "edit/:countryId",
            name: "country.edit",
            component: () => import("@/pages/countries/CountryForm.vue"),
            meta: {
              table: 'countries',
              action: 'update',
              breadcrumb: {
                title: t("Edit country"),
              },
            },
          },
        ],
        meta: {
          breadcrumb: {
            title: t("Countries2"),
          },
        },
      },
      {
        path: "/domains",
        children: [
          {
            path: "",
            name: "domain.list",
            component: () => import("@/pages/domains/DomainList.vue"),
            meta: {
              table: 'domains',
              action: 'index',
            },
          },
          {
            path: "create",
            name: "domain.create",
            component: () => import("@/pages/domains/DomainForm.vue"),
            meta: {
              table: 'domains',
              action: 'create',
              breadcrumb: {
                title: t("Add domain")
              }
            },
          },
          {
            path: "edit/:domainId",
            name: "domain.edit",
            component: () => import("@/pages/domains/DomainForm.vue"),
            meta: {
              table: 'domains',
              action: 'update',
              breadcrumb: {
                title: t("Edit domain"),
              },
            },
          },
        ],
        meta: {
          breadcrumb: {
            title: t("Domains"),
          },
        },
      },
      {
        path: "/favorites",
        children: [
          {
            path: "",
            name: "favorites.list",
            component: () => import("@/pages/favorites/List.vue"),
          },
        ],
        meta: {
          table: "favorites",
          action: "index",
          breadcrumb: {
            title: t("Favorites"),
          }
        }
      },
      {
        path: "/notification-types",
        children: [
          {
            path: "",
            name: "notificationTypes.list",
            component: () => import("@/pages/notification_system/notification_types/NotificationTypes.vue"),
          },
          {
            path: "create",
            name: "notificationTypes.create",
            component: () => import("@/pages/notification_system/notification_types/Form.vue"),
            meta: {
              breadcrumb: {
                title: t("Notification type creation"),
              },
              table: "notification_types",
              action: "create",
            }
          },
          {
            path: "edit/:id",
            name: "notificationTypes.edit",
            component: () => import("@/pages/notification_system/notification_types/Form.vue"),
            meta: {
              breadcrumb: {
                title: t("Notification type edit"),
              },
              table: "notification_types",
              action: "update",
            }
          }
        ],
        meta: {
          breadcrumb: {
            title: t("Notification types"),
          },
          table: "notification_types",
          action: "index",
        },
      },
      {
        path: "/notification-management",
        children: [
          {
            path: "",
            name: "notificationManagement.list",
            component: () => import("@/pages/notification_system/notification_management/NotificationManagement.vue")
          },
          {
            path: "create",
            name: "notificationManagement.create",
            component: () => import("@/pages/notification_system/notification_management/Form.vue"),
            meta: {
              breadcrumb: {
                title: t("Notification creation"),
              },
              table: "notification_schedule",
              action: "create",
            }
          },
          {
            path: "edit/:id",
            name: "notificationManagement.edit",
            component: () => import("@/pages/notification_system/notification_management/Form.vue"),
            meta: {
              breadcrumb: {
                title: t("Notification edit"),
              },
              table: "notification_schedule",
              action: "update",
            }
          }
        ],
        meta: {
          breadcrumb: {
            title: t("Notification management"),
          },
          table: "notification_schedule",
          action: "index",
        }
      },
      {
        path: "coefficients",
        children: [
          {
            path: "",
            name: "coefficients.index",
            component: () => import("@/pages/coefficients/List.vue"),
          },
          {
            path: ":id/edit",
            name: "coefficients.edit",
            component: () => import("@/pages/coefficients/EditForm.vue"),
            props: true,
            meta: {
              breadcrumb: {
                title: t("coefficientss.Edit"),
              },
            },
          },
          {
            path: "create",
            name: "coefficients.create",
            component: () => import("@/pages/coefficients/EditForm.vue"),
            meta: {
              breadcrumb: {
                title: t("coefficientss.Create"),
              },
            },
          },
        ],
        meta: {
          table: "coefficients",
          action: "index",
          breadcrumb: {
            title: t("Coefficients"),
          },
        },
      },
      {
        path: "criticality",
        children: [
          {
            path: "",
            name: "criticality.index",
            component: () => import("@/pages/criticality/List.vue"),
          },
          {
            path: ":id/edit",
            name: "criticality.edit",
            component: () => import("@/pages/criticality/EditForm.vue"),
            props: true,
            meta: {
              breadcrumb: {
                title: t("criticalitys.Edit"),
              },
            },
          },
          {
            path: "create",
            name: "criticality.create",
            component: () => import("@/pages/criticality/EditForm.vue"),
            meta: {
              breadcrumb: {
                title: t("criticalitys.Create"),
              },
            },
          },
        ],
        meta: {
          table: "criticality",
          action: "index",
          breadcrumb: {
            title: t("Criticality"),
          },
        },
      },
      {
        path: "calendar_colors",
        children: [
          {
            path: "",
            name: "calendar_colors.index",
            component: () => import("@/pages/calendar_colors/List.vue"),
          },
        ],
        meta: {
          table: "calendar_colors",
          action: "index",
          breadcrumb: {
            title: t("calendar.Colors dict"),
          },
        },
      },
      {
        path: "product_assignments",
        children: [
          {
            path: "",
            name: "product_assignments.index",
            component: () => import("@/pages/product_assignments/List.vue"),
          },
          {
            path: "add_status",
            name: "product_assignments.add",
            component: () => import("@/pages/product_assignments/ProductStatusCreate.vue"),
            props: true,
            meta:{
              breadcrumb: {
                title: t("Add New Assignment"),
              },
            }
          },
          {
            path: ":id/edit",
            name: "product_assignments.edit",
            component: () => import("@/pages/product_assignments/EditForm.vue"),
            props: true,
            meta: {
              breadcrumb: {
                title: t("Edit Assignment"),
              },
            },
          },
          {
            path: ":id",
            name: "product_assignments.show",
            component: () => import("@/pages/product_assignments/ShowForm.vue"),
            props: true,
            meta: {
              breadcrumb: {
                title: t("Show Status"),
              },
            },
          },
        ],
        meta: {
          table: "references",
          action: "index",
          breadcrumb: {
            title: t("Product assignments dict"),
          },
        },
      },
      {
        path: "/sales_channels",
        children: [
          {
            path: "",
            name: "salesChannel.list",
            component: () => import("@/pages/sales_channels/SalesChannelsList.vue")
          },
          {
            path: "create",
            name: "salesChannel.create",
            component: () => import("@/pages/sales_channels/SalesChannelsForm.vue"),
            meta: {
              table: "sales_channels",
              action: "create",
              breadcrumb: {
                title: t("Add sales channel"),
              }
            }
          },
          {
            path: "edit/:salesChannelId",
            name: "salesChannel.edit",
            component: () => import("@/pages/sales_channels/SalesChannelsForm.vue"),
            meta: {
              table: "sales_channels",
              action: "update",
              breadcrumb: {
                title: t("Edit sales channel"),
              },
            },
          },
        ],
        meta: {
          table: "sales_channels",
          action: "index",
          breadcrumb: {
            title: t("Sales channels"),
          },
        },
      },
      {
        path: "/clients",
        children: [
          {
            path: "",
            name: "clients.list",
            component: () => import("@/pages/clients/ClientList.vue"),
            meta: {
              table: 'clients',
              action: 'index',
            }
          },
          {
            path: ":clientId",
            component: () => import("@/pages/clients/ClientProfile/ClientProfile.vue"),
            children: [
              {
                path: "",
                name: "clients.profile",
                component: () => import("@/pages/clients/ClientProfile/ClientInfo.vue"),
                props: true,
                meta: {
                  blockName: "INFO",
                },
              },
              {
                path: "contacts",
                name: "clients.contacts",
                component: () => import("@/pages/general/Contacts.vue"),
                props: true,
                meta: {
                  breadcrumb: {
                    title: t("Contacts"),
                  },
                  blockName: "CONTACTS"
                },
              },
              {
                path: "products",
                name: "clients.products",
                component: () => import("@/pages/products/ClientProducts.vue"),
                props: true,
                children: [
                  {
                    path: "add_product",
                    name: "clients.products.add",
                    component: () => import("@/pages/products/ProductForm.vue"),
                    props: true,
                  },
                  {
                    path: ":id/:section?",
                    name: "clients.products.show",
                    component: () => import("@/pages/products/ProductInfo.vue"),
                    props: true,
                  }
                ],
                meta: {
                  breadcrumb: {
                    title: t("Products"),
                  },
                  blockName: "PRODUCTS"
                },
              },
              {
                path: "holding_financial_data",
                name: "clients.holding.financial_data",
                component: () => import("@/pages/holding/FinancialData.vue"),
                props: true,
                meta: {
                  breadcrumb: {
                    title: t("Financial indicators"),
                  },
                },
              },
              {
                path: "holding_transactions",
                name: "clients.holding.transactions",
                component: () => import("@/pages/holding/Transactions.vue"),
                props: true,
                meta: {
                  breadcrumb: {
                    title: t("Transactions"),
                  },
                },
              },
              {
                path: "documents",
                name: "clients.documents",
                component: () => import("@/pages/clients/ClientProfile/ClientDocuments.vue"),
                props: true,
                meta: {
                  table: "client_documents",
                  action: "index",
                  breadcrumb: {
                    title: t("Documents"),
                  },
                  blockName: "DOCUMENTS",
                },
              },
              {
                path: "tickets",
                name: "clients.tickets",
                component: () => import("@/pages/clients/ClientProfile/ClientTickets.vue"),
                props: true,
                meta: {
                  breadcrumb: {
                    title: t("ts.Tickets"),
                  },
                  blockName: "TICKETS",
                },
              },
              {
                path: "aggregator-participants",
                name: "clients.aggregatorParticipants",
                component: () => import("@/pages/clients/ClientProfile/ClientParticipants/AggregatorParticipants.vue"),
                props: true,
                meta: {
                  breadcrumb: {
                    title: t("Participants"),
                  },
                  blockName: "AGGREGATOR_PARTICIPANTS",
                },
              },
              {
                path: "holding-participants",
                name: "clients.holdingParticipants",
                component: () => import("@/pages/clients/ClientProfile/ClientParticipants/HoldingParticipants.vue"),
                props: true,
                meta: {
                  breadcrumb: {
                    title: t("Participants"),
                  },
                  blockName: "HOLDING_PARTICIPANTS",
                },
              },
              {
                path: "changelog",
                name: "clients.changelog",
                component: () => import("@/pages/clients/ClientProfile/ClientLog.vue"),
                props: true,
                meta: {
                  breadcrumb: {
                    title: t("Change history"),
                  },
                },
              },
            ],
            props: true,
            meta: {
              table: 'clients',
              action: 'show',
              breadcrumb: {
                dynamic: true,
                idParam: "clientId",
                crumbApi: "/api/clients/breadcrumb",
              },
              blockName: "PROFILE",
            }
          }
        ],
        meta: {
          breadcrumb: {
            title: t("Clients"),
          },
        },
      },
      {
        path: "/leads",
        children: [
          {
            path: "",
            name: "leads.list",
            component: () => import("@/pages/leads/LeadList.vue"),
            meta: {
              table: 'leads',
              action: 'index',
            },
          },
          {
            path: ":leadId",
            component: () => import("@/pages/leads/LeadProfile/LeadProfile.vue"),
            props: true,
            children: [
              {
                path: "",
                name: "leads.profile",
                component: () => import("@/pages/leads/LeadProfile/LeadInfo.vue"),
                props: true,
                meta: {
                  blockName: "INFO",
                }
              },
              {
                path: "contacts",
                name: "leads.contacts",
                component: () => import("@/pages/general/Contacts.vue"),
                props: true,
                meta: {
                  breadcrumb: {
                    title: t("Contacts"),
                  },
                  blockName: "CONTACTS",
                },
              },
              {
                path: "documents",
                name: "leads.documents",
                component: () => import("@/pages/leads/LeadProfile/LeadDocuments.vue"),
                props: true,
                meta: {
                  breadcrumb: {
                    title: t("Documents"),
                  },
                  blockName: "DOCUMENTS",
                },
              },
              {
                path: "aggregator-participants",
                name: "leads.aggregatorParticipants",
                component: () => import("@/pages/leads/LeadProfile/LeadParticipants/AggregatorParticipants.vue"),
                props: true,
                meta: {
                  breadcrumb: {
                    title: t("Participants"),
                  },
                  blockName: "AGGREGATOR_PARTICIPANTS",
                },
              },
              {
                path: "holding-participants",
                name: "leads.holdingParticipants",
                component: () => import("@/pages/leads/LeadProfile/LeadParticipants/HoldingParticipants.vue"),
                props: true,
                meta: {
                  breadcrumb: {
                    title: t("Participants"),
                  },
                  blockName: "HOLDING_PARTICIPANTS",
                },
              },
              {
                path: "tickets",
                name: "leads.tickets",
                component: () => import("@/pages/leads/LeadProfile/LeadTickets.vue"),
                props: true,
                meta: {
                  breadcrumb: {
                    title: t("ts.Tickets"),
                  },
                  blockName: "TICKETS",
                },
              },
              {
                path: "changelog",
                name: "leads.changelog",
                component: () => import("@/pages/leads/LeadProfile/LeadLog.vue"),
                props: true,
                meta: {
                  breadcrumb: {
                    title: t("Change history"),
                  },
                },
              },
            ],
            meta: {
              table: 'leads',
              action: 'show',
              breadcrumb: {
                dynamic: true,
                idParam: "leadId",
                crumbApi: "/api/leads/breadcrumb",
              },
              blockName: "PROFILE",
            },
          },
          {
            path: "create",
            name: "leads.create",
            component: () => import("@/pages/leads/LeadForm.vue"),
            meta: {
              table: 'leads',
              action: 'create',
              breadcrumb: {
                title: t("Add lead"),
              },
            },
          }
        ],
        meta: {
          breadcrumb: {
            title: t("Leads"),
          },
        }
      },
      {
        path: "/products",
        children: [
          {
            path: "",
            name: "products.import",
            component: () => import("@/pages/products/ProductImport.vue"),
            meta: {
              table: 'products',
              action: 'import',
            }
          },
        ],
        meta: {
          breadcrumb: {
            title: t("Products import"),
          }
        }
      },
      {
        path: "/calendar",
        name: "calendar",
        component: () => import("@/pages/calendar/CalendarPage.vue"),
        meta: {
          table: "communications",
          action: "index",
          breadcrumb: {
            title: t("Calendar"),
          },
        }
      },
      {
        path: "/calendar_new",
        name: "calendar_new",
        component: () => import("@/pages/calendar/CalendarPageNew.vue"),
        meta: {
          breadcrumb: {
            title: t("Calendar New"),
          },
        }
      },
      {
        path: "/notifications",
        children: [
          {
            path: "",
            name: "notifications",
            component: () => import("@/pages/notification_system/notification_listing/NotificationListing.vue"),
          },
          {
            path: "settings",
            name: "notifications.settings",
            component: () => import("@/pages/notification_system/notification_listing/NotificationSettings.vue"),
            meta: {
              breadcrumb: {
                title: t("Settings"),
              },
            },
          }
        ],
        meta: {
          breadcrumb: {
            title: t("Notifications"),
          },
        }
      },
      {
        path: "/deferred-export",
        name: 'deferred-export',
        children: [
          {
            path: "",
            name: "deferred-export.list",
            component: () => import("@/pages/deferred_export/DeferredExportListing.vue"),
            meta: {
              breadcrumb: {
                title: t("Deferred exports"),
              },
            }
          },
        ],
      },
      {
        path: "/association-types",
        name: "association-types",
        children: [
          {
            path: "",
            name: "association-types.list",
            component: () => import("@/pages/associations/AssociationList.vue"),
            meta: {
              table: "association_types",
              action: "index",
            },
          },
          {
            path: "create",
            name: "association-types.create",
            component: () => import("@/pages/associations/AssociationForm.vue"),
          },
          {
            path: "edit/:associationTypeId",
            name: "association-types.edit",
            component: () => import("@/pages/associations/AssociationForm.vue"),
          }
        ]
      },
      {
        path: "/association-types",
        name: "association-types",
        children: [
          {
            path: "",
            name: "association-types.list",
            component: () => import("@/pages/associations/AssociationList.vue"),
            meta: {
              table: "association_types",
              action: "index",
            },
          },
          {
            path: "create",
            name: "association-types.create",
            component: () => import("@/pages/associations/AssociationForm.vue"),
            meta: {
              table: "association_types",
              action: "create",
              breadcrumb: {
                title: t("Add client type"),
              }
            }
          },
          {
            path: "edit/:associationTypeId",
            name: "association-types.edit",
            component: () => import("@/pages/associations/AssociationForm.vue"),
            meta: {
              table: "association_types",
              action: "update",
              breadcrumb: {
                title: t("Edit client type"),
              },
            },
          },
        ],
        meta: {
          breadcrumb: {
            title: t("Client Types"),
          }
        }
      },
      {
        path: "/reports",
        meta: {
          requiresAuth: true,
          table: "reports",
          action: "index",
          breadcrumb: {
            title: t("Reports"),
          }
        },
        children: [
          {
            /* BEGIN Report groups */
            path: "",
            name: "reports",
            component: () => import("@/pages/reports/ReportMenu.vue"),
            children: [
              {
                path: "crm",
                name: "reports.crm",
                meta: {
                  table: "reports_crm",
                  action: "index",
                  breadcrumb: {
                    title: t("Reports CRM"),
                  },
                },
                children: [
                  {
                    path: "personnel",
                    name: "reports.crm.personnel",
                    component: () => import("@/pages/reports/ReportCards.vue"),
                    meta: {
                      table: "reports_crm_personnel",
                      action: "index",
                      breadcrumb: {
                        title: t("Reports on personnel"),
                      },
                      reportSubgroupRoute: true,
                    },
                  },
                  {
                    path: "activities",
                    name: "reports.crm.activities",
                    component: () => import("@/pages/reports/ReportCards.vue"),
                    meta: {
                      table: "reports_crm_activities",
                      action: "index",
                      breadcrumb: {
                        title: t("Reports on activities"),
                      },
                      reportSubgroupRoute: true,
                    },
                  },
                  {
                    path: "customer-support",
                    name: "reports.crm.customer-support",
                    component: () => import("@/pages/reports/ReportCards.vue"),
                    meta: {
                      table: "reports_crm_customer_support",
                      action: "index",
                      breadcrumb: {
                        title: t("Customer support department"),
                      },
                      reportSubgroupRoute: true,
                    },
                  },
                  {
                    path: "employee-grade",
                    name: "reports.crm.employee-grade",
                    component: () => import("@/pages/reports/ReportCards.vue"),
                    meta: {
                      table: "reports_crm_employee_grade",
                      action: "index",
                      breadcrumb: {
                        title: t("Employee grade"),
                      },
                      reportSubgroupRoute: true,
                    },
                  }
                ],
              },
              {
                path: "payport",
                name: "reports.payport",
                meta: {
                  table: "reports_payport",
                  action: "index",
                  breadcrumb: {
                    title: t("Reports Payport"),
                  },
                },
                children: [
                  {
                    path: "sales",
                    name: "reports.payport.sales",
                    component: () => import("@/pages/reports/ReportCards.vue"),
                    meta: {
                      table: "reports_payport_sales",
                      action: "index",
                      breadcrumb: {
                        title: t("Sales reports"),
                      },
                      reportSubgroupRoute: true,
                    },
                  },
                  {
                    path: "maintenance",
                    name: "reports.payport.maintenance",
                    component: () => import("@/pages/reports/ReportCards.vue"),
                    meta: {
                      table: "reports_payport_maintenance",
                      action: "index",
                      breadcrumb: {
                        title: t("Maintenance reports"),
                      },
                      reportSubgroupRoute: true,
                    },
                  },
                  {
                    path: "profitability",
                    name: "reports.payport.profitability",
                    component: () => import("@/pages/reports/ReportCards.vue"),
                    meta: {
                      table: "reports_payport_profitability",
                      action: "index",
                      breadcrumb: {
                        title: t("Profitability reports"),
                      },
                      reportSubgroupRoute: true,
                    },
                  },
                  {
                    path: "1-line",
                    name: "reports.payport.1-line",
                    component: () => import("@/pages/reports/ReportCards.vue"),
                    meta: {
                      table: "reports_payport_1_line",
                      action: "index",
                      breadcrumb: {
                        title: t("Reports - 1 line"),
                      },
                      reportSubgroupRoute: true,
                    },
                  },
                ]
              },
              {
                path: "gnu-vpn",
                name: "reports.gnu-vpn",
                meta: {
                  table: "reports_gnu_vpn",
                  action: "index",
                  breadcrumb: {
                    title: t("Reports GNU VPN"),
                  },
                },
                children: [],
              },
              {
                path: "crm-ts",
                name: "reports.crm_ts",
                meta: {
                  table: "reports_crm_ts",
                  action: "index",
                  breadcrumb: {
                    title: t("Reports CRM_TS"),
                  },
                },
                children: [
                  {
                    path: "ticket-invoices",
                    name: "reports.crm_ts.ticket_invoices",
                    component: () => import("@/pages/reports/ReportCards.vue"),
                    meta: {
                      table: "reports_crm_ts_ticket_invoices_general",
                      action: "index",
                      breadcrumb: {
                        title: t("Reports on ticket invoices"),
                      },
                      reportSubgroupRoute: true,
                    },
                  },
                  {
                    path: "user-tickets",
                    name: "reports.crm_ts.user_tickets",
                    component: () => import("@/pages/reports/ReportCards.vue"),
                    meta: {
                      table: "reports_crm_ts_user_tickets",
                      action: "index",
                      breadcrumb: {
                        title: t("Reports on ticket personnel"),
                      },
                      reportSubgroupRoute: true,
                    },
                  },
                  {
                    path: "user-tickets-by-queue",
                    name: "reports.crm_ts.user_tickets_by_queue",
                    component: () => import("@/pages/reports/ReportCards.vue"),
                    meta: {
                      // table: "reports_crm_ts_user_tickets_by_queue_status",
                      table: "reports_crm_ts_user_tickets_by_queue",
                      action: "index",
                      breadcrumb: {
                        title: t("Reports on ticket personnel"),
                      },
                      reportSubgroupRoute: true,
                    },
                  },
                ],
              },
            ]
            /* END Report groups */
          },
          {
            /* BEGIN Reports CRM */
            path: "crm",
            meta: {
              table: "reports_crm",
              action: "index",
              breadcrumb: {
                title: t("Reports CRM"),
              },
            },
            children: [
              {
                path: "personnel",
                meta: {
                  table: "reports_crm_personnel",
                  action: "index",
                  breadcrumb: {
                    title: t("Reports on personnel"),
                  }
                },
                children: [
                  {
                    path: "auth-log",
                    name: "reports.crm.personnel.auth-log",
                    component: () => import('@/pages/reports/AuthLog'),
                    meta: {
                      breadcrumb: {
                        title: t("Auth log"),
                      }
                    }
                  },
                  {
                    path: "manager-activity",
                    name: "reports.crm.personnel.manager-activity",
                    component: () => import('@/pages/reports/ManagerActivity'),
                    meta: {
                      breadcrumb: {
                        title: t("Manager activity"),
                      }
                    }
                  },
                  {
                    path: "limited-search",
                    name: "reports.crm.personnel.limited-search",
                    component: () => import('@/pages/reports/LimitedSearch/LimitedSearch.vue'),
                    meta: {
                      breadcrumb: {
                        title: t("limited_search"),
                      }
                    }
                  },
                  {
                    path: "calendar-tasks",
                    name: "reports.crm.personnel.calendar-tasks",
                    component: () => import('@/pages/reports/CalendarTasks'),
                    meta: {
                      breadcrumb: {
                        title: t("Calendar tasks by managers"),
                      }
                    }
                  },
                ],
              },
              {
                path: "activities",
                meta: {
                  table: "reports_crm_activities",
                  action: "index",
                  breadcrumb: {
                    title: t("Reports on activities"),
                  },
                },
                children: [
                  {
                    path: "with-no-activity",
                    name: "reports.crm.activities.with-no-activity",
                    component: () => import('@/pages/reports/WithNoActivity'),
                    meta: {
                      table: "reports_crm_activities",
                      action: "index",
                      onlyAll: true,
                      breadcrumb: {
                        title: t("Leads' and clients' activity"),
                      }
                    }
                  },
                  {
                    path: "added-to-blacklist",
                    name: "reports.crm.activities.added-to-blacklist",
                    component: () => import('@/pages/reports/AddedToBlacklist'),
                    meta: {
                      table: "reports_crm_activities",
                      action: "index",
                      onlyAll: true,
                      breadcrumb: {
                        title: t("Added to blacklist"),
                      }
                    }
                  },
                  {
                    path: "merchants-entering-sand",
                    name: "reports.crm.activities.merchants-entering-sand",
                    component: () => import('@/pages/reports/MerchantsEnteringSand'),
                    meta: {
                      breadcrumb: {
                        title: t("Merchants entering sand"),
                      }
                    }
                  },
                  {
                    path: "payport-average-time-to-prod-after-sand",
                    name: "reports.crm.activities.payport-average-time-to-prod-after-sand",
                    component: () => import('@/pages/reports/AverageTimeToProdAfterSand'),
                    meta: {
                      table: "reports_crm_activities",
                      action: "index",
                      onlyAll: true,
                      breadcrumb: {
                        title: t("Average time to prod after sand"),
                      }
                    }
                  },
                  {
                    path: "merchants-entering-prod",
                    name: "reports.crm.activities.merchants-entering-prod",
                    component: () => import('@/pages/reports/MerchantsEnteringProd'),
                    meta: {
                      breadcrumb: {
                        title: t("Merchants entering prod"),
                      }
                    }
                  },
                  {
                    path: "merchants-without-transactions",
                    name: "reports.crm.activities.merchants-without-transactions",
                    component: () => import('@/pages/reports/MerchantsWithoutTransactions'),
                    meta: {
                      table: "reports_crm_activities",
                      action: "index",
                      onlyAll: true,
                      breadcrumb: {
                        title: t("Merchants without transactions"),
                      }
                    }
                  },
                  {
                    path: "average-time-to-bargain",
                    name: "reports.crm.activities.average-time-to-bargain",
                    component: () => import('@/pages/reports/AverageTimeToBargain'),
                    meta: {
                      table: "reports_crm_activities",
                      action: "index",
                      onlyAll: true,
                      breadcrumb: {
                        title: t("Average time to bargain"),
                      }
                    }
                  },
                  {
                    path: "leads-by-resp-and-products",
                    name: "reports.crm.activities.leads-by-resp-and-products",
                    component: () => import('@/pages/reports/LeadsByRespAndProducts'),
                    meta: {
                      table: "reports_crm_activities",
                      action: "index",
                      onlyAll: true,
                      breadcrumb: {
                        title: t("Leads by responsibles and products"),
                      }
                    }
                  },
                  {
                    path: "converted-cancelled-leads",
                    name: "reports.crm.activities.converted-cancelled-leads",
                    component: () => import("@/pages/reports/ConvertedCancelledLeads"),
                    meta: {
                      table: "reports_crm_activities",
                      action: "index",
                      onlyAll: true,
                      breadcrumb: {
                        title: t("Converted & cancelled leads"),
                      }
                    }
                  },
                  {
                    path: "holding-participant-leads",
                    name: "reports.crm.activities.holding-participant-leads",
                    component: () => import("@/pages/reports/HoldingParticipantLeads"),
                    meta: {
                      table: "reports_crm_activities",
                      action: "index",
                      onlyAll: true,
                      breadcrumb: {
                        title: t("Holding leads by participants"),
                      }
                    }
                  },
                  {
                    path: "aggregator-leads",
                    name: "reports.crm.activities.aggregator-leads",
                    component: () => import("@/pages/reports/AggregatorLeads"),
                    meta: {
                      table: "reports_crm_activities",
                      action: "index",
                      onlyAll: true,
                      breadcrumb: {
                        title: t("Aggregator leads"),
                      }
                    }
                  },
                  {
                    path: "leads-by-sales-channels",
                    name: "reports.crm.activities.leads-by-sales-channels",
                    component: () => import("@/pages/reports/LeadsBySalesChannels"),
                    meta: {
                      table: "reports_crm_activities",
                      action: "index",
                      onlyAll: true,
                      breadcrumb: {
                        title: t("Leads by sales channels"),
                      }
                    }
                  },
                  {
                    path: "holding-participant-clients",
                    name: "reports.crm.activities.holding-participant-clients",
                    component: () => import("@/pages/reports/HoldingParticipantClients"),
                    meta: {
                      table: "reports_crm_activities",
                      action: "index",
                      onlyAll: true,
                      breadcrumb: {
                        title: t("Holding clients by participants"),
                      }
                    }
                  },
                  {
                    path: "aggregator-clients",
                    name: "reports.crm.activities.aggregator-clients",
                    component: () => import("@/pages/reports/AggregatorClients"),
                    meta: {
                      table: "reports_crm_activities",
                      action: "index",
                      onlyAll: true,
                      breadcrumb: {
                        title: t("Aggregator clients"),
                      }
                    }
                  },
                  {
                    path: "clients-by-sales-channels",
                    name: "reports.crm.activities.clients-by-sales-channels",
                    component: () => import("@/pages/reports/ClientsBySalesChannels"),
                    meta: {
                      table: "reports_crm_activities",
                      action: "index",
                      onlyAll: true,
                      breadcrumb: {
                        title: t("Clients by sales channels"),
                      }
                    }
                  },
                  {
                    path: "deactivated-clients",
                    name: "reports.crm.activities.deactivated-clients",
                    component: () => import("@/pages/reports/DeactivatedClients"),
                    meta: {
                      table: "reports_crm_activities",
                      action: "index",
                      onlyAll: true,
                      breadcrumb: {
                        title: t("Deactivated clients"),
                      }
                    }
                  },
                  {
                    path: "merchants-status-new",
                    name: "reports.crm.activities.merchants-status-new",
                    component: () => import("@/pages/reports/MerchantsStatusNew"),
                    meta: {
                      table: "reports_crm_activities",
                      action: "index",
                      onlyAll: true,
                      breadcrumb: {
                        title: t("Merchants in status \"New\""),
                      }
                    }
                  },

                ],
              },
              {
                path: "customer-support",
                meta: {
                  table: "reports_crm_customer_support",
                  action: "index",
                  breadcrumb: {
                    title: t("Customer support department"),
                  }
                },
                children: [
                  {
                    path: "customer-support-activity",
                    name: "reports.crm.customer-support.customer-support-activity",
                    component: () => import("@/pages/reports/CustomerSupportActivity"),
                    meta: {
                      breadcrumb: {
                        title: t("Customer support department activity"),
                      }
                    }
                  },
                ]
              },
              {
                path: "employee-grade",
                meta: {
                  table: "reports_crm_employee_grade",
                  action: "index",
                  breadcrumb: {
                    title: t("Employee grade"),
                  }
                },
                children: [
                  {
                    path: "employee-grade",
                    name: "reports.crm.employee-grade.employee-grade",
                    component: () => import("@/pages/reports/EmployeeGrade"),
                    meta: {
                      breadcrumb: {
                        title: t("Employee grade"),
                      }
                    }
                  },
                ]
              },
            ]
            /* END Reports CRM */
          },
          {
            /* BEGIN Reports Payport */
            path: "payport",
            meta: {
              table: "reports_payport",
              action: "index",
              breadcrumb: {
                title: t("Reports Payport"),
              },
            },
            children: [
              {
                path: "sales",
                meta: {
                  table: "reports_payport_sales",
                  action: "index",
                  breadcrumb: {
                    title: t("Sales reports"),
                  }
                },
                children: [
                  {
                    path: "payport-top-currencies-without-profitability",
                    name: "reports.payport.sales.top-currencies-without-profitability",
                    component: () => import('@/pages/reports/TopCurrenciesWithoutProfitability'),
                    meta: {
                      table: "reports_payport_sales",
                      action: "index",
                      onlyAll: true,
                      breadcrumb: {
                        title: t("Top currencies"),
                      }
                    }
                  },
                  {
                    path: "merchant-circulation-amount-timeline",
                    name: "reports.payport.sales.merchant-circulation-amount-timeline",
                    component: () => import('@/pages/reports/MerchantCirculationAmountTimeline'),
                    meta: {
                      breadcrumb: {
                        title: t("Merchant circulation amount timeline"),
                      }
                    }
                  },
                  {
                    path: "fiat-circulation-amount-timeline",
                    name: "reports.payport.sales.fiat-circulation-amount-timeline",
                    component: () => import('@/pages/reports/FiatCirculationAmountTimeline'),
                    meta: {
                      breadcrumb: {
                        title: t("Fiat circulation amount timeline"),
                      }
                    }
                  },

                  {
                    path: "payport-top-service-providers",
                    name: "reports.payport.sales.top-service-providers",
                    component: () => import('@/pages/reports/TopServiceProviders'),
                    meta: {
                      table: "reports_payport_sales",
                      action: "index",
                      onlyAll: true,
                      breadcrumb: {
                        title: t("Top service providers"),
                      }
                    }
                  },
                  {
                    path: "currency-merchant",
                    name: "reports.payport.sales.currency-merchant",
                    component: () => import('@/pages/reports/CurrencyMerchant'),
                    meta: {
                      table: "reports_payport_sales",
                      action: "index",
                      onlyAll: true,
                      breadcrumb: {
                        title: t("Currency merchant"),
                      }
                    }
                  },
                  {
                    path: "merchant-currency",
                    name: "reports.payport.sales.merchant-currency",
                    component: () => import('@/pages/reports/MerchantCurrency'),
                    meta: {
                      table: "reports_payport_sales",
                      action: "index",
                      onlyAll: true,
                      breadcrumb: {
                        title: t("Merchant currency"),
                      }
                    }
                  },
                  {
                    path: "payport-merchant-recalculations",
                    name: "reports.payport.sales.merchant-recalculations",
                    component: () => import('@/pages/reports/MerchantRecalculations'),
                    meta: {
                      table: "reports_payport_sales",
                      action: "index",
                      onlyAll: true,
                      breadcrumb: {
                        title: t("Merchant recalculations"),
                      }
                    }
                  },
                  {
                    path: "trader-conversions",
                    name: "reports.payport.sales.trader-conversions",
                    component: () => import('@/pages/reports/TraderConversions'),
                    meta: {
                      table: "reports_payport_sales",
                      action: "index",
                      onlyAll: true,
                      breadcrumb: {
                        title: t("Trader conversions"),
                      }
                    }
                  },
                  {
                    path: "payport-merchant-cancellations",
                    name: "reports.payport.sales.merchant-cancellations",
                    component: () => import('@/pages/reports/TraderCancellations'),
                    meta: {
                      table: "reports_payport_sales",
                      action: "index",
                      onlyAll: true,
                      breadcrumb: {
                        title: t("Trader cancellations"),
                      }
                    }
                  },
                  {
                    path: "payport-traders-speed",
                    name: "reports.payport.sales.traders-speed",
                    component: () => import('@/pages/reports/TradersSpeed'),
                    meta: {
                      table: "reports_payport_sales",
                      action: "index",
                      onlyAll: true,
                      breadcrumb: {
                        title: t("Traders speed"),
                      }
                    }
                  },
                  {
                    path: "payport-invoices-distribution-by-time",
                    name: "reports.payport.sales.invoices-distribution-by-time",
                    component: () => import('@/pages/reports/InvoicesDistributionByTime'),
                    meta: {
                      table: "reports_payport_sales",
                      action: "index",
                      onlyAll: true,
                      breadcrumb: {
                        title: t("Invoices distribution by time"),
                      }
                    }
                  },
                ],
              },
              {
                path: "maintenance",
                meta: {
                  table: "reports_payport_maintenance",
                  action: "index",
                  breadcrumb: {
                    title: t("Maintenance reports"),
                  }
                },
                children: [
                  {
                    path: "payport-top-merchants-without-profitability",
                    name: "reports.payport.maintenance.top-merchants-without-profitability",
                    component: () => import('@/pages/reports/TopMerchantsWithoutProfitability'),
                    meta: {
                      breadcrumb: {
                        title: t("Top merchants"),
                      }
                    }
                  },
                  {
                    path: "merchant-conversions",
                    name: "reports.payport.maintenance.merchant-conversions",
                    component: () => import('@/pages/reports/MerchantConversions'),
                    meta: {
                      table: "reports_payport_maintenance",
                      action: "index",
                      // onlyAll: true,
                      breadcrumb: {
                        title: t("Merchant conversions"),
                      }
                    }
                  },
                  {
                    path: "merchant-circulation-amount-timeline",
                    name: "reports.payport.maintenance.merchant-circulation-amount-timeline",
                    component: () => import('@/pages/reports/MerchantCirculationAmountTimeline'),
                    meta: {
                      breadcrumb: {
                        title: t("Merchant circulation amount timeline"),
                      }
                    }
                  },
                  {
                    path: "fiat-circulation-amount-timeline",
                    name: "reports.payport.maintenance.fiat-circulation-amount-timeline",
                    component: () => import('@/pages/reports/FiatCirculationAmountTimeline'),
                    meta: {
                      breadcrumb: {
                        title: t("Fiat circulation amount timeline"),
                      }
                    }
                  },
                ],
              },
              {
                path: "profitability",
                meta: {
                  table: "reports_payport_profitability",
                  action: "index",
                  breadcrumb: {
                    title: t("Profitability reports"),
                  }
                },
                children: [
                  {
                    path: "payport-top-service-providers-with-profitability",
                    name: "reports.payport.profitability.top-service-providers-with-profitability",
                    component: () => import('@/pages/reports/TopServiceProvidersWithProfitability'),
                    meta: {
                      breadcrumb: {
                        title: t("Top service providers (profitability)"),
                      }
                    }
                  },
                  {
                    path: "payport-top-currencies-with-profitability",
                    name: "reports.payport.profitability.top-currencies-with-profitability",
                    component: () => import('@/pages/reports/TopCurrenciesWithProfitability'),
                    meta: {
                      breadcrumb: {
                        title: t("Top currencies (profitability)"),
                      }
                    }
                  },
                  {
                    path: "payport-top-merchants-with-profitability",
                    name: "reports.payport.profitability.top-merchants-with-profitability",
                    component: () => import('@/pages/reports/TopMerchantsWithProfitability'),
                    meta: {
                      breadcrumb: {
                        title: t("Top merchants (profitability)"),
                      }
                    }
                  },
                  {
                    path: "payport-top-merchants-by-intervals",
                    name: "reports.payport.profitability.top-merchants-by-intervals",
                    component: () => import('@/pages/reports/TopMerchantsByIntervals'),
                    meta: {
                      breadcrumb: {
                        title: t("Top merchants by intervals (profitability)"),
                      }
                    }
                  },
                ],
              },
              {
                path: "1-line",
                meta: {
                  table: "reports_payport_1_line",
                  action: "index",
                  breadcrumb: {
                    title: t("Reports - 1 line"),
                  }
                },
                children: [
                  {
                    path: "trader-conversions",
                    name: "reports.payport.1-line.trader-conversions",
                    component: () => import('@/pages/reports/TraderConversions'),
                    meta: {
                      breadcrumb: {
                        title: t("Trader conversions"),
                      }
                    }
                  },
                  {
                    path: "merchant-conversions",
                    name: "reports.payport.1-line.merchant-conversions",
                    component: () => import('@/pages/reports/MerchantConversions'),
                    meta: {
                      breadcrumb: {
                        title: t("Merchant conversions"),
                      }
                    }
                  },
                ],
              },
            ]
            /* END Reports Payport */
          },
          // {
          //   /* BEGIN Reports GNU VPN */
          //   path: "gnu-vpn",
          //   meta: {
          //     breadcrumb: {
          //       title: t("Reports GNU VPN"),
          //     },
          //   },
          //   children: []
          //   /* END Reports GNU VPN */
          // },

          {
            path: "crm-ts",
            name: "crm_ts",
            meta: {
              table: "reports_crm_ts",
              action: "index",
              breadcrumb: {
                title: t("Reports CRM_TS"),
              },
            },
            children: [
              {
                path: "ticket-invoices",
                meta: {
                  table: "reports_crm_ts_ticket_invoices_general",
                  name: "reports.crm_ts.ticket_invoices",
                  action: "index",
                  breadcrumb: {
                    title: t("Reports on ticket invoices"),
                  }
                },
                children: [
                  {
                    path: "general",
                    name: "reports.crm_ts.ticket_invoices.general",
                    component: () => import("@/pages/reports/TicketSystem/TicketInvoices/TicketInvoices.vue"),
                    meta: {
                      table: "reports_crm_ts_ticket_invoices_general",
                      action: "index",
                      breadcrumb: {
                        title: t("reports_crm_ts_ticket_invoices_general"),
                      }
                    }
                  },
                ],
              },
              {
                path: "user-tickets",
                meta: {
                  table: "reports_crm_ts_user_tickets",
                  action: "index",
                  breadcrumb: {
                    title: t("Reports on ticket personnel"),
                  }
                },
                children: [
                  {
                    path: "status",
                    name: "reports.crm_ts.user_tickets.status",
                    component: () => import("@/pages/reports/TicketSystem/UserTicketStatus/UserTicketStatus.vue"),
                    meta: {
                      table: "reports_crm_ts_user_tickets",
                      action: "index",
                      breadcrumb: {
                        title: t("reports_crm_ts_user_tickets_status"),
                      },

                    }
                  },
                  {
                    path: "status-by-queue",
                    name: "reports.crm_ts.user_tickets_by_queue.status",
                    component: () => import("@/pages/reports/TicketSystem/UserTicketByQueueStatus/UserTicketByQueueStatus.vue"),
                    meta: {
                      table: "reports_crm_ts_user_tickets_by_queue_status",
                      action: "index",
                      breadcrumb: {
                        title: t("reports_crm_ts_user_tickets_by_queue_status"),
                      },
                    }
                  },
                ],
              },
            ],
          },
        ]
      },
      {
        path: "/ts",
        redirect: '/ts/tickets',
        children: [
          {
            path: "tickets",
            children: [
              {
                path: "",
                name: "ts.tickets.index",
                component: () => import("@/pages/ts/tickets/List.vue"),
              },
              {
                path: ":id",
                name: "ts.tickets.show",
                component: () => import("@/pages/ts/tickets/View.vue"),
                meta: {
                  breadcrumb: {
                    dynamic: true,
                    idParam: "id",
                    crumbApi: "/api/ts/tickets/breadcrumb",
                  },
                }
              },
              {
                path: "create",
                name: "ts.tickets.create",
                component: () => import("@/pages/ts/tickets/EditForm.vue"),
                meta: {
                  breadcrumb: {
                    title: t("ts.tickets.Create"),
                  },
                },
              },
            ],
            meta: {
              table: 'ts_tickets',
              action: 'index',
              breadcrumb: {
                title: t("ts.Tickets"),
              },
            },
          },
          {
            path: "queues",
            children: [
              {
                path: "",
                name: "ts.queues.index",
                component: () => import("@/pages/ts/queues/List.vue"),
              },
              {
                path: ":id/edit",
                name: "ts.queues.edit",
                component: () => import("@/pages/ts/queues/EditForm.vue"),
                props: true,
                meta: {
                  breadcrumb: {
                    title: t("ts.queues.Edit"),
                  },
                },
              },
              {
                path: "create",
                name: "ts.queues.create",
                component: () => import("@/pages/ts/queues/EditForm.vue"),
                meta: {
                  breadcrumb: {
                    title: t("ts.queues.Create"),
                  },
                },
              },
            ],
            meta: {
              table: 'ts_administration',
              action: 'index',
              breadcrumb: {
                title: t("ts.Queues"),
              },
            },
          },
          {
            path: "ticket_types",
            children: [
              {
                path: "",
                name: "ts.ticket_types.index",
                component: () => import("@/pages/ts/ticket_types/List.vue"),
              },
              {
                path: ":id/edit",
                name: "ts.ticket_types.edit",
                component: () => import("@/pages/ts/ticket_types/EditForm.vue"),
                props: true,
                meta: {
                  breadcrumb: {
                    title: t("ts.ticket_types.Edit"),
                  },
                },
              },
              {
                path: "create",
                name: "ts.ticket_types.create",
                component: () => import("@/pages/ts/ticket_types/EditForm.vue"),
                meta: {
                  breadcrumb: {
                    title: t("ts.ticket_types.Create"),
                  },
                },
              },
            ],
            meta: {
              table: 'ts_administration',
              action: 'index',
              breadcrumb: {
                title: t("ts.Ticket Types"),
              },
            },
          },
          {
            path: "priorities",
            children: [
              {
                path: "",
                name: "ts.priorities.index",
                component: () => import("@/pages/ts/priorities/List.vue"),
              },
              {
                path: ":id/edit",
                name: "ts.priorities.edit",
                component: () => import("@/pages/ts/priorities/EditForm.vue"),
                props: true,
                meta: {
                  breadcrumb: {
                    title: t("ts.priorities.Edit"),
                  },
                },
              },
              {
                path: "create",
                name: "ts.priorities.create",
                component: () => import("@/pages/ts/priorities/EditForm.vue"),
                meta: {
                  breadcrumb: {
                    title: t("ts.priorities.Create"),
                  },
                },
              },
            ],
            meta: {
              table: 'ts_administration',
              action: 'index',
              breadcrumb: {
                title: t("ts.Priorities"),
              },
            },
          },
          {
            path: "topics",
            children: [
              {
                path: "",
                name: "ts.topics.index",
                component: () => import("@/pages/ts/topics/List.vue"),
              },
              {
                path: ":id/edit",
                name: "ts.topics.edit",
                component: () => import("@/pages/ts/topics/EditForm.vue"),
                props: true,
                meta: {
                  breadcrumb: {
                    title: t("ts.topics.Edit"),
                  },
                },
              },
              {
                path: "create",
                name: "ts.topics.create",
                component: () => import("@/pages/ts/topics/EditForm.vue"),
                meta: {
                  breadcrumb: {
                    title: t("ts.topics.Create"),
                  },
                },
              },
            ],
            meta: {
              table: 'ts_administration',
              action: 'index',
              breadcrumb: {
                title: t("ts.Topics"),
              },
            },
          },
          {
            path: "sla",
            children: [
              {
                path: "",
                name: "ts.sla.index",
                component: () => import("@/pages/ts/sla/List.vue"),
              },
              {
                path: ":id/edit",
                name: "ts.sla.edit",
                component: () => import("@/pages/ts/sla/EditForm.vue"),
                props: true,
                meta: {
                  breadcrumb: {
                    title: t("ts.sla.Edit"),
                  },
                },
              },
              {
                path: "create",
                name: "ts.sla.create",
                component: () => import("@/pages/ts/sla/EditForm.vue"),
                meta: {
                  breadcrumb: {
                    title: t("ts.sla.Create"),
                  },
                },
              },
            ],
            meta: {
              table: 'ts_administration',
              action: 'index',
              breadcrumb: {
                title: t("ts.SLA"),
              },
            },
          },
          {
            path: "queue_role_permissions",
            children: [
              {
                path: "",
                name: "ts.queue_role_permissions.index",
                component: () => import("@/pages/ts/queue_role_permissions/EditForm.vue"),
              },
            ],
            meta: {
              table: 'ts_administration',
              action: 'index',
              breadcrumb: {
                title: t("ts.Queue Roles"),
              },
            },
          },
          {
            path: "dynamic_fields",
            children: [
              {
                path: "",
                name: "ts.dynamic_fields.index",
                component: () => import("@/pages/ts/dynamic_fields/List.vue"),
              },
              {
                path: ":id/edit",
                name: "ts.dynamic_fields.edit",
                component: () => import("@/pages/ts/dynamic_fields/EditForm.vue"),
                props: true,
                meta: {
                  breadcrumb: {
                    title: t("ts.dynamic_fields.Edit"),
                  },
                },
              },
              {
                path: "create",
                name: "ts.dynamic_fields.create",
                component: () => import("@/pages/ts/dynamic_fields/EditForm.vue"),
                meta: {
                  breadcrumb: {
                    title: t("ts.dynamic_fields.Create"),
                  },
                },
              },
            ],
            meta: {
              table: 'ts_administration',
              action: 'index',
              breadcrumb: {
                title: t("ts.Dynamic Fields"),
              },
            },
          },
          {
            path: "ticket_templates",
            children: [
              {
                path: "",
                name: "ts.ticket_templates.index",
                component: () => import("@/pages/ts/ticket_templates/List.vue"),
              },
              {
                path: ":id/edit",
                name: "ts.ticket_templates.edit",
                component: () => import("@/pages/ts/ticket_templates/EditForm.vue"),
                props: true,
                meta: {
                  breadcrumb: {
                    title: t("ts.ticket_templates.Edit"),
                  },
                },
              },
              {
                path: "create",
                name: "ts.ticket_templates.create",
                component: () => import("@/pages/ts/ticket_templates/EditForm.vue"),
                meta: {
                  breadcrumb: {
                    title: t("ts.ticket_templates.Create"),
                  },
                },
              },
            ],
            meta: {
              table: 'ts_administration',
              action: 'index',
              breadcrumb: {
                title: t("ts.Ticket Templates"),
              },
            },
          },
          {
            path: "filters",
            children: [
              {
                path: "",
                name: "ts.filters.index",
                component: () => import("@/pages/ts/filters/List.vue"),
              },
            ],
            meta: {
              table: 'ts_administration',
              action: 'index',
              breadcrumb: {
                title: t("ts.Filter settings"),
              },
            },
          },
          {
            path: "tickets-autofill",
            children: [
              {
                path: "",
                name: "ts.tickets-autofill.index",
                component: () => import("@/pages/ts/tickets_autofill/List.vue"),
              },
              {
                path: "create",
                name: "ts.tickets-autofill.create",
                component: () => import("@/pages/ts/tickets_autofill/EditForm.vue"),
                meta: {
                  breadcrumb: {
                    title: t("ts.Autofill create"),
                  },
                },
              },
              {
                path: ":id/edit",
                name: "ts.tickets-autofill.edit",
                component: () => import("@/pages/ts/tickets_autofill/EditForm.vue"),
                props: true,
                meta: {
                  breadcrumb: {
                    title: t("ts.Autofill edit"),
                  },
                },
              },
            ],
            meta: {
              table: 'ts_administration',
              action: 'index',
              breadcrumb: {
                title: t("ts.Tickets autofill"),
              },
            },
          },
          {
            path: "tickets-autofill-by-product-assignment",
            children: [
              {
                path: "",
                name: "ts.tickets-autofill-by-product-assignment.index",
                component: () => import("@/pages/ts/tickets_autofill/by_product_assignment/List.vue"),
              },
              {
                path: "create",
                name: "ts.tickets-autofill-by-product-assignment.create",
                component: () => import("@/pages/ts/tickets_autofill/by_product_assignment/EditForm.vue"),
                meta: {
                  breadcrumb: {
                    title: t("ts.Autofill create"),
                  },
                },
              },
              {
                path: ":id/edit",
                name: "ts.tickets-autofill-by-product-assignment.edit",
                component: () => import("@/pages/ts/tickets_autofill/by_product_assignment/EditForm.vue"),
                props: true,
                meta: {
                  breadcrumb: {
                    title: t("ts.Autofill edit"),
                  },
                },
              },
            ],
            meta: {
              table: 'ts_administration',
              action: 'index',
              breadcrumb: {
                title: t("ts.Tickets autofill"),
              },
            },
          },
          {
            path: "settings",
            redirect: '/ts/settings/main',
            children: [
              {
                path: "main",
                name: "ts.settings.main",
                component: () => import("@/pages/ts/settings/Main.vue"),
              },
              {
                path: "mail",
                name: "ts.settings.mail",
                children: [
                  {
                    path: "income",
                    name: "ts.settings.mail_accounts.list.income",
                    component: () => import("@/pages/ts/settings/tabs/MailIncome.vue"),
                    meta: {
                      breadcrumb: {
                        title: t("ts.mail_accounts.List"),
                      },
                    },
                  },
                  {
                    path: "outcome",
                    name: "ts.settings.mail_accounts.list.outcome",
                    component: () => import("@/pages/ts/settings/tabs/MailOutcome.vue"),
                    meta: {
                      breadcrumb: {
                        title: t("ts.mail_accounts.List"),
                      },
                    },
                  },
                  {
                    path: "create",
                    name: "ts.settings.mail_accounts.create",
                    component: () => import("@/pages/ts/mail_accounts/EditForm.vue"),
                    meta: {
                      breadcrumb: {
                        title: t("ts.mail_accounts.Create"),
                      },
                    },
                  },
                  {
                    path: ":id/edit",
                    name: "ts.settings.mail_accounts.edit",
                    component: () => import("@/pages/ts/mail_accounts/EditForm.vue"),
                    props: true,
                    meta: {
                      breadcrumb: {
                        title: t("ts.mail_accounts.Edit"),
                      },
                    },
                  },
                ],
              },
              {
                path: "clients_api",
                name: "ts.settings.clients_api",
                children: [
                  {
                    path: "",
                    name: "ts.settings.clients_api.list",
                    component: () => import("@/pages/ts/settings/tabs/ClientsApi.vue"),
                    meta: {
                      breadcrumb: {
                        title: t("ts.clients_api.List"),
                      },
                    },
                  },
                  {
                    path: "create",
                    name: "ts.settings.clients_api.create",
                    component: () => import("@/pages/ts/clients_api/EditForm.vue"),
                    meta: {
                      breadcrumb: {
                        title: t("ts.clients_api.Create"),
                      },
                    },
                  },
                  {
                    path: ":id/edit",
                    name: "ts.settings.clients_api.edit",
                    component: () => import("@/pages/ts/clients_api/EditForm.vue"),
                    props: true,
                    meta: {
                      breadcrumb: {
                        title: t("ts.clients_api.Edit"),
                      },
                    },
                  },
                ],
              },
            ],
            meta: {
              table: 'ts_administration',
              action: 'index',
              breadcrumb: {
                title: t("ts.Settings"),
              },
            },
          },
        ],
        meta: {
          breadcrumb: {
            title: t("ts.Ticket System"),
          }
        }
      },
      ...educationRoutes,
      ...docsRoutes,
      ...tagsRoutes,
      ...erpPackageRoutes,
    ],
    meta: {
      requiresAuth: true,
      breadcrumb: {
        title: t("Home"),
      },
    }
  },
  {
    path: "/regular-reports/:report",
    name: "regular-reports",
    component: () => import("@/pages/regular-reports"),
    meta: {
      requiresAuth: true,
    },
  },
  {
    path: "/deferred-export/download/:deferredExportHash",
    name: "deferred-export.download",
    component: () => import("@/pages/deferred_export/DeferredExportDownload.vue"),
    meta: {
      requiresAuth: true,
    }
  },
  {
    path: "/simple-menu",
    component: SimpleMenu,
    children: [

    ],
    meta: { requiresAuth: true }
  },
  {
    path: "/top-menu",
    component: TopMenu,
    children: [

    ],
    meta: { requiresAuth: true }
  },
  {
    path: '/login',
    component: () => import('@/pages/Guest.vue'),
    meta: { requiresAuth: false },
    children: [
      {
        path: '',
        name: "login",
        component: () => import("@/pages/Login.vue"),
      },
      {
        path: "/reset-password",
        name: "reset-password",
        component: () => import("@/pages/PasswordReset.vue"),
      },
    ]
  },
  {
    path: '/access_deny',
    name: 'access_deny',
    component: () => import('../pages/Deny.vue'),
    meta: { requiresAuth: false }
  },
  {
    path: "/:pathMatch(.*)*",
    component: () => import('../pages/ErrorPage.vue'),
  },
];

const router = createRouter({
  history: createWebHistory(),
  routes,
  scrollBehavior(to, from, savedPosition) {
    return savedPosition || { left: 0, top: 0 };
  },
});

router.beforeEach(async (to, from) => {
  const user = useUserStore()

  if (to.meta.requiresAuth && !user.isLoggedIn()) {
    try {
      await user.getUser();
    }
    catch {
      return {
        path: '/login',
        // save the location we were at to come back later
        query: { redirect: to.fullPath },
      }
    }
  }

  if (Object.prototype.hasOwnProperty.call(to, 'meta')
    && to.meta.table !== undefined && to.meta.action !== undefined) {
    if (user.auth.user && !user.isUserHasPermission(to.meta.table, to.meta.action, undefined, to.meta.onlyAll)) {
      return {
        path: '/access_deny',
      }
    }
  }
  if (to.name === 'clients.products.show') {
    if (to.params.section === 'merchant_crypto_operations' && !await user.isUserHasPermission('crypto_operations', 'index')) {
      return {
        path: '/access_deny',
      }
    }
  }
  if (to.name === "clients.list" && !Object.keys(to.query).includes("filter_field") ) {
    to.query = {
      filter_field: "name",
      status: "1",
      "product_type[]": [
        ProductType["Payport Merchants"].toString(),
        ProductType["Payport Agents"].toString(),
      ],
    };
    return to;
  }
  else if (to.name === "ts.tickets.index"
    && !Object.keys(to.query).filter(param => param !== 'reloadSameUrl').length
  ) {
    const {getOneById} = useFilterPresetStore()
    const settingId = getSettingId()

    const settings: {[key: string]: any} = {
      "status[]": [
        IStatus.New.toString(),
        IStatus.Processing.toString(),
      ],
    }

    if (settingId) {
      const preset = await getOneById(settingId)

      if (!preset) {
        removeSettingData()

        return
      }

      settings['status[]'] = preset.settings.status.map(String) ?? []
      settings["executor[]"] = preset.settings.executor.map(String) ?? []
      settings["source[]"] = preset.settings.source.map(String) ?? []
      settings["creator[]"] = preset.settings.creator.map(String) ?? []
      settings["priority[]"] = preset.settings.priority.map(String) ?? []
      settings["queue[]"] = preset.settings.queue.map(String) ?? []
      settings["topic[]"] = preset.settings.topic.map(String) ?? []

      settings["type_id"] = preset.settings.type_id
      settings["created_at_from"] = preset.settings.created?.split('-')[0]?.trim() ?? ''
      settings["created_at_to"] = preset.settings.created?.split('-')[1]?.trim() ?? ''
      settings["updated_at_from"] = preset.settings.updated?.split('-')[0]?.trim() ?? ''
      settings["updated_at_to"] = preset.settings.updated?.split('-')[1]?.trim() ?? ''
      settings["closed_at_from"] = preset.settings.closed?.split('-')[0]?.trim() ?? ''
      settings["closed_at_to"] = preset.settings.closed?.split('-')[1]?.trim() ?? ''
      settings["date_execution_from"] = preset.settings.executed?.split('-')[0]?.trim() ?? ''
      settings["date_execution_to"] = preset.settings.executed?.split('-')[1]?.trim() ?? ''
    }

    if (isPreviewActivated()) {
      settings["preview"] = '1'
    }

    to.query = {...settings};
    return to;
  }
  else if (to.name === "dashboard"
    && !Object.keys(to.query).filter(param => param !== 'reloadSameUrl').length
  ) {
    const {getOneById} = useFilterPresetStore()
    const settingId = getSettingIdDashboard()

    const settings: {[key: string]: any} = {
      "status[]": [
        IStatus.New.toString(),
      ],
    }

    if (settingId) {
      const preset = await getOneById(settingId)

      if (!preset) {
        removeSettingDataDashboard()

        return
      }

      settings["executor[]"] = preset.settings.executor.map(String) ?? []
      settings["source[]"] = preset.settings.source.map(String) ?? []
      settings["creator[]"] = preset.settings.creator.map(String) ?? []
      settings["priority[]"] = preset.settings.priority.map(String) ?? []
      settings["queue[]"] = preset.settings.queue.map(String) ?? []
      settings["topic[]"] = preset.settings.topic.map(String) ?? []

      settings["type_id"] = preset.settings.type_id
      settings["created_at_from"] = preset.settings.created?.split('-')[0]?.trim() ?? ''
      settings["created_at_to"] = preset.settings.created?.split('-')[1]?.trim() ?? ''
      settings["updated_at_from"] = preset.settings.updated?.split('-')[0]?.trim() ?? ''
      settings["updated_at_to"] = preset.settings.updated?.split('-')[1]?.trim() ?? ''
      settings["closed_at_from"] = preset.settings.closed?.split('-')[0]?.trim() ?? ''
      settings["closed_at_to"] = preset.settings.closed?.split('-')[1]?.trim() ?? ''
      settings["date_execution_from"] = preset.settings.executed?.split('-')[0]?.trim() ?? ''
      settings["date_execution_to"] = preset.settings.executed?.split('-')[1]?.trim() ?? ''
    }

    to.query = {...settings};
    return to;
  }
  else if (to.name === "ts.queue_role_permissions.index" && !Object.keys(to.query).includes("status") ) {
    to.query = {"status": IQueueStatus.Active.toString()};
    return to;
  }
  else if (to.name === 'reports.crm_ts.user_tickets_by_queue.status' && !Object.keys(to.query).includes("with_tickets") ) {
    to.query = {"with_tickets": '1'};
    return to;
  }
  if (to.fullPath == from.fullPath && to.query.reloadSameUrl == "true") {
    router.go(0);
    return;
  }
})

router.afterEach((to) => {
  //
  const breadcrumbStore = useBreadcrumbsStore();
  if (to.meta && to.meta.breadcrumb && Object.hasOwn(to.meta.breadcrumb, "dynamic")) {
    breadcrumbStore.clearCache((to.meta.breadcrumb as { crumbApi: string }).crumbApi);
  }
  breadcrumbStore.setCrumbs(to);
});

export { }

declare module 'vue-router' {
  interface RouteMeta {
    isAdmin?: boolean
    requiresAuth?: boolean
    table?: string,
    action?: string,
    onlyAll?: boolean
  }
}

export default router;
