import {i18n} from "@/utils/i18n";
import {defineAsyncComponent} from "vue";

const {t} = i18n.global;

const initTagsRoutes = () => {
  if (import.meta.env.VITE_TAGS_ENABLED !== '1') {
    return [];
  }

  return [
    {
      path: "/tags",
      meta: {
        table: "tags",
        action: "index",
        breadcrumb: {
          title: t("Tags"),
        }
      },
      children: [
        {
          path: "",
          name: "tags.list",
          component: defineAsyncComponent(() => import("../../node_modules/@erp-npm-packages/tags/dist/components/pages/List")),
        },
        {
          path: "create",
          name: "tags.create",
          component: defineAsyncComponent(() => import("../../node_modules/@erp-npm-packages/tags/dist/components/pages/Form")),

          meta: { 
            table: "tags",
            action: "update",
            breadcrumb: {
              title: t("Add tag"),
            }
          }
        },
        {
          path: ":id",
          name: "tags.edit",
          component: defineAsyncComponent(() => import("../../node_modules/@erp-npm-packages/tags/dist/components/pages/Form")),

          meta: {
            table: "tags",
            action: "update",
            breadcrumb: {
              title: t("Edit tag"),
            },
          },
        },
      ],
    },
    {
      path: "/tags-search",
      name: "tags-search",
      component: defineAsyncComponent(() => import("../../node_modules/@erp-npm-packages/tags/dist/components/pages/Search")),
      meta: {
        breadcrumb: {
          title: t("Search by tags"),
        },
        table: "tags_search",
        action: "index",
      },
    },
  ]
}

export {initTagsRoutes};
