import { defineStore } from "pinia";
import axios, { AxiosError } from "axios";

import {
  IAggregatorParticipant,
  IAggregatorParticipantCreate,
  IAggregatorParticipantFilter,
  IBaseAggregatorParticipant
} from "./interfaces";
import { IPage } from "@/utils/interfaces";

const URL = "/api/aggregator-participants/";

export const useAggregatorParticipantStore = defineStore("aggregator-participants", () => {
  async function getAggregatorParticipants (params: IAggregatorParticipantFilter): Promise<IPage<IAggregatorParticipant>> {
    try {
      const res = await axios.get(URL, { params })
      return res.data
    } catch (err) {
      const error = err as AxiosError;
      throw error.response;
    }
  }
  
  async function createAggregatorParticipant (params: IAggregatorParticipantCreate): Promise<IAggregatorParticipant> {
    try {
      const res = await axios.post(URL, params);
      return res.data;
    } catch (err) {
      const error = err as AxiosError;
      throw error.response;
    }
  }

  async function updateAggregatorParticipant (id: string | number, params: IBaseAggregatorParticipant): Promise<IAggregatorParticipant> {
    try {
      const res = await axios.put(URL + id, { ...params });
      return res.data;
    } catch (err) {
      const error = err as AxiosError;
      throw error.response;
    }
  }

  async function deleteAggregatorParticipant (id: string | number): Promise<void> {
    try {
      axios.delete(URL + id);
    } catch (err) {
      const error = err as AxiosError;
      throw error.response;
    }
  }

  return {
    getAggregatorParticipants,
    createAggregatorParticipant,
    updateAggregatorParticipant,
    deleteAggregatorParticipant,
  };
});
