import { computed, ref, Ref } from "vue";
import { defineStore } from "pinia";
import axios, { AxiosError } from "axios";

import { IAssociationType, IBaseAssociationType } from "@/stores/association/interfaces";
import { IFilterData, IPage } from "@/utils/interfaces";

const URL = "/api/association-types/";

export const useAssociationTypeStore = defineStore('association-types', () => {
  const store = ref({
    list: [] as Array<IAssociationType>,
  });

  const associationTypes: Ref<Array<IAssociationType>> = computed(() => store.value.list);

  async function getAllAssociationTypes (params: IFilterData = {}): Promise<void> {
    try {
      const res = await axios.get(URL + "all", { params });
      store.value.list = res.data;
    } catch (err) {
      const error = err as AxiosError;
      throw error.response;
    }
  }

  async function getAssociationTypes (params: IFilterData = {}): Promise<IPage<IAssociationType>> {
    try {
      const res = await axios.get(URL, { params });
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getAssociationType (id: number|string|null): Promise<IAssociationType> {
    try {
      const res = await axios.get(URL + id);
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function createAssociationType(data: IBaseAssociationType) {
    try {
      await axios.post(URL, data);
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function updateAssociationType (id: number|string|null, data: IBaseAssociationType) {
    try {
      await axios.put(URL + id, data);
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  return {
    associationTypes,
    getAllAssociationTypes,
    getAssociationTypes,
    getAssociationType,
    createAssociationType,
    updateAssociationType,
  }
});
