import { defineStore } from "pinia";
import axios, { AxiosError } from "axios";

import {
  IBaseHolding,
  IHoldingEditForm,
  IHoldingParticipant,
  IHoldingParticipantFilter
} from "./interfaces";
import { IPage } from "@/utils/interfaces";

const URL = "/api/holding-participants/";

export const useHoldingParticipantStore = defineStore("holding-participants", () => {
  async function getHoldingParticipants(params: IHoldingParticipantFilter): Promise<IPage<IHoldingParticipant>> {
    try {
      const res = await axios.get(URL, { params });
      return res.data;
    } catch (err) {
      const error = err as AxiosError;
      throw error.response;
    }
  }

  async function assignHolding (params: IBaseHolding): Promise<void> {
    try {
      await axios.post(URL, params);
    } catch (err) {
      const error = err as AxiosError;
      throw error.response;
    }
  }

  async function editHolding (holding_participant_id: string | number, params: IHoldingEditForm): Promise<void> {
    try {
      await axios.put(URL + holding_participant_id, params);
    } catch (err) {
      const error = err as AxiosError;
      throw error.response;
    }
  }

  return {
    getHoldingParticipants,
    assignHolding,
    editHolding,
  };
});
