import {IFilterData, IPage} from "@/utils/interfaces";
import {defineStore} from "pinia";
import axios from "@/axios";
import {AxiosError} from "axios";
import {ICalendarColor, ICalendarColorUpdateForm} from "@/pages/calendar_colors/interfaces";
import {CalendarColor} from "@/pages/calendar_colors/classes";

const URL = "/api/calendar_colors";

export const useCalendarColorsStore = defineStore("calendar_colors", () => {
  async function getRows(params: IFilterData = {}): Promise<IPage<ICalendarColor>> {
    try {
      const res = await axios.get(URL, {params});
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getOneRow(id: number | string | null): Promise<ICalendarColor> {
    try {
      const res = await axios.get(URL + "/" + id + "/edit");
      return new CalendarColor(res.data);
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function updateRow(id: number | string | null, data: ICalendarColorUpdateForm): Promise<ICalendarColor> {
    try {
      const res = await axios.put(URL + "/" + id, data);
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  return {getRows, getOneRow, updateRow};
});
