import { defineStore } from "pinia";
import axios, { AxiosError } from "axios";
import dayjs from "dayjs";
import CustomParseFormat from "dayjs/plugin/customParseFormat";
dayjs.extend(CustomParseFormat);
import { ICalendarEventParamsDate, ICalendarEventData } from "./interfaces";
import {useI18n} from "vue-i18n";

export const useCalendarEventStore = defineStore("calendar_events", () => {
  const {t} = useI18n();

  const listEduTestStatusesFilter = [
    {text: t("Assigned"), value: 0},
    {text: t("In process"), value: 1},
    {text: t("Failed by timeout"), value: 2},
    {text: t("Not passed"), value: 3},
    {text: t("Awaiting inspection"), value: 5},
  ];

  async function getEvents(params: ICalendarEventParamsDate) : Promise<ICalendarEventData> {
    try {
      const res = await axios.get("/api/calendar_events", { params });
      return res.data;
    } catch (err) {
      const error = err as AxiosError;
      throw error.response;
    }
  }

  return { getEvents, listEduTestStatusesFilter };
});
