import { defineStore } from 'pinia'
import axios from '../../axios'
import { ref, computed } from 'vue'
import {IModelLog} from "@/stores/client_log/interfaces";
import {IPage} from "@/utils/interfaces";

export const useClintLogStore = defineStore('client-log', () => {
  const store = ref({
    clientLog: {} as IPage<IModelLog>,
    clientProductsLog: {} as IPage<IModelLog>,
    clientContactPersonLog: {} as IPage<IModelLog>,
    clientCommunicationsLog: {} as IPage<IModelLog>,
  })

  const getClientLog = computed(() => store.value.clientLog.data)
  const getClientProductsLog = computed(() => store.value.clientProductsLog.data)
  const getClientContactPersonLog = computed(() => store.value.clientContactPersonLog.data)
  const getClientCommunicationsLog = computed(() => store.value.clientCommunicationsLog.data)

  async function clientLog(id: number) {
    try {
      let url = `api/log/clients/${id}`
      if(store.value.clientLog.data && store.value.clientLog.next_page_url === null) {
        return
      }
      if(store.value.clientLog.next_page_url) {
        url = store.value.clientLog.next_page_url
      }

      const resp = await axios.get(url)
      if(store.value.clientLog.data) {
        resp.data.data.data.forEach(function(item: IModelLog) {
          store.value.clientLog.data.push(item)
        });
        store.value.clientLog.next_page_url = resp.data.data.next_page_url
        store.value.clientLog.next_cursor = resp.data.data.next_cursor
      } else {
        store.value.clientLog = resp.data.data
      }

    } catch (error: any) {
      console.log(error)
      throw error.response
    }
  }
  async function clientProductsLog(id: number) {
    try {
      let url = `api/log/clients/products/${id}`
      if(store.value.clientProductsLog.data && store.value.clientProductsLog.next_page_url === null) {
        return
      }
      if(store.value.clientProductsLog.next_page_url) {
        url = store.value.clientProductsLog.next_page_url
      }
      const resp = await axios.get(url)
      if(store.value.clientProductsLog.data) {
        resp.data.data.data.forEach(function(item: IModelLog) {
          store.value.clientProductsLog.data.push(item)
        });
        store.value.clientProductsLog.next_page_url = resp.data.data.next_page_url
        store.value.clientProductsLog.next_cursor = resp.data.data.next_cursor
      } else {
        store.value.clientProductsLog = resp.data.data
      }
    } catch (error: any) {
      throw error.response
    }
  }
  async function clientContactPersonLog(id: number) {
    try {
      let url = `api/log/clients/contact-persons/${id}`
      if(store.value.clientContactPersonLog.data && store.value.clientContactPersonLog.next_page_url === null) {
        return
      }
      if(store.value.clientContactPersonLog.next_page_url) {
        url = store.value.clientContactPersonLog.next_page_url
      }
      const resp = await axios.get(url)
      if(store.value.clientContactPersonLog.data) {
        resp.data.data.data.forEach(function(item: IModelLog) {
          store.value.clientContactPersonLog.data.push(item)
        });
        store.value.clientContactPersonLog.next_page_url = resp.data.data.next_page_url
        store.value.clientContactPersonLog.next_cursor = resp.data.data.next_cursor
      } else {
        store.value.clientContactPersonLog = resp.data.data
      }
    } catch (error: any) {
      throw error.response
    }
  }
  async function clientCommunicationsLog(id: number) {
    try {
      let url = `api/log/clients/communications/${id}`
      if(store.value.clientCommunicationsLog.data && store.value.clientCommunicationsLog.next_page_url === null) {
        return
      }
      if(store.value.clientCommunicationsLog.next_page_url) {
        url = store.value.clientCommunicationsLog.next_page_url
      }
      const resp = await axios.get(url)
      if(store.value.clientCommunicationsLog.data) {
        resp.data.data.data.forEach(function(item: IModelLog) {
          store.value.clientCommunicationsLog.data.push(item)
        });
        store.value.clientCommunicationsLog.next_page_url = resp.data.data.next_page_url
        store.value.clientCommunicationsLog.next_cursor = resp.data.data.next_cursor
      } else {
        store.value.clientCommunicationsLog = resp.data.data
      }
    } catch (error: any) {
      throw error.response
    }
  }

  function clear() {
    store.value.clientLog = {}  as IPage<IModelLog>
    store.value.clientProductsLog = {} as IPage<IModelLog>
    store.value.clientContactPersonLog = {} as IPage<IModelLog>
    store.value.clientCommunicationsLog = {} as IPage<IModelLog>
  }

  return {
    store,
    getClientLog,
    clientLog,
    clientProductsLog,
    clientContactPersonLog,
    getClientProductsLog,
    getClientContactPersonLog,
    clientCommunicationsLog,
    getClientCommunicationsLog,
    clear
  }
})
