import { defineStore } from 'pinia'
import axios from '../../axios'
import { ref, computed } from 'vue'
import {IModelLog} from "@/stores/client_log/interfaces";
import {IPage} from "@/utils/interfaces";

export const useLeadLogStore = defineStore('lead-log', () => {
  const store = ref({
    leadLog: {} as IPage<IModelLog>,
    leadCommunicationsLog: {} as IPage<IModelLog>,
    leadContactPersonLog: {} as IPage<IModelLog>,
  })

  const getLeadLog = computed(() => store.value.leadLog.data)
  const getLeadCommunicationsLog = computed(() => store.value.leadCommunicationsLog.data)
  const getLeadContactPersonLog = computed(() => store.value.leadContactPersonLog.data)

  async function leadLog(id: number) {
    try {
      let url = `api/log/leads/${id}`
      if(store.value.leadLog.data && store.value.leadLog.next_page_url === null) {
        return
      }
      if(store.value.leadLog.next_page_url) {
        url = store.value.leadLog.next_page_url
      }

      const resp = await axios.get(url)
      if(store.value.leadLog.data) {
        resp.data.data.data.forEach(function(item: IModelLog) {
          store.value.leadLog.data.push(item)
        });
        store.value.leadLog.next_page_url = resp.data.data.next_page_url
        store.value.leadLog.next_cursor = resp.data.data.next_cursor
      } else {
        store.value.leadLog = resp.data.data
      }

    } catch (error: any) {
      console.log(error)
      throw error.response
    }
  }
  async function leadCommunicationsLog(id: number) {
    try {
      let url = `api/log/leads/communications/${id}`
      if(store.value.leadCommunicationsLog.data && store.value.leadCommunicationsLog.next_page_url === null) {
        return
      }
      if(store.value.leadCommunicationsLog.next_page_url) {
        url = store.value.leadCommunicationsLog.next_page_url
      }
      const resp = await axios.get(url)
      if(store.value.leadCommunicationsLog.data) {
        resp.data.data.data.forEach(function(item: IModelLog) {
          store.value.leadCommunicationsLog.data.push(item)
        });
        store.value.leadCommunicationsLog.next_page_url = resp.data.data.next_page_url
        store.value.leadCommunicationsLog.next_cursor = resp.data.data.next_cursor
      } else {
        store.value.leadCommunicationsLog = resp.data.data
      }
    } catch (error: any) {
      throw error.response
    }
  }
  async function leadContactPersonLog(id: number) {
    try {
      let url = `api/log/leads/contact-persons/${id}`
      if(store.value.leadContactPersonLog.data && store.value.leadContactPersonLog.next_page_url === null) {
        return
      }
      if(store.value.leadContactPersonLog.next_page_url) {
        url = store.value.leadContactPersonLog.next_page_url
      }
      const resp = await axios.get(url)
      if(store.value.leadContactPersonLog.data) {
        resp.data.data.data.forEach(function(item: IModelLog) {
          store.value.leadContactPersonLog.data.push(item)
        });
        store.value.leadContactPersonLog.next_page_url = resp.data.data.next_page_url
        store.value.leadContactPersonLog.next_cursor = resp.data.data.next_cursor
      } else {
        store.value.leadContactPersonLog = resp.data.data
      }
    } catch (error: any) {
      throw error.response
    }
  }

  function clear() {
    store.value.leadLog = {}  as IPage<IModelLog>
    store.value.leadCommunicationsLog = {} as IPage<IModelLog>
    store.value.leadContactPersonLog = {} as IPage<IModelLog>
  }

  return {
    store,
    getLeadLog,
    getLeadCommunicationsLog,
    leadLog,
    leadCommunicationsLog,
    leadContactPersonLog,
    getLeadContactPersonLog,
    clear
  }
})
