import {IFilterData, IPage} from "@/utils/interfaces";
import {defineStore} from "pinia";
import axios from "@/axios";
import {AxiosError} from "axios";
import {ICoefficient, ICoefficientUpdateForm} from "@/pages/coefficients/interfaces";
import {Coefficient} from "@/pages/coefficients/classes";

const URL = "/api/coefficients";

export const useCoefficientStore = defineStore("coefficients", () => {
  async function getRows(params: IFilterData = {}): Promise<IPage<ICoefficient>> {
    try {
      const res = await axios.get(URL, {params});
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getOneRow(id: number | string | null): Promise<ICoefficient> {
    try {
      const res = await axios.get(URL + "/" + id + "/edit");
      return new Coefficient(res.data);
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function createRow(params: ICoefficientUpdateForm): Promise<ICoefficient> {
    try {
      const res = await axios.post(URL, params);
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function updateRow(id: number | string | null, data: ICoefficientUpdateForm): Promise<ICoefficient> {
    try {
      const res = await axios.put(URL + "/" + id, data);
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function deleteRow(id: number): Promise<ICoefficient> {
    try {
      const res = await axios.delete(URL + '/' + id);
      return res.data.data;
    }
    catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function setClientCoefficient(params: IFilterData = {}): Promise<ICoefficient> {
    try {
      const res = await axios.post(URL + '/set_client_coefficient', params);
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  return {getRows, getOneRow, createRow, updateRow, setClientCoefficient, deleteRow};
});
