import { IComment, IPage } from "@/utils/interfaces";
import axios, { AxiosError } from "axios";
import { defineStore } from "pinia";

export const useCommentStore = defineStore("comments", () => {
  async function getComments(params?: {
    commentable_type?: string,
    commentable_id?: number,
    perPage?: string | number | undefined,
    page?: string | number | undefined,
    is_pinned?: 0 | 1,
    without_pagination?: 0 | 1,
  }): Promise<IPage<IComment>> {
    try {
      const res = await axios.get("/api/comments", { params });
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function createComment(params: {
    commentable_type: string,
    commentable_id: number | string,
    comment: string | null,
    blacklist_id?: number | null,
  }): Promise<IComment> {
    try {
      const res = await axios.post("/api/comments", params);
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }
  
  async function updateComment (id: string|number|null, data: { comment: string | null }) {
    try {
      await axios.put("/api/comments/" + id, data);
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function pinnedComment (commentId: string|number) {
    try {
      const comment = await axios.patch("/api/comments/pinned/" + commentId);

      return comment.data as IComment
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function unPinnedComment (commentId: string|number) {
    try {
      const comment = await axios.patch("/api/comments/un-pinned/" + commentId);

      return comment.data as IComment
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  return { getComments, createComment, updateComment, pinnedComment, unPinnedComment };
});
