import { IUserShort } from "@/pages/users/interfaces";

enum ICommunicatableType {
  ServiceProvider = "App\\Models\\ServiceProvider",
  Client = "App\\Models\\Client",
  Lead = "App\\Models\\Lead",
  Trader = "App\\Models\\Trader",
}

interface ICommunicationParamsDate {
  filter_field?: string,
  filter_value?: string,
  communication_type?: string,
  communicatable_type?: string,
  communicatable_id?: string,
  "status[]"?: Array<string>,
  date_begin?: string,
  date_end?: string,
  show_all?: number,
  show_own?: number,
  show_own_department?: number,
}

interface ICommunicationType {
  readonly id: string,
  name: string,
  name_original: string,
}

interface ICommunicationCall {
  readonly id: string | number,
  communication_id: string | number,
  status: string,
  status_name: string,
  datetime: string,
  duration: string | number | null,
  reminder: string | number | null,
}

interface ICommunicationStatus {
  [key: string]: string
}

interface ICommunicationTaskPriority {
  [key: string]: string
}

interface ICommunicationMeeting {
  readonly id: string | number,
  communication_id: string | number,
  status: string,
  status_name: string,
  datetime: string,
  duration: string | number | null,
  reminder: string | number | null,
}

interface ICommunicationTask {
  readonly id: string | number,
  communication_id: string | number,
  status: string,
  status_name: string,
  date_start: string | null,
  date_complete: string | null,
  priority: string | number,
  reminder_datetime: string | null,
}

interface ICommunicatable {
  readonly id: string | number,
  name: string,
}

type ICommunicationDetails = ICommunicationCall | ICommunicationMeeting | ICommunicationTask;

interface ICommunication {
  readonly id: string | number,
  topic: string,
  description: string,
  communicatable_type: ICommunicatableType | null,
  communicatable: { id: string | number, name: string } | null,
  communication_details: ICommunicationDetails,
  responsible_user: IUserShort,
  communication_type: ICommunicationType,
}

interface ICommunicationData {
  communications: Array<ICommunication>,
}

interface ICommunicationCallForm {
  communication_type: "Call",
  communicatable_type: string,
  communicatable_id: string,
  topic: string,
  responsible_user_id: string,
  status: string,
  datetime: string,
  duration?: string | null,
  description?: string | null,
  reminder?: string | null,
}

interface ICommunicationMeetingForm {
  communication_type: "Meeting",
  communicatable_type: string,
  communicatable_id: string,
  topic: string,
  responsible_user_id: string,
  status: string,
  datetime: string,
  duration?: string | null,
  description?: string | null,
  reminder?: string | null,
}

interface ICommunicationTaskForm {
  communication_type: "Task",
  communicatable_type: string,
  communicatable_id: string,
  topic: string,
  responsible_user_id?: string,
  responsible_user_ids: Array<string>,
  responsible_departments: Array<string>,
  status: string,
  date_start: string,
  priority: string,
  date_complete?: string | null,
  description?: string | null,
  reminder_date?: string | null,
  reminder_time?: string | null,
  is_bulk?: boolean,
}

type ICommunicationForm = ICommunicationCallForm | ICommunicationMeetingForm | ICommunicationTaskForm;

interface ICommunicationOccupied {
  id: number,
  communicatable_type: string,
  communicatable_id: number,
  time: string,
  communication_type: ICommunicationType,
  communicatable: ICommunicatable,
  topic: string,
}

export type {
  ICommunicationParamsDate,
  ICommunicationCall,
  ICommunicationMeeting,
  ICommunicationTask,
  ICommunicationDetails,
  ICommunication,
  ICommunicationData,
  ICommunicationType,
  ICommunicationStatus,
  ICommunicationTaskPriority,
  ICommunicationForm,
  ICommunicationCallForm,
  ICommunicationMeetingForm,
  ICommunicationTaskForm,
  ICommunicatable,
  ICommunicationOccupied,
};

export {
  ICommunicatableType,
};