import { defineStore } from 'pinia'
import axios from '@/axios'
import { ref, computed } from 'vue'
import { PaginationInterface } from "@/components/Pagination/interfaces";
import type { ContactPerson } from "@/stores/contact_person/interfaces";
import {IFilterData} from "@/utils/interfaces";
import { AxiosError } from "axios";

export const useContactPersonStore = defineStore('contact_person', () => {
  const store = ref({
    list: [] as ContactPerson[],
    meta: {} as PaginationInterface,
    contactPerson: {} as ContactPerson
  })

    interface ContactPersons {
        list: ContactPerson[],
        meta: PaginationInterface
        contactPerson: ContactPerson
    }

    const getContactPersons = computed(() => store.value.list)
    const pagination = computed(() => store.value.meta)
    const getContactPerson = computed(() => store.value.contactPerson)

    async function getContactPersonsList(filterData: IFilterData = {}) {
      try {
        const resp = await axios.get(`api/contact-persons`, {params: filterData})
        store.value.list = resp.data.data
        store.value.meta = resp.data
      } catch (error: any) {
        throw error.response
      }
    }

    async function getContactPersonId (id: string) {
      try {
        const resp = await axios.get(`api/contact-persons/${id}`)
        store.value.contactPerson = resp.data
        return resp.data
      } catch (error: any) {
        throw error.response
      }
    }

    async function saveContactPerson ($payload: object) {
      try {
        const resp = await axios.post(`api/contact-persons`, $payload)
        store.value.contactPerson = resp.data
      } catch (error: any) {
        throw error.response
      }
    }

    async function updateContactPerson ($payload: object, id: string) {
      try {
        const resp = await axios.put(`api/contact-persons/${id}`, $payload)
        store.value.contactPerson = resp.data
      } catch (error: any) {
        throw error.response
      }
    }

    async function deleteContactPerson (id: string) {
      try {
        const resp = await axios.delete(`api/contact-persons/${id}`)
        //find and delete department with id in list
      } catch (error: any) {
        throw error.response
      }
    }

    async function getAllContacts(params?: { ids?: Array<string> }) {
      try {
        const res = await axios.get("/api/contact-persons/all", { params });
        return res.data;
      } catch (error) {
        const err = error as AxiosError;
        throw err.response;
      }
    }

    return {
      store,
      getContactPersons,
      getContactPerson,
      getContactPersonsList,
      getContactPersonId,
      saveContactPerson,
      updateContactPerson,
      deleteContactPerson,
      getAllContacts,
      pagination
    }
})
