import { ref } from "vue";
import {IFilterData, IPage} from "@/utils/interfaces";
import { IBaseCountry, ICountry } from "@/pages/countries/interfaces";
import axios from "@/axios";
import { AxiosError } from "axios";
import { defineStore } from "pinia";

export const useCountryStore = defineStore("countries", () => {
  const store = ref({
    list: [] as Array<ICountry>
  });

  async function getAllCountries() {
    try {
      const res = await axios.get("/api/countries/all");
      store.value.list = res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getCountries (params: IFilterData = {}): Promise<IPage<ICountry>> {
    try {
      const res = await axios.get("/api/countries", { params });
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getCountry (id: number|string|null): Promise<ICountry> {
    try {
      const res = await axios.get("/api/countries/" + id);
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function createCountry(data: IBaseCountry) {
    try {
      await axios.post("/api/countries", data);
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function updateCountry(id: number|string|null, data: IBaseCountry) {
    try {
      await axios.put("/api/countries/" + id, data);
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  return { store, getAllCountries, getCountries, getCountry, createCountry, updateCountry };
});
