import {IFilterData, IPage} from "@/utils/interfaces";
import {defineStore} from "pinia";
import axios from "@/axios";
import {AxiosError} from "axios";
import {ICriticality, ICriticalityUpdateForm} from "@/pages/criticality/interfaces";
import {Criticality} from "@/pages/criticality/classes";

const URL = "/api/criticality";

export const useCriticalityStore = defineStore("criticality", () => {
  async function getRows(params: IFilterData = {}): Promise<IPage<ICriticality>> {
    try {
      const res = await axios.get(URL, {params});
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getOneRow(id: number | string | null): Promise<ICriticality> {
    try {
      const res = await axios.get(URL + "/" + id + "/edit");
      return new Criticality(res.data);
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function createRow(params: ICriticalityUpdateForm): Promise<ICriticality> {
    try {
      const res = await axios.post(URL, params);
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function updateRow(id: number | string | null, data: ICriticalityUpdateForm): Promise<ICriticality> {
    try {
      const res = await axios.put(URL + "/" + id, data);
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function deleteRow(id: number): Promise<ICriticality> {
    try {
      const res = await axios.delete(URL + '/' + id);
      return res.data.data;
    }
    catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  return {getRows, getOneRow, createRow, updateRow, deleteRow};
});
