import {defineStore} from "pinia";
import axios from "@/axios";
import {IPage} from "@/utils/interfaces";
import {IDeferredExport} from "@/stores/deferred_export/interfaces";
import {computed, ref, watch} from "vue";
import {useFileStore} from "@/stores/file/file";
import {getDeferredExportName} from "@/stores/deferred_export/helpers";

export const useDeferredExport = defineStore('downloads', () => {
  const state = ref({
    hasDeferredExportInProgress: localStorage.getItem("hasDeferredExportInProgress") != null
      ? !!parseInt(localStorage.getItem("hasDeferredExportInProgress") as string)
      : false,
  });

  const hasDeferredExportInProgress = computed({
    get: () => state.value.hasDeferredExportInProgress,
    set: (newValue) => {
      state.value.hasDeferredExportInProgress = newValue
    }
  });

  const getList = async (params?: {page?: number}) => {
    try {
      const response = await axios.get('api/deferred-export', {
        params,
      })

      return response.data as IPage<IDeferredExport>
    }
    catch (e) {
      throw e
    }
  }

  const remove = async (id: string | number) => {
    try {
      await axios.delete('api/deferred-export/' + id)
    }
    catch (e) {
      throw e
    }
  }

  const getOne = async (id: string | number) => {
    try {
      const response = await axios.get('api/deferred-export/show/' + id)

      return response.data as IDeferredExport
    }
    catch (e) {
      throw null
    }
  }

  const downloadDeferredExport  = async (hash: string) => {
    const id = atob(hash)
    const deferredExport = await getOne(id)

    if (!deferredExport) {
      return
    }

    await useFileStore().downloadFile(
      deferredExport.file?.id as string,
      getDeferredExportName(deferredExport),
    )
  }

  watch(hasDeferredExportInProgress, (newValue) => {
    localStorage.setItem("hasDeferredExportInProgress", (+newValue).toString());
  });

  return {
    getList,
    remove,
    hasDeferredExportInProgress,
    downloadDeferredExport,
  }
})
