import {defineStore} from 'pinia'
import axios from '../../axios'
import {computed, ref} from 'vue'
import {PaginationInterface} from "@/components/Pagination/interfaces";
import {ISelect} from "@/utils/interfaces";
import {IDepartment, IDepartmentPayload} from "@/stores/department/interfaces";

export const useDepartmentStore = defineStore('department', () => {
  const store = ref({
    list: [] as IDepartment[],
    meta: {} as PaginationInterface,
    select_list: [] as ISelect[],
    select_list_active: [] as ISelect[],
    department: {} as IDepartment,
    department_users_select_list: [] as ISelect[]
  })

  const getDepartments = computed(() => store.value.list)
  const getDepartmentsSelect = computed(() => store.value.select_list)
  const getDepartmentsSelectActive = computed(() => store.value.select_list_active)
  const pagination = computed(() => store.value.meta)
  const getDepartment = computed(() => store.value.department)
  const getUsersSelect = computed(() => store.value.department_users_select_list)

  async function getDepartmentsList(filterData: object = {}) {
    try {
      const resp = await axios.get(`api/departments`, {params: filterData})
      store.value.list = resp.data.data
      store.value.meta = resp.data
    } catch (error: any) {
      throw error.response
    }
  }

  async function getDepartmentsSelectList() {
    try {
      const resp = await axios.get(`api/departments/list`)
      store.value.select_list = resp.data.data

      return resp.data.data as ISelect[]
    } catch (error: any) {
      throw error.response
    }
  }

  async function getDepartmentsSelectListActive() {
    try {
      const resp = await axios.get(
        `api/departments/list`,
        {
          params: {
            status: [ 1 ],
          }
        });
      store.value.select_list_active = resp.data.data
    } catch (error: any) {
      throw error.response
    }
  }

  async function getDepartmentById (id: string) {
    try {
      const resp = await axios.get(`api/departments/${id}`)
      store.value.department = resp.data
      return resp.data
    } catch (error: any) {
      throw error.response
    }
  }

  async function saveDepartment ($payload: IDepartmentPayload) {
    try {
      const resp = await axios.post(`api/departments`, $payload)
      store.value.department = resp.data
    } catch (error: any) {
      throw error.response
    }
  }

  async function updateDepartment ($payload: IDepartmentPayload, id: string) {
    try {
      const resp = await axios.put(`api/departments/${id}`, $payload)
      store.value.department = resp.data
    } catch (error: any) {
      throw error.response
    }
  }

  async function deleteDepartment (id: string) {
    try {
      const resp = await axios.delete(`api/departments/${id}`)
      //find and delete department with id in list
    } catch (error: any) {
      throw error.response
    }
  }

  async function fetchUsersSelectList(id: string): Promise<ISelect[]> {
    try {
      const response = await axios.get<ISelect[]>(`api/departments/${id}/users-select`)
      store.value.department_users_select_list = response.data
      return response.data;
    } catch (error: any) {
      throw error.response
    }
  }

  async function fetchDepartmentBySlug(slug: string): Promise<IDepartment | null> {
    try {
      const response = await axios.get<{data: IDepartment}>(`api/departments/slugs/` + slug)

      return response.data.data
    } catch (error: any) {
      throw error
    }
  }

  return {
    store,
    getDepartments,
    getDepartment,
    getDepartmentsList,
    getDepartmentById,
    saveDepartment,
    updateDepartment,
    deleteDepartment,
    pagination,
    getDepartmentsSelectList,
    getDepartmentsSelectListActive,
    getUsersSelect,
    getDepartmentsSelect,
    getDepartmentsSelectActive,
    fetchUsersSelectList,
    fetchDepartmentBySlug,
  }
})
