import {defineStore} from "pinia";
import {computed, ref} from "vue";
import {IDepartmentGrade, IDepartmentGradeReport, IPayload} from "@/stores/department_grades/interfaces";
import axios from "@/axios";
import {IPage} from "@/utils/interfaces";

export const useDepartmentGradesStore = defineStore('department-grades', () => {
  const store = ref({
    list: [] as IDepartmentGrade[],
    meta: {} as IPage<IDepartmentGrade[]>,
    grade: {} as IDepartmentGrade,
    updatedId: null as number | null,
    report: {} as IDepartmentGradeReport[]
  })

  const grades = computed(() => store.value.list)
  const pagination = computed(() => store.value.meta)
  const grade = computed(() => store.value.grade)
  const updatedId = computed(() => store.value.updatedId)
  const report = computed(() => store.value.report)

  function setUpdatedId(id: number) {
    store.value.updatedId = id
  }

  function discardUpdatedId() {
    store.value.updatedId = null
  }

  async function remove(id: number) {
    try {
      await axios.delete(`api/department-grades/${id}`)
    } catch (error: any) {
      throw error.response
    }
  }

  async function getDepartmentGradeList(query: object, departmentId: string) {
    try {
      const resp = await axios.get(`api/departments/${departmentId}/grades`, {
        params: query,
      })

      store.value.list = resp.data.data
      store.value.meta = resp.data
    } catch (error: any) {
      throw error.response
    }
  }

  async function getGrade(id: string) {
    try {
      const resp = await axios.get(`api/department-grades/${id}`)
      store.value.grade = resp.data;
    } catch (error: any) {
      throw error.response
    }
  }

  async function create(payload: IPayload, id: string) {
    try {
      await axios.post(`api/departments/${id}/grades`, payload)
    } catch (error: any) {
      throw error.response
    }
  }

  async function update(payload: IPayload, id: string) {
    try {
      await axios.patch(`api/department-grades/${id}`, payload)
    } catch (error: any) {
      throw error.response
    }
  }

  async function getMonthlyReport(id: string, payload?: { filter_value: string }) {
    try {
      const res = await axios.get(`api/departments/${id}/grades/report-monthly`, {
        params: payload
      })
      store.value.report = res.data
    } catch (error: any) {
      throw error.response
    }
  }

  async function getQuarterlyReport(id: string, payload?: {filter_value: string}) {
    try {
      const res = await axios.get(`api/departments/${id}/grades/report-quarterly`, {
        params: payload,
      })
      store.value.report = res.data
    } catch (error: any) {
      throw error.response
    }
  }

  return {
    grades,
    pagination,
    grade,
    updatedId,
    report,
    create,
    update,
    remove,
    setUpdatedId,
    discardUpdatedId,
    getDepartmentGradeList,
    getMonthlyReport,
    getQuarterlyReport,
    getGrade,
  }
})
