import { defineStore } from 'pinia'
import { ref } from 'vue'
import axios from '../../axios'
import { AxiosError } from "axios";
import { ISelect } from "@/utils/interfaces";
import { IDomain } from "@/stores/domain/interfaces";
import { IFilterData, IPage } from "@/utils/interfaces";

export const useDomainStore = defineStore("domains", () => {
  const store = ref({
    list: [] as Array<IDomain>,
    isListLoading: false as boolean,
    selectList: [] as ISelect [],
  });

  async function getDomainsSelectList() {
    try {
      const resp = await axios.get(`api/domains/list`)
      store.value.selectList = resp.data.data
    } catch (error: any) {
      throw error.response
    }
  }

  async function getDomains (params: IFilterData = {}): Promise<IPage<IDomain>> {
    try {
      store.value.isListLoading = false
      const res = await axios.get("/api/domains", { params });
      store.value.isListLoading = true
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getDomain (id: number|string|null): Promise<IDomain> {
    try {
      const res = await axios.get("/api/domains/" + id);
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function createDomain(data: IDomain) {
    try {
      await axios.post("/api/domains", data);
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function updateDomain(id: number|string|null, data: IDomain) {
    try {
      await axios.put("/api/domains/" + id, data);
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  return { store, getDomainsSelectList, getDomains, getDomain, createDomain, updateDomain };
});
