import {IFilterData, IPage} from "@/utils/interfaces";
import {IFavorite, IFavoriteForList, IFavoriteUpdateForm} from "@/pages/favorites/interfaces";
import {Favorite} from "@/pages/favorites/classes";
import {defineStore} from "pinia";
import axios from "@/axios";
import {AxiosError} from "axios";

const URL = "/api/favorites";

export const useFavoritesStore = defineStore("favorites", () => {
  async function getRows(params: IFilterData = {}): Promise<IPage<IFavoriteForList>> {
    try {
      const res = await axios.get(URL, {params});
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getOneRow(id: number | string | null): Promise<IFavorite> {
    try {
      const res = await axios.get(URL + "/" + id + "/edit");
      return new Favorite(res.data);
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function createRow(params: IFavoriteUpdateForm): Promise<IFavorite> {
    try {
      const res = await axios.post(URL, params);
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function deleteRow(id: number | string) {
    try {
      const res = await axios.delete(URL + "/" + id);
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  return {getRows, getOneRow, createRow, deleteRow};
});
