import { defineStore } from "pinia";
import axios, { AxiosError } from "axios";

import { ICollectable } from "@/components/ElementCollection/interfaces";

const URL = "/api/ips/";

export const useIpStore = defineStore("ip", () => {
  async function getIps (ipable_type: string, ipable_id: string | number): Promise<Array<ICollectable>> {
    try {
      const res = await axios.get(URL, {
        params: {
          ipable_type,
          ipable_id,
        }
      });
      return res.data;
    } catch (err) {
      const error = err as AxiosError;
      throw error.response;
    }
  }

  async function createIp (ipable_type: string, ipable_id: string | number, value: string): Promise<ICollectable> {
    try {
      const res = await axios.post(URL, {
        ipable_type,
        ipable_id,
        value,
      });
      return res.data;
    } catch (err) {
      const error = err as AxiosError;
      throw error.response;
    }
  }

  async function updateIp (id: number | string, value: string): Promise<void> {
    try {
      await axios.put(URL + id, { value });
    } catch (err) {
      const error = err as AxiosError;
      throw error.response;
    }
  }

  async function deleteIp (id: number | string): Promise<void> {
    try {
      await axios.delete(URL + id);
    } catch (err) {
      const error = err as AxiosError;
      throw error.response;
    }
  }

  return {
    getIps,
    createIp,
    updateIp,
    deleteIp,
  };
});
