import {defineStore} from "pinia";
import axios from "@/axios";
import {LocationQuery} from "vue-router";
import {IPage} from "@/utils/interfaces";
import {ILimitedSearchLog, ILimitedSearchVault} from "@/pages/reports/LimitedSearch/interface";

const URL = "/api/limited-search/";

export const useLimitedSearchStore = defineStore('limited_search', () => {
  async function getParticipantsInfo(params: {type: string, query: string, category: string | number}) {
    try {
      const response = await axios.get(URL + 'participants', {params})

      return response.data
    }
    catch (e) {
      throw e
    }
  }

  async function getWebsitesInfo(params: {type: string, query: string, category: string | number}) {
    try {
      const response = await axios.get(URL + 'websites', {params})

      return response.data
    }
    catch (e) {
      throw e
    }
  }

  async function getLimit(type: 'Client' | 'Lead') {
    try {
      const response = await axios.get(URL + 'limit', {params: {type}})

      return response.data
    }
    catch (e) {
      throw e
    }
  }

  async function getLogs(params: LocationQuery | null = null) {
    try {
      const response = await axios.get(URL + 'logs', {params})

      return response.data as IPage<ILimitedSearchLog>
    }
    catch (e) {
      throw e
    }
  }

  async function getVault(params: LocationQuery | null = null) {
    try {
      const response = await axios.get(URL + 'vault', {params})

      return response.data as IPage<ILimitedSearchVault>
    }
    catch (e) {
      throw e
    }
  }

  return {
    getParticipantsInfo,
    getWebsitesInfo,
    getLimit,
    getVault,
    getLogs,
  }
})