import { defineStore } from "pinia";
import { computed, ref, watch } from "vue";
import axios, { AxiosError } from "axios";

import { INotification } from "./interfaces";
import { IPage } from "@/utils/interfaces";
import { Icon } from "@/base-components/Lucide/Lucide.vue";

const URL = "/api/notifications/";

export const useNotificationStore = defineStore("notification", () => {
  const state = ref({
    hasNewNotifications: localStorage.getItem("hasNewNotification") != null
      ? !!parseInt(localStorage.getItem("hasNewNotification") as string)
      : false,
    soundOn: localStorage.getItem("soundOn") != null
      ? !!parseInt(localStorage.getItem("soundOn") as string)
      : true,
    icon: null as Icon | null,
    color: null as string | null,
  });

  const hasNewNotifications = computed({
    get: () => state.value.hasNewNotifications,
    set: (newValue) => {
      state.value.hasNewNotifications = newValue
    }
  });

  const soundOn = computed(() => state.value.soundOn);
  
  /**
   * Icon and color are for custom notifications only (CustomNotification.vue)
   */
  const icon = computed(() => state.value.icon);
  const color = computed(() => state.value.color);

  const setSound = (value: boolean) => {
    state.value.soundOn = value;
  };

  const setCustomIconStyle = (style: { icon: Icon | null, color: string | null }): void => {
    state.value.icon = style.icon;
    state.value.color = style.color;
  };

  watch(hasNewNotifications, (newValue) => {
    localStorage.setItem("hasNewNotification", (+newValue).toString());
  });

  watch(soundOn, (newValue) => {
    localStorage.setItem("soundOn", (+newValue).toString());
  });

  async function getNotifications(params?: { page? : number | null }): Promise<IPage<INotification>> {
    try {
      const res = await axios.get(URL, { params });
      return res.data;
    } catch (err) {
      const error = err as AxiosError;
      throw error.response;
    }
  }

  async function setNotificationRead(notification_id: string | number) {
    try {
      const res = await axios.put(URL + notification_id, { is_closed: true });
      return res.data;
    } catch (err) {
      const error = err as AxiosError;
      throw error.response;
    }
  }

  async function setReadAll(): Promise<void> {
    try {
      await axios.put(URL + "set-read-all");
    } catch (err) {
      const error = err as AxiosError;
      throw error.response;
    }
  }

  return {
    hasNewNotifications,
    soundOn,
    icon,
    color,
    setSound,
    getNotifications,
    setNotificationRead,
    setReadAll,
    setCustomIconStyle,
  }
});
