import { defineStore } from "pinia";
import axios, { AxiosError } from "axios";
import { INotificationScheduleForm } from "./interfaces";

export const useNotificationScheduleStore = defineStore("notification_schedule", () => {
  async function getStatuses(){
    try {
      const res = await axios.get("/api/notification-schedule/statuses");
      return res.data;
    } catch (err) {
      const error = err as AxiosError;
      throw error.response;
    }
  }

  async function create(params: INotificationScheduleForm) {
    try {
      await axios.post("/api/notification-schedule", params);
    } catch (err) {
      const error = err as AxiosError;
      throw error.response;
    }
  }

  async function getPaginated(params: object) {
    try {
      const res = await axios.get("/api/notification-schedule", { params });
      return res.data;
    } catch (err) {
      const error = err as AxiosError;
      throw error.response;
    }
  }

  async function getNotification(id: number | string) {
    try {
      const res = await axios.get("/api/notification-schedule/" + id);
      return res.data;
    } catch (err) {
      const error = err as AxiosError;
      throw error.response;
    }
  }

  async function update(id: number | string, params: object) {
    try {
      await axios.put("/api/notification-schedule/" + id, params);
    } catch (err) {
      const error = err as AxiosError;
      throw error.response;
    }
  }

  async function run(id: number | string) {
    try {
      await axios.post("/api/notification-schedule/run/" + id);
    } catch (err) {
      const error = err as AxiosError;
      throw error.response;
    }
  }

  async function copy(id: number | string) {
    try {
      await axios.put("/api/notification-schedule/copy/" + id);
    } catch (err) {
      const error = err as AxiosError;
      throw error.response;
    }
  }

  async function getTSParticipants() {
    try {
      const res = await axios.get("/api/ts/ticket-participant/all");
      return res.data;
    } catch (err) {
      const error = err as AxiosError;
      throw error.response;
    }
  }

  return {
    getStatuses,
    create,
    getPaginated,
    getNotification,
    update,
    run,
    copy,
    getTSParticipants,
  };
});
