import { defineStore } from "pinia";
import { INotificationType, INotificationTypeForm } from "../notification_type/interfaces";
import axios, { AxiosError } from "axios";
import { IPage } from "@/utils/interfaces";

export const useNotificationTypeStore = defineStore("notification_type", () => {
  async function getPaginated (params?: { name?: string }): Promise<IPage<INotificationType>> {
    try {
      const res = await axios.get("/api/notification-types", { params });
      return res.data;
    } catch (err) {
      const error = err as AxiosError;
      throw error.response;
    }
  }
  
  async function getSingle (id: string | number): Promise<INotificationTypeForm> {
    try {
      const res = await axios.get("/api/notification-types/" + id);
      return res.data;
    } catch (err) {
      const error = err as AxiosError;
      throw error.response;
    }
  }
  
  async function create (params: INotificationTypeForm): Promise<INotificationType> {
    try {
      const res = await axios.post("/api/notification-types", params);
      return res.data;
    } catch (err) {
      const error = err as AxiosError;
      throw error.response;
    }
  }

  async function update (id: number | string, params: INotificationTypeForm): Promise<INotificationType> {
    try {
      const res = await axios.put("/api/notification-types/" + id, params);
      return res.data;
    } catch (err) {
      const error = err as AxiosError;
      throw error.response;
    }
  }

  async function getStatuses () {
    try {
      const res = await axios.get("/api/notification-types/statuses");
      return res.data;
    } catch (err) {
      const error = err as AxiosError;
      throw error.response;
    }
  }

  async function all () {
    try {
      const res = await axios.get("/api/notification-types/all");
      return res.data;
    } catch (err) {
      const error = err as AxiosError;
      throw error.response;
    }
  }

  return {
    getPaginated,
    getSingle,
    create,
    update,
    getStatuses,
    all,
  };
});
