import { defineStore } from "pinia";
import axios from "@/axios";
import { AxiosError, isAxiosError } from "axios";
import {computed, ref} from "vue";
import {PaginationInterface} from "@/components/Pagination/interfaces";
import {IOtrsTicket} from "@/stores/otrs/interfaces";
import {IFilterData, ISelect} from "@/utils/interfaces";

export const useOtrsStore = defineStore("otrs", () => {
  const store = ref({
    list: [] as IOtrsTicket[],
    item: {} as IOtrsTicket,
    meta: {} as PaginationInterface,
    stateTypesList: [] as ISelect[],
  })

  const getList = computed(() => store.value.list)
  const getStateTypesList = computed(() => store.value.stateTypesList)
  const getItem = computed(() => store.value.item)
  const pagination = computed(() => store.value.meta)
  async function list(filterData: IFilterData) {
    try {
      store.value.list = []
      const resp = await axios.get(`api/otrs`, {params: filterData})
      store.value.list = resp.data.data
      store.value.meta = resp.data
    } catch (error: unknown) {
      if(isAxiosError(error)) {
        throw error.response
      }
      throw error
    }
  }
  async function ststeTypesList() {
    try {
      store.value.list = []
      const resp = await axios.get(`api/otrs/list`)
      store.value.stateTypesList = resp.data.data
    } catch (error: unknown) {
      if(isAxiosError(error)) {
        throw error.response
      }
      throw error
    }
  }

  async function save(payload: object) {
    try {
      const resp = await axios.post(`api/otrs`, payload)
      return resp.data
    } catch (error: unknown) {
      if(isAxiosError(error)) {
        throw error.response
      }
      throw error
    }
  }

  return { save, list, getList, pagination, getStateTypesList, ststeTypesList };
});
