import { defineStore } from 'pinia'
import axios from '../axios'
import { ref, computed} from 'vue'
import {PaginationInterface} from "@/components/Pagination/interfaces";
import {LocationQueryValue} from "vue-router";
import { useI18n } from 'vue-i18n';

export type PermissionAttrs = {
  value: string,
  list: Array<{ text: string, value: string }>,
  translate: string,
};

export type Permission = {
  (key: string): PermissionAttrs,
};

export type RolePermissions = {
  [ key: string ]: Permission,
};

export type Setting = "all" | "none" | "own" | "own_and_departments";

export const usePermissionsStore = defineStore('permissions', () => {
  const { t } = useI18n();

    interface Permission {
        [key: string]: {
            [key: string]: {
                [key: string]: {
                    list: [{
                        text: string,
                        value: string
                    }],
                    value: string,
                    translate: string
                }
            }
        }
    }

    const rightOptions = [
      t("All"),
      t("No access"),
      t("Own"),
      t("Own department"),
    ];

    async function updateRolePermission (id: number | string, params: RolePermissions) {
      try {
        await axios.post(`api/permissions/update-role/${id}`, params)
      } catch (error: any) {
        throw error.response
      }
    }

    async function getRolePermissions (id: number | string): Promise<{ data: RolePermissions, permissions_by_group: [] }> {
      try {
        const resp = await axios.get(`api/permissions/by-role/${id}`);
        return resp.data;
        
      } catch (error: any) {
        throw error.response
      }
    }


    return {
      updateRolePermission,
      getRolePermissions,
      rightOptions,
    };
})
