import { defineStore } from 'pinia'
import axios from '../../axios'
import { isAxiosError } from "axios";
import { ref, computed } from 'vue'
import { IRolePermissionsLog } from "@/stores/client_log/interfaces";
import { IPage } from "@/utils/interfaces";
import { IFilterData, ISelect } from "@/utils/interfaces";

export const usePermissionsLogStore = defineStore('permissions-log', () => {
  const store = ref({
    permissionsLog: {} as IPage<IRolePermissionsLog>,
    permissionsLogLoading: false as boolean,
    permissionsLogShowMoreLoading: false as boolean,
    permissionModelOpsFilter: [] as ISelect[],
  })

  const getPermissionsLog = computed(() => store.value.permissionsLog.data)
  const permissionModelOpsFilter = computed(() => store.value.permissionModelOpsFilter)

  async function getPermissionModelOpsFilter ()
  {
    try {
      const resp = await axios.get(`/api/permissions/get-model-ops-filter`);
      store.value.permissionModelOpsFilter = resp.data.data
      return resp.data
    } catch (error: unknown) {
      if(isAxiosError(error)) {
        throw error.response
      }
      throw error
    }
  }

  async function permissionsLog(params: IFilterData, showMoreLoading = false) {
    try {
      let url = `api/log/permissions`
      if(store.value.permissionsLog.data && store.value.permissionsLog.next_page_url === null) {
        return
      }
      if(store.value.permissionsLog.next_page_url) {
        url = store.value.permissionsLog.next_page_url
      }
      if (showMoreLoading) {
        store.value.permissionsLogShowMoreLoading = false
      } else {
        store.value.permissionsLogLoading = false
      }
      const resp = await axios.get(url, {params})
      if (showMoreLoading) {
        store.value.permissionsLogShowMoreLoading = true
      } else {
        store.value.permissionsLogLoading = true
        store.value.permissionsLogShowMoreLoading = true
      }
      if(store.value.permissionsLog.data) {
        resp.data.data.data.forEach(function(item: IRolePermissionsLog) {
          store.value.permissionsLog.data.push(item)
        });
        store.value.permissionsLog.next_page_url = resp.data.data.next_page_url
        store.value.permissionsLog.next_cursor = resp.data.data.next_cursor
      } else {
        store.value.permissionsLog = resp.data.data
      }

    } catch (error: any) {
      console.log(error)
      throw error.response
    }
  }

  function clear() {
    store.value.permissionsLog = {}  as IPage<IRolePermissionsLog>
  }

  return {
    store,
    getPermissionModelOpsFilter,
    permissionModelOpsFilter,
    getPermissionsLog,
    permissionsLog,
    clear
  }
})
