import {IFilterData, IPage} from "@/utils/interfaces";
import {defineStore} from "pinia";
import axios from "@/axios";
import {AxiosError} from "axios";
import {IChangeStatusFormData, IFormData, IProductStatus} from "@/pages/product_assignments/interfaces";

const URL = "/api/product_assignments";

export const useProductStatusesStore = defineStore("product_assignments", () => {
  async function getRows(params: IFilterData = {}): Promise<IPage<IProductStatus>> {
    try {
      const res = await axios.get(URL, {params});
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function show(id: string) {
    try {
      const res = await axios.get(URL+'/'+id);
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function setStatus(id: string, status: boolean) {
    try {
      const res = await axios.post(URL+'/set_status', {id: id, status: status});
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }
  async function setProductStatus(formData:IChangeStatusFormData){
    try {
      const res = await axios.post(URL+'/set_product_status', formData);
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }
  async function create(formData:IFormData) {
    try {
      const res = await axios.post(URL, formData);
      return res.data?.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }
  async function update(formData:IFormData) {
    try {
      const res = await axios.put(URL + "/" + formData.id, formData);
      return res.data?.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }
  return {getRows, setStatus, create, show, update, setProductStatus};
});
