import { defineStore } from "pinia";
import axios, { AxiosError } from "axios";

export const useRegularReportStore = defineStore("regular_reports", () => {
  async function all () {
    try {
      const res = await axios.get("/api/regular-reports/all");
      return res.data;
    } catch (err) {
      const error = err as AxiosError;
      throw error.response;
    }
  }

  async function downloadReport (report: string) {
    try {
      const res = await axios({
        url: "/api/regular-reports/" + report,
        method: "GET",
        responseType: "arraybuffer"
      });
      const url = window.URL.createObjectURL(new Blob([res.data]));
      const link = document.createElement('a');
      link.href = url;
      link.setAttribute('download', 'report.xlsx');
      document.body.appendChild(link);
      link.click();
      link.remove();
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  return {
    all,
    downloadReport,
  };
})