import {defineStore} from "pinia";
import axios from "@/axios";
import {CreateReminderRequest, IReminder, ListReminderRequest} from "@/stores/reminder/interfaces";

export const REMINDERS_URL = '/api/reminders'

export const useReminders = defineStore('ticket-reminders', () => {
  const getReminders = async (params: ListReminderRequest) => {
    try {
      const response = await axios.get<IReminder[]>(REMINDERS_URL, {
        params,
      })

      return response.data as IReminder[]
    } catch (e) {
      throw e
    }
  }

  const createReminder = async (request: CreateReminderRequest): Promise<IReminder> => {
    try {
      const response = await axios.post(REMINDERS_URL, request)

      return response.data as IReminder
    } catch (e) {
      throw e
    }
  }

  const removeReminder = async (reminderId: number | string): Promise<void> => {
    await axios.delete(REMINDERS_URL + '/' + reminderId)
  }

  return {
    getReminders,
    createReminder,
    removeReminder,
  }
})
