import {IDepartment} from "@/stores/department/interfaces";
import {IDepartmentGrade} from "@/stores/department_grades/interfaces";
import { IUserShort } from "@/pages/users/interfaces";
import { IPage } from "@/utils/interfaces";
import * as lucideIcons from "lucide-vue-next";

export interface IReportPayportAuthLog {
  id: number,
  user_id: number,
  ip: string,
  os: string,
  created_at: string,
  responsible_user: IUserShort,
}

export interface IReportPayportManagerActivity {
  id: number,
  responsible_user: string,
  email: string,
  updated_at: string,
  action: string,
  entities: Array<IReportLogEntity>,
  log: string,
}

export interface IReportPayportWithNoActivity {
  id: number,
  created_at: string,
  action: string,
  parent_model_type: "App\\Models\\Client" | "App\\Models\\Lead",
  parent_type: string,
  parent_id: number,
  parent_name: string,
  email: string,
  status_name: string,
  log: string,
  user: IUserShort,
  responsible_users: Array<IUserShort>,
}

export interface IReportPayportAddedToBlacklist {
  id: number,
  blacklistable_type: string,
  blacklistable_id: number,
  created_at: string,
  blacklistable: {
    id: number,
    name: string,
    email: string,
    status_name: string,
    responsible_users: Array<IUserShort>
  },
  comment: {
    id: number,
    comment: string,
  }
}

export interface IReportPayportMerchantsEnteringProd {
  id: number,
  name: string,
  email: string,
  product_id: number,
  client_id: number,
  client_name: string,
  client_email: string,
  responsible_users: string,
  payport: {
    id: number,
    created_at: number,
    currencies_input: string,
    currencies_output: string,
  }
}

export interface IReportPayportMerchantsWithoutTransactions {
  id: number,
  name: string,
  email: string,
  product_id: number,
  product: {
    client: Array<{
      id: number,
      responsible_users: Array<IUserShort>,
    }>
  },
  payport: {
    id: number,
    created_at: string,
    last_invoice_date: string,
  }
}

export interface IReportPayportAverageTimeToBargain {
  id: number,
  name: string,
  email: string,
  product_id: number,
  product: {
    client: Array<{
      id: number,
      responsible_users: Array<IUserShort>,
    }>
  },
  index: number,
  payport: {
    id: number,
    created_at: string,
    nth_date: string,
    delta_days: number,
  },
  average_days: number,
}

export interface IReportPayportTopCurrencies {
  id: number,
  fiat_currency: string,
  payment_invoice_count: number,
  payment_invoice_sum: number,
  payment_invoice_grow: number,
  withdrawal_invoice_count: number,
  withdrawal_invoice_sum: number,
  withdrawal_invoice_grow: number,
  payout_invoice_count: number,
  payout_invoice_sum: number,
  payout_invoice_grow: number,
  all_invoice_count: number,
  all_invoice_sum: number,
  all_invoice_grow: number,
}

export interface IReportPayportGetMerchantsFilter {
  id: number,
  name: string,
}

export interface IReportPayportGetFiatsFilter {
  name: string,
}

export interface IReportPayportTopMerchants {
  id: number,
  name: string,
  created_at: string,
  payment_invoice_count: number,
  payment_invoice_sum: number,
  payment_invoice_grow: number,
  withdrawal_invoice_count: number,
  withdrawal_invoice_sum: number,
  withdrawal_invoice_grow: number,
  payout_count: number,
  payout_sum: number,
  payout_grow: number,
  all_invoice_count: number,
  all_invoice_sum: number,
  all_invoice_grow: number,
  responsible_users: Array<{
    user_id: number,
    full_name: string,
    last_name: string,
  }>,
  client: Array<{
    client_id: number,
    product_id: number,
  }>,
  hour: number,
  period: string,
}


export interface IReportPayportMerchantCirculationAmountTimeline {
    id: number,
    hour: number,
    period: string,
    responsible_users: Array<{
        user_id: number,
        full_name: string,
        last_name: string,
    }>,
    client: Array<{
        client_id: number,
        product_id: number,
    }>,
    data:{
    cummulative: Array<any> ;

    merchants: Array<IReportPayportTopMerchants>,
    invoices: Array<MerchantsInvoiceData>,
    periods: Array<InvoicePeriodData>,
    fiats: Array<FiatsInvoiceData>
    ranges: {
        week_ago: {
            start_date: string,
            end_date: string,
        },
        yesterday: {
            start_date: string,
            end_date: string,
        },
        today: {
            start_date: string,
            end_date: string,
        }
    }
    }
}
export interface IReportPayportFiatCirculationAmountTimeline {
    id: number,
    hour: number,
    period: string,
    responsible_users: Array<{
        user_id: number,
        full_name: string,
        last_name: string,
    }>,
    client: Array<{
        client_id: number,
        product_id: number,
    }>,
    data:{

        merchants: Array<IReportPayportTopMerchants>,
        invoices: Array<FiatsInvoiceData>,
        periods: Array<InvoicePeriodData>,
        fiats: Array<{id:number, name: string}>
        cummulative: any,
        ranges: {
            week_ago: {
                start_date: string,
                end_date: string,
            },
            yesterday: {
                start_date: string,
                end_date: string,
            },
            today: {
                start_date: string,
                end_date: string,
            }
        }
    }
}

export interface IPeriodMerchantsInvoiceData {
    merchant_id: number;
    merchant_name: string;
    hour: string;
    total_count: string;
    total_invoice_sum: string;
    period: string;
}
export interface IPeriodFiatsInvoiceData {
    input_currency: string;
    hour: string;
    total_count: string;
    total_invoice_sum: string;
    period: string;
}

export interface MerchantsInvoiceData {
    [key: number]:Array<IPeriodMerchantsInvoiceData>
}
export interface FiatsInvoiceData {
    [key: string]:Array<IPeriodFiatsInvoiceData>
}
export interface InvoicePeriodData {
    [key: string]: number
}

export interface IReportPayportGetSalesManagersFilter {
  id: number,
  name: string,
}

export interface IReportPayportMerchantCurrencyRowTypeSp {
  sp_name: string,
  sum: number,
}

export interface IReportPayportMerchantCurrency {
  merchant_name: string,
  fiat_currency: string,
  payment: Array<IReportPayportMerchantCurrencyRowTypeSp>,
  withdrawal: Array<IReportPayportMerchantCurrencyRowTypeSp>,
  bg_color: string,
  color: string,
  product_id: number|null,
  client_id: number|null,
}

export interface IReportPayportTopServiceProviders {
  id: number,
  id_crm: number,
  name: string,
  payment_invoice_count: number,
  payment_invoice_sum: number,
  payment_invoice_grow: number,
  withdrawal_invoice_count: number,
  withdrawal_invoice_sum: number,
  withdrawal_invoice_grow: number,
  payout_invoice_count: number,
  payout_invoice_sum: number,
  payout_invoice_grow: number,
  all_invoice_count: number,
  all_invoice_sum: number,
  all_invoice_grow: number,
  responsible_users: Array<{
    user_id: number,
    full_name: string,
    last_name: string,
  }>,
}

export interface IReportPayportGetServiceProvidersFilter {
  id: number,
  name: string,
}

export interface IReportPayportCurrencyMerchantRowTypeSp {
  sp_name: string,
  sum: number,
}

export interface IReportPayportCurrencyMerchant {
  fiat_currency: string,
  merchant_name: string,
  payment: Array<IReportPayportCurrencyMerchantRowTypeSp>,
  withdrawal: Array<IReportPayportCurrencyMerchantRowTypeSp>,
  product_id: number|null,
  client_id: number|null,
}

export interface IReportPayportGetMerchantsFilter {
  id: number,
  name: string,
}

export interface IReportPayportGetFiatsFilter {
  name: string,
}

export interface IReportPayportMerchantRecalculations {
  product_id: number|null,
  client_id: string|null,
  merchant_name: string,
  total_recalculations: string,
}

export interface IReportPayportMerchantsEnteringSand {
  id: number,
  name: string,
  email: string,
  product_id: number,
  client_id: number,
  client_name: string,
  client_email: string,
  responsible_user: Array<{ id: number, full_name: string }>,
  sand_created_at: string,
}

export interface IReportPayportAverageTimeToProdAfterSand {
  id: number,
  client_id: number,
  client_name: string,
  index: number,
  merchant_prod_product_id: number,
  merchant_prod_name: string,
  merchant_prod_email: string,
  merchant_sand_product_id: number,
  merchant_sand_name: string,
  merchant_sand_email: string,
  responsible_user: Array<{ id: number, full_name: string }>,
  created_at_sand: string,
  created_at_prod: string,
  diff_days: number,
  average_days: number,
}

export interface IReportPayportGetTradersFilter {
  id: number,
  name: string,
}

export interface IReportPayportGetPaymentSystemsFilter {
  id: number,
  name: string,
}

export interface IReportPayportTraderConversions {
  id: number,
  service_provider_id: number,
  crm_service_provider_id: number,
  service_provider_name: string,
  fiat_name: string,
  trader_id: number,
  crm_trader_id: number,
  trader_name: string,
  invoice_type: string,
  payment_system_type: string,
  payment_system_type_details: {
    id: number,
    name: string,
  },
  payment_system: {
    id: number,
    name: string,
  },
  paid_count: number,
  cancelled_count: number,
  total_count: number,
  total_without_by_timeout_count: number,
  conversion_percent: number,
  conversion_without_by_timeout_percent: number,
  is_text_bold: boolean,
  stateIcon: keyof typeof lucideIcons,
  isCollapsed?: boolean,
  additional_data?: Array<IReportPayportTraderConversions>,
  payment_system_id: string,
  account_info: string
}

export interface IReportPayportMerchantConversions {
  id: number,
  merchant_id: number,
  fiat_name: string,
  total_amount: number,
  crm_merchant_id: number,
  merchant_name: string,
  invoice_type: string,
  payment_system_id: string,
  payment_system_type: string,
  payment_system_type_details: {
    id: number,
    name: string,
  },
  payment_system: {
    id: number,
    name: string,
  },
  paid_count: number,
  cancelled_count: number,
  total_count: number,
  total_without_by_timeout_count: number,
  total_by_timeout_count: number,
  conversion_percent: number,
  conversion_without_by_timeout_percent: number,
  is_text_bold: boolean,
  responsible_users?: Array<{
    user_id: number,
    full_name: string,
    last_name: string,
  }>,
  service_provider: {
      name: string
  }
  merchant_links: Array<number>,
  stateIcon: keyof typeof lucideIcons,
  isCollapsed?: boolean,
  additional_data?: Array<IReportPayportMerchantConversions>
}
interface IRange {
    [key: string]: any
}
export interface IReportPayportTraderCancellations {
  id: number,
  service_provider_id: number,
  crm_service_provider_id: number,
  service_provider_name: string,
  trader_id: number,
  crm_trader_id: number,
  trader_name: string,
  type: string,
  total_deals: number,
  completed_deals: number,
  cancelled_deals: number,
  first_cancelled_then_completed: number,
  percent_from_completed: number,
  percent_from_total: number,
  is_text_bold: boolean,
  fiat_name: string,
  ad:{payment_system_type: { id: number, name: string, obj_name: string }},
  payment_system_type_details: { id: number, name: string },
  payment_system: { id: number, name: string },
  ps_name: string,
  pst_name: string,
  range: Array<IRange>,
  [key: string]: any;
}
export interface ITraderCancellationTotals {
    [key: string]: any
}
export interface IReportPayportTradersSpeed {
  id: number,
  service_provider_id: number,
  crm_service_provider_id: number,
  service_provider_name: string,
  trader_id: number,
  crm_trader_id: number,
  trader_name: string,
  type: string,
  normal_deals: number,
  normal_time: number,
  arbitrage_deals: number,
  arbitrage_time: number,
  is_text_bold: boolean,
}

export interface IReportPayportInvoicesDistributionByTime {
  hour: number,
  invoice_type: number,
  total_count: number,
  total_amount: number,
  percent: number,
}

export interface IReportPayportInvoicesDistributionByTimeTable {
  name: string,
  data: Array<number>,
  total: number,
}

export interface IReportPayportTopMerchantsByIntervalsDateRanges {
  0: string,
  1: string,
}

export interface IReportPayportTopMerchantsByIntervalsDataInterval {
  from_date: string,
  to_date: string,
  deals_count: number,
  deals_sum: number,
  fiat_sum: number,
  grow_sum: number,
}

export interface IReportPayportTopMerchantsByIntervalsData {
  id: number,
  name: string,
  intervals: Array<IReportPayportTopMerchantsByIntervalsDataInterval>,
  all_deals_count: number,
  all_deals_sum: number,
  all_fiat_sum: number,
  all_grow_sum: number,
  client: Array<{
    id: number,
    client_id: number,
    product_id: number,
  }>,
}

export interface IReportPayportTopMerchantsByIntervalsTotals {
  intervals: Array<{
    deals_count: number,
    deals_sum: number,
    fiat_sum: number,
    grow_sum: number,
  }>,
  all_deals_count: number,
  all_deals_sum: number,
  all_fiat_sum: number,
  all_grow_sum: number,
}

export interface IReportPayportTopMerchantsByIntervals {
  data: Array<IReportPayportTopMerchantsByIntervalsData>,
  totals: Array<IReportPayportTopMerchantsByIntervalsTotals>,
  data_ranges: Array<IReportPayportTopMerchantsByIntervalsDateRanges>,
}

export interface IPageReportPayportTopMerchantsByIntervals extends IPage<IReportPayportTopMerchantsByIntervalsData> {
  totals: IReportPayportTopMerchantsByIntervalsTotals,
  data_ranges: Array<IReportPayportTopMerchantsByIntervalsDateRanges>,
}

export interface IReportPayportTopMerchantsWithProfitabilityDataInterval {
  from_date: string,
  to_date: string,
  pi_deals_count: number,
  pi_deals_sum: number,
  pi_fiat_sum: number,
  pi_grow_sum: number,
  mwi_deals_count: number,
  mwi_deals_sum: number,
  mwi_fiat_sum: number,
  mwi_grow_sum: number,
  po_deals_count: number,
  po_deals_sum: number,
  po_fiat_sum: number,
  po_grow_sum: number,
}

export interface IReportPayportTopMerchantsWithProfitabilityData {
  id: number,
  name: string,
  created_at: string,
  intervals: Array<IReportPayportTopMerchantsWithProfitabilityDataInterval>,
  all_deals_count: number,
  all_deals_sum: number,
  all_fiat_sum: number,
  all_grow_sum: number,
  client: Array<{
    id: number,
    client_id: number,
    product_id: number,
  }>,
  responsible_users: Array<{
    user_id: number,
    full_name: string,
    last_name: string,
  }>,
}

export interface IReportPayportTopMerchantsWithProfitabilityTotals {
  intervals: Array<{
    pi_deals_count: number,
    pi_deals_sum: number,
    pi_fiat_sum: number,
    pi_grow_sum: number,
    mwi_deals_count: number,
    mwi_deals_sum: number,
    mwi_fiat_sum: number,
    mwi_grow_sum: number,
    po_deals_count: number,
    po_deals_sum: number,
    po_fiat_sum: number,
    po_grow_sum: number,
  }>,
  all_deals_count: number,
  all_deals_sum: number,
  all_fiat_sum: number,
  all_grow_sum: number,
}

export interface IReportPayportTopMerchantsWithProfitability {
  data: Array<IReportPayportTopMerchantsWithProfitabilityData>,
  totals: Array<IReportPayportTopMerchantsWithProfitabilityTotals>,
  data_ranges: Array<IReportPayportTopMerchantsByIntervalsDateRanges>,
}

export interface IPageReportPayportTopMerchantsWithProfitability extends IPage<IReportPayportTopMerchantsWithProfitabilityData> {
  totals: IReportPayportTopMerchantsWithProfitabilityTotals,
  data_ranges: Array<IReportPayportTopMerchantsByIntervalsDateRanges>,
}

export interface IReportCRMLeadsByRespAndProducts {
  id: number,
  name: string,
  email: string,
  created_at: string,
  status_name: string,
  responsible_users: Array<string>,
  product_types: Array<string>,
}

export interface IReportCRMLeadConverting {
  id: number,
  name: string,
  email: string,
  status: string,
  responsible_users: string,
  product_types: string,
  created_at: string,
  action_date: string,
}

export interface IReportCRMHoldingParticipantLeads {
  id: number,
  participant_id: number,
  participant_name: string,
  participant_email: string,
  holding_name: string,
  holding_email: string | null,
  holding_responsible_users: string,
  holding_created_at: string,
  date_enter: string,
  date_exit: string,
}

export interface IReportCRMAggregatorLeads {
  id: number,
  aggregator_id: number,
  participant_name: string,
  participant_url: string,
  aggregator_name: string,
  aggregator_email: string,
  aggregator_created_at: string,
  aggregator_responsible_users: string,
}

export interface IReportCRMLeadsBySalesChannels {
  id: number,
  name: string,
  email: string,
  status: string,
  created_at: string,
  sales_channel: string,
  responsible_users: string,
}

export interface IReportCRMHoldingParticipantClients {
  id: number,
  participant_id: number,
  participant_name: string,
  participant_email: string,
  holding_name: string,
  holding_email: string | null,
  holding_responsible_users: string,
  holding_created_at: string,
  date_enter: string,
  date_exit: string,
}

export interface IReportCRMAggregatorClients {
  id: number,
  aggregator_id: number,
  participant_name: string,
  participant_url: string,
  aggregator_name: string,
  aggregator_email: string,
  aggregator_created_at: string,
  aggregator_responsible_users: string,
}

export interface IReportCRMClientsBySalesChannels {
  id: number,
  name: string,
  email: string,
  status: string,
  created_at: string,
  sales_channel: string,
  responsible_users: string,
}

export interface IReportCRMDeactivatedClients {
  id: number,
  name: string,
  email: string,
  status: string,
  created_at: string,
  responsible_users: string,
  deactivated_at: string,
}

export interface IReportCRMMerchantsStatusNew {
  id: number,
  name: string,
  email: string,
  product_id: number,
  client_id: number,
  status: string,
  created_at: string,
  responsible_users: string,
}

export interface IReportLogEntity {
  parent_type: "App\\Models\\ServiceProvider" | "App\\Models\\Client" | "App\\Models\\Lead" | "App\\Models\\Trader" | "App\\Models\\ContactPerson",
  parent_id: number,
  entity_title: string,
  entity_value: string,
}

export interface IReportCRMCustomerSupportActivity {
  id: number,
  responsible_user: string,
  email: string,
  updated_at: string,
  action: string,
  entities: Array<IReportLogEntity>,
  log: string,
}

export interface IReportCrmEmployeeGrade {
  user_id: number,
  user: IUserShort,
  department: IDepartment,
  grades: Array<IDepartmentGrade>,
  positive_result: number,
  negative_result: number,
  general_result: number,
}

export interface IReportCRMCalendarTasks {
  id: number,
  responsible_user: string,
  status: string,
  entity_type: string|null,
  entity_id: number|null,
  entity_name: string|null,
  topic: string,
  date_start: string,
  date_complete: string,
}

export interface  IReportTSUserTicketsStatus {
  user_id: number,
  user_full_name: string,
  count_processing_tickets: number,
  count_closed_tickets: number,
  count_delayed_tickets: number,
  count_moved_tickets: number,
  count_ticket_comments: number,
}


export interface IReportTSUserTicketsByQueueStatus {
  user_name: string
  user_id: number
  data: IReportTSUserTicketsByQueueStatusItem[]
  total: ITotalReportTSUserTicketsByQueueStatusItem
}

export interface ITotalReportTSUserTicketsByQueueStatusItem{
  total_count_new_tickets: number
  total_count_processing_tickets: number
  total_count_sla_expired_tickets: number
  total_count_delayed_tickets: number
  total_count_summary: number
}

export interface IReportTSUserTicketsByQueueStatusItem{
  queue_name: string
  count_new_tickets: number
  count_processing_tickets: number
  count_sla_expired_tickets: number
  count_delayed_tickets: number
  count_summary: number
}
