import { ref } from "vue";
import { defineStore } from "pinia";
import {IAdditionalProductInfo} from "@/pages/leads/interfaces";
import axios, {AxiosError} from "axios";
import { Lead } from "@/pages/leads/classes";
import {Client} from "@/pages/clients/classes";

export const useRequisiteStore = defineStore('requisite', () => {
  const store = ref({
    lead: null as unknown as Lead,
    client: null as unknown as Client
  })

  async function update(id: number|string|null, iface: 'Lead' | 'Client', field: string, value: string|number|Array<string|number>|{[key:string]:string}|IAdditionalProductInfo|boolean|null|undefined ) {
    try {

      const res = await axios.post("/api/requisites/" + id, {
        interface: iface,
        field_name: field,
        value: value,
        model_id: id
      });
      switch (iface){
        case "Lead":
          store.value.lead = res.data;
          break
        case "Client":
          store.value.client = res.data;
          break
      }
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }
  return {
    update,
    store
  };
})
