import { defineStore } from "pinia";
import axios from "../axios";
import { AxiosError, isAxiosError } from "axios";
import {computed, ref} from "vue";
import {PaginationInterface} from "@/components/Pagination/interfaces";
import {IRole} from "@/stores/role/interfaces";
import {IFilterData} from "@/utils/interfaces";

export const useRoleStore = defineStore("role", () => {
  const store = ref({
    list: [] as IRole[],
    item: {} as IRole,
    meta: {} as PaginationInterface,
  })
  async function getAllRoles(params?: {
    without_admin?: "true" | "false",
  }): Promise<Array<IRole>> {
    try {
      const res = await axios.get("/api/roles/all", { params });
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  const getList = computed(() => store.value.list)
  const getItem = computed(() => store.value.item)
  const pagination = computed(() => store.value.meta)
  async function list(filterData: IFilterData) {
    try {
      const resp = await axios.get(`api/roles`, {params: filterData})
      store.value.list = resp.data.data
      store.value.meta = resp.data
    } catch (error: unknown) {
      if(isAxiosError(error)) {
        throw error.response
      }
      throw error
    }
  }

  async function show(id: string) {
    try {
      const resp = await axios.get(`api/roles/${id}`)
      store.value.item = resp.data
      return resp.data
    } catch (error: unknown) {
      if(isAxiosError(error)) {
        throw error.response
      }
      throw error
    }
  }

  async function save(payload: object): Promise<IRole> {
    try {
      const res = await axios.post("/api/roles", payload)
      return res.data
    } catch (error: unknown) {
      if(isAxiosError(error)) {
        throw error.response
      }
      throw error
    }
  }

  async function update(payload: object, id: string) {
    try {
      const resp = await axios.put(`api/roles/${id}`, payload)

    } catch (error: unknown) {
      if(isAxiosError(error)) {
        throw error.response
      }
      throw error
    }
  }

  async function deleteRole(id: string) {
    try {
      const resp = await axios.delete(`api/departments/${id}`)
    } catch (error: unknown) {
      if(isAxiosError(error)) {
        throw error.response
      }
      throw error
    }
  }


  return { getAllRoles, save, deleteRole, update, show, list, getList, pagination, getItem };
});
