import { ref } from "vue";
import axios from "@/axios";
import { AxiosError } from "axios";
import { defineStore } from "pinia";
import {IFilterData, IPage} from "@/utils/interfaces";
import { IBaseSalesChannel, ISalesChannel } from "@/pages/sales_channels/interfaces";

export const useSalesChannelStore = defineStore("sales-channel", () => {
  const store = ref({
    list: [] as Array<ISalesChannel>
  })

  async function getAllSalesChannels() {
    try {
      const res = await axios.get("/api/sales-channels/all");
      store.value.list = res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getSalesChannels (params: IFilterData = {}): Promise<IPage<ISalesChannel>> {
    try {
      const res = await axios.get("/api/sales-channels", { params });
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getSalesChannel (id: number|string|null): Promise<ISalesChannel> {
    try {
      const res = await axios.get("/api/sales-channels/" + id);
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function createSalesChannel(data: IBaseSalesChannel) {
    try {
      await axios.post("/api/sales-channels", data);
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function updateSalesChannel (id: number|string|null, data: IBaseSalesChannel) {
    try {
      await axios.put("/api/sales-channels/" + id, data);
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function deleteSalesChannel (id: number|string|null) {
    if (id) {
      try {
        await axios.delete("/api/sales-channels/" + id);
      } catch (error) {
        const err = error as AxiosError;
        throw err.response;
      }
    } else {
      console.error("deleteSalesChannel: id is not set");
    }
  }

  return {
    store,
    getAllSalesChannels,
    getSalesChannels,
    getSalesChannel,
    createSalesChannel,
    updateSalesChannel,
    deleteSalesChannel
  };
})
