import {defineStore} from "pinia";
import axios from "@/axios";
import {isAxiosError} from "axios";
import {computed, ref} from "vue";
import {PaginationInterface} from "@/components/Pagination/interfaces";
import {IServiceProvider} from "@/stores/trader/interfaces";
import {IFilterData, ISelect} from "@/utils/interfaces";

export const useServiceProviderStore = defineStore("service_provider", () => {
  const store = ref({
    list: [] as IServiceProvider[],
    item: {} as IServiceProvider,
    meta: {} as PaginationInterface,
    selectList: [] as (ISelect & {id: number})[],
  })

  const getList = computed(() => store.value.list)
  const getItem = computed(() => store.value.item)
  const pagination = computed(() => store.value.meta)
  const getSelectList = computed(() => store.value.selectList)
  async function list(filterData: IFilterData) {
    try {
      const resp = await axios.get(`api/service-providers`, {params: filterData})
      store.value.list = resp.data.data
      store.value.meta = resp.data
    } catch (error: unknown) {
      if(isAxiosError(error)) {
        throw error.response
      }
      throw error
    }
  }

  async function show(id: string) {
    try {
      const resp = await axios.get(`api/service-providers/${id}`)
      store.value.item = resp.data
      return resp.data
    } catch (error: unknown) {
      if(isAxiosError(error)) {
        throw error.response
      }
      throw error
    }
  }
  async function selectList(filterData?: IFilterData) {
    try {
      const resp = await axios.get(`api/service-providers/list`, {params: filterData})
      store.value.selectList = resp.data.data
      return resp.data
    } catch (error: unknown) {
      if(isAxiosError(error)) {
        throw error.response
      }
      throw error
    }
  }

  return { show, list, getList, pagination, getItem, selectList, getSelectList};
});
