import { IServiceProvider } from "@/stores/service_providers/interfaces";
import { IComment, ICommentable, IPage } from "@/utils/interfaces";
import { IUserShort } from "@/pages/users/interfaces";
import { useCommentStore } from "@/stores/comment";
import { ContactPerson as IContact } from "@/stores/contact_person/interfaces";
import { ILeadShortWithStatus } from "@/pages/leads/interfaces";
import {ITelegramChats} from "@/stores/telegram_chats/interfaces";

class ServiceProvider implements IServiceProvider, ICommentable {
  id: number
  id_payport: number
  id_payport_sand: number
  name: string
  email: string
  status: number
  phone: string
  telegram: string
  type: string
  association_type_id: number
  environment_type: string
  responsible_users: Array<IUserShort>
  responsible_user_ids: Array<string>
  lead: ILeadShortWithStatus | null;
  created_at: string
  contacts: Array<IContact>
  chats: Array<ITelegramChats> | null;

  static commentStore = useCommentStore();

  constructor(attrs: IServiceProvider) {
    this.id = attrs.id;
    this.id_payport = attrs.id_payport;
    this.id_payport_sand = attrs.id_payport_sand;
    this.name = attrs.name;
    this.email = attrs.email;
    this.status = attrs.status;
    this.phone = attrs.phone;
    this.telegram = attrs.telegram;
    this.type = attrs.type;
    this.association_type_id = attrs.association_type_id;
    this.environment_type = attrs.environment_type;
    this.responsible_users = attrs.responsible_users;
    this.responsible_user_ids = attrs.responsible_user_ids;
    this.lead = attrs.lead;
    this.created_at = attrs.created_at;
    this.contacts = attrs.contacts;
    this.chats = attrs.chats
  }

  async getComments(params?: { page?: string | number | undefined; perPage?: string | number | undefined; }): Promise<IPage<IComment>> {
    return await ServiceProvider.commentStore.getComments(
      {
        ...params,
        commentable_type: "ServiceProvider",
        commentable_id: this.id
      }
    );
  }

  async addNewComment(comment: string | null): Promise<IComment> {
    return await ServiceProvider.commentStore.createComment({
      commentable_type: "ServiceProvider",
      commentable_id: this.id,
      comment
    });
  }
}

export { ServiceProvider };
