import { defineStore } from "pinia";
import axios from "@/axios";
import { isAxiosError } from "axios";
import { computed, ref } from "vue";
import { PaginationInterface } from "@/components/Pagination/interfaces";
import { IFinancialIndicator } from "@/stores/service_providers/interfaces";
import { IFilterData, ISelect } from "@/utils/interfaces";

export const useSpFinancialIndicatorsStore = defineStore("sp-financial-indicators", () => {
  const store = ref({
    list: [] as IFinancialIndicator[],
    totals: {} as IFinancialIndicator,
    meta: {} as PaginationInterface,
    spTradersFilter: [] as ISelect[],
    listLoading: false as boolean,
  })

  const getList = computed(() => store.value.list)
  const getTotals = computed(() => store.value.totals)
  const pagination = computed(() => store.value.meta)
  const getSpTradersFilter = computed(() => store.value.spTradersFilter)
  const isListLoading = computed(() => store.value.listLoading)

  async function list(filterData: IFilterData, id: string) {
    try {
      store.value.list = []
      store.value.totals = {} as IFinancialIndicator
      store.value.listLoading = false
      const resp = await axios.get(`api/service-providers/financial-indicators/${id}`, {params: filterData})
      store.value.listLoading = true
      store.value.list = resp.data.data
      store.value.totals = resp.data.totals
      store.value.meta = resp.data
    } catch (error: unknown) {
      if(isAxiosError(error)) {
        throw error.response
      }
      throw error
    }
  }

  async function spTradersFilter (id: string)
  {
    try {
      const resp = await axios.get(`/api/service-providers/get-traders-filter/${id}`);
      store.value.spTradersFilter = resp.data.data
      return resp.data
    } catch (error: unknown) {
      if(isAxiosError(error)) {
        throw error.response
      }
      throw error
    }
  }

  return { pagination, list, isListLoading, spTradersFilter, getList, getTotals, getSpTradersFilter };
});
