import { IUserShort } from "@/pages/users/interfaces";
import { IContactable } from "@/utils/interfaces";
import { ILeadShortWithStatus } from "@/pages/leads/interfaces";
import {IPayportMerchant} from "@/pages/products/interfaces";
import { ITelegramChats } from "../telegram_chats/interfaces";

interface IServiceProvider extends IContactable {
    id: number,
    id_payport: number,
    id_payport_sand: number,
    name: string,
    email: string,
    phone: string,
    telegram: string,
    association_type_id: number,
    status: number,
    created_at: string,
    type: string,
    environment_type: string,
    chat_name?: string,
    responsible_user_ids: Array<string>,
    responsible_users: Array<IUserShort>,
    chats: Array<ITelegramChats> | null,
    lead: ILeadShortWithStatus | null;
}

interface IServiceProviderForm {
  name: string,
  email: string,
  status: string,
  phone: string,
  telegram: string,
  type: string,
  environment_type: string,
  responsible_user_ids: Array<string>,
}

interface IServiceProviderCurrencySetting {
  id: number,
  service_provider_id: number,
  direction: number,
  fiat_id: string,
  rate_source_id: string,
  markup: number,
  working_hours: string,
}

interface IServiceProviderCurrencySettingForm {
  id: string,
  service_provider_id: string,
  direction: string,
  fiat_id: string,
  rate_source_id: string,
  markup: string,
  working_hours: string,
  is_trader_checked?: boolean,
  trader_id?: string,
}

interface IServiceProviderCurrencySettingResponse {
  settings : Array<IServiceProviderCurrencySettingForm>
  modify_settings : Array<IServiceProviderCurrencySettingForm>
  was_changed_for_trader: boolean
  was_changed: boolean
}

interface IFinancialIndicator {
  name: string,
  withdrawal_sum?: string,
  input_sum?: string,
  balance?: string,
}

interface IMerchant {
  id?: number;
  name?: string;
  email?: string;
  balance?: IMerchantBalance
}

interface IMerchantBalance {
  id: number;
  merchant_id: number;
  amount: string;
  created_at: string;
  updated_at: string;
}

interface IPaymentSystem {
  id: number;
  name?: string;
  bg_color: string
  color: string
}

interface IPaymentAdditionInfo {
  ad: {
    coin: string,
  },
  contact: {
    cancellation_reason: string | null,
    payment_completed_at: string | null,
    payment_attributes: IPaymentAttributes,
  }
}

interface IPaymentAttributes {
  client_name?: string,
  client_email?: string,
  invoice_type?: number,
}

interface ITransaction {
  id: number,
  created_at: string,
  expired_at: string,
  input_rate: string,
  fiat_rate: string,
  completed_at: string | null,
  usdt_amount: string,
  usdt_amount2pay?: string,
  usdt_amount2grow?: string,
  usdt_amount2service?: string,
  usdt_amount2agent?: string,
  usdt_amount2service_agents?: string,
  usdt_amount2markup_payport?: string,
  usdt_amount2markup_agents?: string,
  merchant_id?: number,
  merchant_order_id?: string,
  api_type: number,
  status: number,
  fiat_currency: string,
  fiat_amount: string,
  invoice_type: number,
  payment_id?: string,
  service_provider_id?: number,
  payment_system_id?: number,
  type?: number,
  comment?: string,
  trader_id?: number,
  trader_name?: string,
  deal_status?: number,
  amount2agent_selected?: string,
  amount2service_agent_selected?: string,
  serviceAgentCommision?: number,
  agentCommision?: number,
  cancellation_reason_id?: number,
  merchant?: IMerchant,
  payment_system?: IPaymentSystem,
  service_provider?: IServiceProvider,
  addition_info?: IPaymentAdditionInfo,
  payment_attributes?: IPaymentAttributes
  check?: number,
  card_number?: string,
  first_paid_time?: string,
  owner_name?: string,
  trader_reaction_time?: string,
  first_paid_at?: string,
}

interface ITransactionTotal {
  invoice_count: number,
  usdt_amount: number,
  volume: number,
  usdt_amount2pay: number,
  usdt_amount2grow: number,
  usdt_amount2service: number,
  usdt_amount2agent: number,
  usdt_amount2service_agents: number,
  usdt_amount2agent_selected: number,
  usdt_amount2service_agent_selected: number,
  usdt_amount2markup_payport: number,
  usdt_amount2markup_agents: number,
  fiat_amount: boolean | string
}

interface IServiceProviderMerchant {
  name: string,
  email?: string,
  status: number,
  status_name: string,
  product_payport_merchant: IPayportMerchant[]
}
interface IPriority {
    id: number;
    ads_type: number;
    priority: number;
    group_type: number;
    fiat_id: number;
    merchant_id: number;
    fiat: {
        id: number;
        asset: string;
        name: string;
        precision: number;
        status: number;
    };
    priority_service_provider_groups: any[]; // Adjust this type as needed
}
export type {
  IServiceProvider,
  IServiceProviderForm,
  IServiceProviderCurrencySetting,
  IServiceProviderCurrencySettingForm,
  IServiceProviderCurrencySettingResponse,
  IFinancialIndicator,
  ITransaction,
  ITransactionTotal,
  IServiceProviderMerchant,
  IPriority,
};
