import { defineStore } from 'pinia'
import axios from '../../axios'
import { ref, computed } from 'vue'
import { IModelLog } from "@/stores/client_log/interfaces";
import { IPage } from "@/utils/interfaces";

export const useServiceProviderLogStore = defineStore('service-providers-log', () => {
  const store = ref({
    serviceProviderLog: {} as IPage<IModelLog>,
    serviceProviderCommunicationsLog: {} as IPage<IModelLog>,
    serviceProviderContactPersonLog: {} as IPage<IModelLog>,
    serviceProviderContactCurrencySettingLog: {} as IPage<IModelLog>,
  })

  const getServiceProviderLog = computed(() => store.value.serviceProviderLog.data)
  const getServiceProviderCommunicationsLog = computed(() => store.value.serviceProviderCommunicationsLog.data)
  const getServiceProviderContactPersonLog = computed(() => store.value.serviceProviderContactPersonLog.data)
  const getServiceProviderContactCurrencySettingLog = computed(() => store.value.serviceProviderContactCurrencySettingLog.data)

  async function serviceProviderLog(id: number) {
    try {
      let url = `api/log/service-providers/${id}`
      if(store.value.serviceProviderLog.data && store.value.serviceProviderLog.next_page_url === null) {
        return
      }
      if(store.value.serviceProviderLog.next_page_url) {
        url = store.value.serviceProviderLog.next_page_url
      }

      const resp = await axios.get(url)
      if(store.value.serviceProviderLog.data) {
        resp.data.data.data.forEach(function(item: IModelLog) {
          store.value.serviceProviderLog.data.push(item)
        });
        store.value.serviceProviderLog.next_page_url = resp.data.data.next_page_url
        store.value.serviceProviderLog.next_cursor = resp.data.data.next_cursor
      } else {
        store.value.serviceProviderLog = resp.data.data
      }

    } catch (error: any) {
      console.log(error)
      throw error.response
    }
  }
  async function serviceProviderCommunicationsLog(id: number) {
    try {
      let url = `api/log/service-providers/communications/${id}`
      if(store.value.serviceProviderCommunicationsLog.data && store.value.serviceProviderCommunicationsLog.next_page_url === null) {
        return
      }
      if(store.value.serviceProviderCommunicationsLog.next_page_url) {
        url = store.value.serviceProviderCommunicationsLog.next_page_url
      }
      const resp = await axios.get(url)
      if(store.value.serviceProviderCommunicationsLog.data) {
        resp.data.data.data.forEach(function(item: IModelLog) {
          store.value.serviceProviderCommunicationsLog.data.push(item)
        });
        store.value.serviceProviderCommunicationsLog.next_page_url = resp.data.data.next_page_url
        store.value.serviceProviderCommunicationsLog.next_cursor = resp.data.data.next_cursor
      } else {
        store.value.serviceProviderCommunicationsLog = resp.data.data
      }
    } catch (error: any) {
      throw error.response
    }
  }
  async function serviceProviderContactPersonLog(id: number) {
    try {
      let url = `api/log/service-providers/contact-persons/${id}`
      if(store.value.serviceProviderContactPersonLog.data && store.value.serviceProviderContactPersonLog.next_page_url === null) {
        return
      }
      if(store.value.serviceProviderContactPersonLog.next_page_url) {
        url = store.value.serviceProviderContactPersonLog.next_page_url
      }
      const resp = await axios.get(url)
      if(store.value.serviceProviderContactPersonLog.data) {
        resp.data.data.data.forEach(function(item: IModelLog) {
          store.value.serviceProviderContactPersonLog.data.push(item)
        });
        store.value.serviceProviderContactPersonLog.next_page_url = resp.data.data.next_page_url
        store.value.serviceProviderContactPersonLog.next_cursor = resp.data.data.next_cursor
      } else {
        store.value.serviceProviderContactPersonLog = resp.data.data
      }
    } catch (error: any) {
      throw error.response
    }
  }
  async function serviceProviderContactCurrencySettingLog(id: number) {
    try {
      let url = `api/log/service-providers/curreny-settings/${id}`
      if(store.value.serviceProviderContactCurrencySettingLog.data && store.value.serviceProviderContactCurrencySettingLog.next_page_url === null) {
        return
      }
      if(store.value.serviceProviderContactCurrencySettingLog.next_page_url) {
        url = store.value.serviceProviderContactCurrencySettingLog.next_page_url
      }
      const resp = await axios.get(url)
      if(store.value.serviceProviderContactCurrencySettingLog.data) {
        resp.data.data.data.forEach(function(item: IModelLog) {
          store.value.serviceProviderContactCurrencySettingLog.data.push(item)
        });
        store.value.serviceProviderContactCurrencySettingLog.next_page_url = resp.data.data.next_page_url
        store.value.serviceProviderContactCurrencySettingLog.next_cursor = resp.data.data.next_cursor
      } else {
        store.value.serviceProviderContactCurrencySettingLog = resp.data.data
      }
    } catch (error: any) {
      throw error.response
    }
  }

  function clear() {
    store.value.serviceProviderLog = {}  as IPage<IModelLog>
    store.value.serviceProviderCommunicationsLog = {} as IPage<IModelLog>
    store.value.serviceProviderContactPersonLog = {} as IPage<IModelLog>
    store.value.serviceProviderContactCurrencySettingLog = {} as IPage<IModelLog>
  }

  return {
    store,
    getServiceProviderLog,
    getServiceProviderCommunicationsLog,
    serviceProviderLog,
    serviceProviderCommunicationsLog,
    serviceProviderContactPersonLog,
    getServiceProviderContactPersonLog,
    serviceProviderContactCurrencySettingLog,
    getServiceProviderContactCurrencySettingLog,
    clear
  }
})
