import { defineStore } from "pinia";
import axios from "@/axios";
import { isAxiosError } from "axios";
import {computed, ref} from "vue";
import {PaginationInterface} from "@/components/Pagination/interfaces";
import {ITrader} from "@/stores/trader/interfaces";
import {IFilterData} from "@/utils/interfaces";

export const useSpTradersStore = defineStore("sp-trader", () => {
  const store = ref({
    list: [] as ITrader[],
    item: {} as ITrader,
    meta: {} as PaginationInterface,
    listLoading: false as boolean,
  })

  const getList = computed(() => store.value.list)
  const getItem = computed(() => store.value.item)
  const pagination = computed(() => store.value.meta)
  const isListLoading = computed(() => store.value.listLoading)

  async function list(filterData: IFilterData) {
    try {
      store.value.list = []
      store.value.listLoading = false
      const resp = await axios.get(`api/traders`, {params: filterData})
      store.value.listLoading = true
      store.value.list = resp.data.data
      store.value.meta = resp.data
    } catch (error: unknown) {
      if(isAxiosError(error)) {
        throw error.response
      }
      throw error
    }
  }

  async function show(id: string) {
    if (Number(id) === store.value.item?.id) return
    try {
      const resp = await axios.get(`api/traders/${id}`)
      store.value.item = resp.data.data
      return resp.data.data
    } catch (error: unknown) {
      if(isAxiosError(error)) {
        throw error.response
      }
      throw error
    }
  }

  return { show, list, isListLoading, getList, pagination, getItem };
});
