import { defineStore } from "pinia";
import axios from "@/axios";
import { isAxiosError } from "axios";
import {computed, ref} from "vue";
import {PaginationInterface} from "@/components/Pagination/interfaces";
import {ITransaction, ITransactionTotal} from "@/stores/service_providers/interfaces";
import {IFilterData, ISelect} from "@/utils/interfaces";

export const useSpTransactionsStore = defineStore("sp-transactions", () => {
  const store = ref({
    list: [] as ITransaction[],
    sum: {} as ITransactionTotal,
    meta: {} as PaginationInterface,
    selectInvoiceTypesList: [] as ISelect[],
    spMerchantsFilter: [] as ISelect[],
    spFiatsFilter: [] as ISelect[],
    listLoading: false as boolean,
  })

  const getList = computed(() => store.value.list)
  const getSum = computed(() => store.value.sum)
  const pagination = computed(() => store.value.meta)
  const getSelectInvoiceTypesList = computed(() => store.value.selectInvoiceTypesList)
  const getSpMerchantsFilter = computed(() => store.value.spMerchantsFilter)
  const getSpFiatsFilter = computed(() => store.value.spFiatsFilter)
  const isListLoading = computed(() => store.value.listLoading)

  async function list(filterData: IFilterData, id: string) {
    try {
      store.value.list = []
      store.value.listLoading = false
      const resp = await axios.get(`api/service-providers/transactions/${id}`, {params: filterData})
      store.value.listLoading = true
      store.value.list = resp.data.deals.data
      store.value.sum = resp.data.sum
      store.value.meta = resp.data.deals
    } catch (error: unknown) {
      if(isAxiosError(error)) {
        throw error.response
      }
      throw error
    }
  }

  async function spFiatsFilter ()
  {
    try {
      const resp = await axios.get(`/api/service-providers/get-fiats-filter`);
      store.value.spFiatsFilter = resp.data.data
      return resp.data
    } catch (error: unknown) {
      if(isAxiosError(error)) {
        throw error.response
      }
      throw error
    }
  }

  async function spMerchantsFilter(filterData: IFilterData, id: string) {
    try {
      const resp = await axios.get(`api/service-providers/get-merchants-filter/${id}`, {params: filterData})
      store.value.spMerchantsFilter = resp.data.data
      return resp.data
    } catch (error: unknown) {
      if(isAxiosError(error)) {
        throw error.response
      }
      throw error
    }
  }

  async function selectInvoiceTypesList() {
    try {
      const resp = await axios.get(`api/trader/invoice-types/list`)
      store.value.selectInvoiceTypesList = resp.data.data
      return resp.data
    } catch (error: unknown) {
      if(isAxiosError(error)) {
        throw error.response
      }
      throw error
    }
  }

  return { list, isListLoading, getList, pagination, getSum, selectInvoiceTypesList, getSelectInvoiceTypesList, getSpMerchantsFilter, spMerchantsFilter, spFiatsFilter, getSpFiatsFilter };
});
