import { defineStore } from "pinia";
import { Icon } from "@/base-components/Lucide/Lucide.vue";
import { i18n } from "@/utils/i18n";
import { metaEnv } from "@/utils/helper";
import { getCurrentInstance } from "vue";

const t = i18n.global.t;

export interface Role {
  name: string;
}

export interface Menu {
  icon?: Icon;
  title: string;
  pageName?: string;
  subMenu?: Menu[];
  ignore?: boolean;
  table?: string;
  action?: string;
  metaButton?: boolean;
  meta?: Record<string, unknown>;
}

export interface SideMenuState {
  menu: Array<Menu | "devider">;
}

export const useSideMenuStore = defineStore("sideMenu", {
  state: (): SideMenuState => {
    const state = {
      menu: [
        {
          icon: "UserPlus",
          pageName: "leads.list",
          title: t("Leads"),
          table: 'leads',
          action: 'index'
        },
        {
          icon: "Users",
          pageName: "clients.list",
          title: t("Clients"),
          table: 'clients',
          action: 'index'
        },
        {
          icon: "Contact",
          pageName: "contact.person.list",
          title: t("Contacts"),
          table: 'contact_persons',
          action: 'index'
        },
        {
          icon: "Calendar",
          pageName: "calendar",
          table: "communications",
          title: t("Calendar"),
          action: "index",
        },
        {
          icon: "Calendar",
          pageName: "calendar_new",
          title: t("Calendar New"),
          table: "calendar_events",
          action: "index",
        },
        {
          icon: "Bell",
          pageName: "notifications",
          title: t("Notifications"),
        },
        {
          icon: "TrendingUp",
          pageName: "trader.list",
          table: "traders",
          title: t("Traders"),
          action: "index", //
        },
        {
          icon: "TrendingUp",
          pageName: "trader-admins.list",
          table: "trader_admins",
          title: t("Trader Admins"),
          action: "index", //
        },
        {
          icon: "List",
          pageName: "service-providers.list",
          table: "service_providers",
          title: t("Service providers"),
          action: "index",
        },
      ],
    } as SideMenuState;

    if (metaEnv.VITE_PAYPORT_ENABLED === '1') {
      state.menu.push({
        icon: "Nfc",
        pageName: "payport.transactions.list",
        title: t("Payport"),
        meta: {
          key: "payport",
        },
      });
    }

    state.menu = [
      ...state.menu,
      {
        icon: "Star",
        pageName: "favorites.list",
        title: t("Favorites"),
        table: "favorites",
        action: "index",
      },
      {
        icon: "Settings",
        pageName: "",
        title: t("Settings"),
        table: "settings",
        action: "index",
        subMenu: [
          {
            icon: "Settings2",
            pageName: "general_settings.index",
            title: t("General settings"),
            table: 'general_settings',
            action: 'index'
          },
          {
            icon: "Users",
            pageName: "permissions.edit",
            title: t("Privileges"),
            table: 'access_settings',
            action: 'index'
          },
          {
            icon: "User",
            pageName: "roles.list",
            title: t("Roles"),
            table: 'roles',
            action: 'index'
          },
          {
            icon: "Settings",
            pageName: "products.import",
            title: t("Products import"),
            table: 'products',
            action: 'import'
          },
          {
            icon: "BellPlus",
            pageName: "notificationManagement.list",
            title: t("Notification management"),
            table: "notification_schedule",
            action: "index",
          },
          {
            icon: "Cog",
            pageName: "dashboards.list.personal",
            title: t("Manage dashboards"),
            table: "dashboard_attach_role",
            action: "index",
          }
        ],
      },
      {
        icon: "BookOpen",
        pageName: "",
        title: t("References"),
        table: "references",
        action: "index",
        subMenu: [
          {
            icon: "User",
            pageName: "user-list",
            title: t("Users2"),
            table: 'users',
            action: 'index'
          },
          {
            icon: "Paperclip",
            pageName: "department.list",
            title: t("Departments"),
            table: 'departments',
            action: 'index'
          },
          {
            icon: "Flag",
            pageName: "country.list",
            title: t("Countries2"),
            table: 'countries',
            action: 'index'
          },
          {
            icon: "Banknote",
            pageName: "salesChannel.list",
            title: t("Sales channels"),
            table: 'sales_channels',
            action: 'index',
          },
          {
            icon: "Album",
            pageName: "association-types.list",
            title: t("Client Types"),
            table: "association_types",
            action: "index",
          },
          {
            icon: "ScreenShare",
            pageName: "domain.list",
            title: t("Domains"),
            table: 'domains',
            action: 'index'
          },
          {
            icon: "BellRing",
            pageName: "notificationTypes.list",
            title: t("Notification types"),
            table: "notification_types",
            action: "index",
          },
          {
            icon: "PaintBucket",
            pageName: "coefficients.index",
            title: t("Coefficients"),
            table: "coefficients",
            action: "index",
          },
          {
            icon: "Activity",
            pageName: "criticality.index",
            title: t("Criticality"),
            table: "criticality",
            action: "index",
          },
          {
            icon: "CalendarRange",
            pageName: "calendar_colors.index",
            title: t("calendar.Colors dict"),
            table: "calendar_colors",
            action: "index",
          },
          {
            icon: "UserCog",
            pageName: "product_assignments.index",
            title: t("Product assignments dict"),
            table: "products",
            action: "update",
          },
        ],},
      {
        icon: "ClipboardCheck",
        pageName: "reports",
        title: t("Reports"),
        table: "reports",
        action: "index",
      },
      {
        icon: "Headphones",
        pageName: "",
        title: t("ts.Ticket System"),
        table: "ts_tickets",
        action: "index",
        subMenu: [
          {
            icon: "Monitor",
            pageName: "dashboard",
            title: t("Dashboard"),
            table: 'dashboard',
            action: 'index',
          },
          {
            icon: "Inbox",
            pageName: "ts.tickets.index",
            title: t("ts.Tickets"),
            table: 'ts_tickets',
            action: 'index',
          },
          {
            icon: "Settings",
            pageName: "",
            title: t("ts.Administration"),
            table: 'ts_administration',
            action: 'index',
            subMenu: [
              {
                icon: "FastForward",
                pageName: "ts.queues.index",
                title: t("ts.Queues"),
              },
              {
                icon: "Folders",
                pageName: "ts.topics.index",
                title: t("ts.Topics"),
              },
              {
                icon: "Clock",
                pageName: "ts.sla.index",
                title: t("ts.SLA"),
              },
              {
                icon: "Disc",
                pageName: "ts.ticket_types.index",
                title: t("ts.Ticket Types"),
              },
              {
                icon: "TrendingUp",
                pageName: "ts.priorities.index",
                title: t("ts.Priorities"),
              },
              {
                icon: "Unlock",
                pageName: "ts.queue_role_permissions.index",
                title: t("ts.Queue Roles"),
              },
              {
                icon: "Clipboard",
                pageName: "ts.ticket_templates.index",
                title: t("ts.Ticket Templates"),
              },
              {
                icon: "Octagon",
                pageName: "ts.dynamic_fields.index",
                title: t("ts.Dynamic Fields"),
              },
              {
                icon: "Filter",
                pageName: "ts.filters.index",
                title: t("ts.Filter settings"),
              },
              {
                icon: "PenTool",
                pageName: "ts.tickets-autofill.index",
                title: t("ts.Tickets autofill"),
              },
              {
                icon: "Settings",
                pageName: "ts.settings.main",
                title: t("ts.Settings"),
              },
            ]
          },
        ],
      },
    ]

    const can = getCurrentInstance()?.appContext.config.globalProperties.can as (table: string, action: string, id?: string | number) => boolean

    if (metaEnv.VITE_TAGS_ENABLED === '1') {
      state.menu.push(
        {
          icon: "Search",
          pageName: "tags-search",
          title: t("Search by tags"),
          table: "tags_search",
          action: "index",
        },
      )

      const referrences = state.menu.find(menuItem => (menuItem as Menu).table === 'references') as Menu

      if (referrences) {
        referrences.subMenu?.push(
          {
            icon: "Tags",
            pageName: "tags.list",
            title: t("Tags"),
            table: "tags",
            action: "index",
          }
        )
      }
    }

    if (metaEnv.VITE_DOCS_ENABLED === '1' && can('docs', 'index')) {
      state.menu.push({
        icon: "BookOpen",
        pageName: "docs.index",
        title: t("Documents"),
        meta: {
          key: "documents",
        },
      });
    }


    if (metaEnv.VITE_EDUCATION_ENABLED === '1' && can('education', 'index')) {
      state.menu.push({
        icon: "BookOpenCheck",
        title: t("Education"),
        pageName: "education",
        meta: {
          key: "education",
        },
      });
    }

    return state;
  }
});
