import { defineStore } from "pinia";
import axios, { AxiosError } from "axios";

import { ICollectable } from "@/components/ElementCollection/interfaces";

const URL = "/api/telegram_chats/";

export const useTelegramChatsStore = defineStore("telegram_chats", () => {
  async function getChats (telegram_chat_related_type: string, telegram_chat_related_id: string | number): Promise<Array<ICollectable>> {
    try {
      const res = await axios.get(URL, {
        params: {
          telegram_chat_related_type,
          telegram_chat_related_id,
        }
      });
      return res.data;
    } catch (err) {
      const error = err as AxiosError;
      throw error.response;
    }
  }

  async function createChat (telegram_chat_related_type: string, telegram_chat_related_id: string | number, value: string): Promise<ICollectable> {
    try {
      const res = await axios.post(URL, {
        telegram_chat_related_type,
        telegram_chat_related_id,
        value,
      });
      return res.data;
    } catch (err) {
      const error = err as AxiosError;
      throw error.response;
    }
  }

  async function updateChat (id: number | string, value: string): Promise<void> {
    try {
      await axios.put(URL + id, { name: value });
    } catch (err) {
      const error = err as AxiosError;
      throw error.response;
    }
  }

  async function deleteChat (id: number | string): Promise<void> {
    try {
      await axios.delete(URL + id);
    } catch (err) {
      const error = err as AxiosError;
      throw error.response;
    }
  }

  return {
    getChats,
    createChat,
    updateChat,
    deleteChat,
  };

});
