import { defineStore } from "pinia";
import axios from "@/axios";
import { AxiosError, isAxiosError } from "axios";
import {computed, ref} from "vue";
import {PaginationInterface} from "@/components/Pagination/interfaces";
import {IAdvert} from "@/stores/trader/interfaces";
import {IFilterData, ISelect} from "@/utils/interfaces";

export const useTraderAdvertStore = defineStore("advert", () => {
  const store = ref({
    list: [] as IAdvert[],
    item: {} as IAdvert,
    meta: {} as PaginationInterface,
    selectList: [] as ISelect[],
    selectTypesList: [] as ISelect[],
  })

  const getList = computed(() => store.value.list)
  const getItem = computed(() => store.value.item)
  const pagination = computed(() => store.value.meta)
  const getSelectList = computed(() => store.value.selectList)
  const getSelectTypesList = computed(() => store.value.selectTypesList)
  async function list(filterData: IFilterData, id: string) {
    try {
      store.value.list = []
      const resp = await axios.get(`api/trader/ads/${id}`, {params: filterData})
      store.value.list = resp.data.data
      store.value.meta = resp.data
    } catch (error: unknown) {
      if(isAxiosError(error)) {
        throw error.response
      }
      throw error
    }
  }

  async function show(id: string) {
    if (Number(id) === store.value.item?.id) return
    try {
      const resp = await axios.get(`api/traders/${id}`)
      store.value.item = resp.data.data
      return resp.data.data
    } catch (error: unknown) {
      if(isAxiosError(error)) {
        throw error.response
      }
      throw error
    }
  }

  async function selectList() {
    try {
      const resp = await axios.get(`api/trader/ad/statuses/list`)
      store.value.selectList = resp.data.data
      return resp.data
    } catch (error: unknown) {
      if(isAxiosError(error)) {
        throw error.response
      }
      throw error
    }
  }

  async function selectTypesList() {
    try {
      const resp = await axios.get(`api/trader/ad/types/list`)
      store.value.selectTypesList = resp.data.data
      return resp.data
    } catch (error: unknown) {
      if(isAxiosError(error)) {
        throw error.response
      }
      throw error
    }
  }
  async function download() {
    try {
      const resp = await axios.get(`api/trader/ad/export`)
      store.value.selectTypesList = resp.data.data
      return resp.data
    } catch (error: unknown) {
      if(isAxiosError(error)) {
        throw error.response
      }
      throw error
    }
  }
  return { show, list, getList, pagination, getItem, selectList, getSelectList, selectTypesList, getSelectTypesList };
});
