import { defineStore } from "pinia";
import axios from "@/axios";
import { isAxiosError } from "axios";
import {computed, ref} from "vue";
import {PaginationInterface} from "@/components/Pagination/interfaces";
import {ICashFlow, IAddr} from "@/stores/trader/interfaces";
import {IFilterData, ISelect} from "@/utils/interfaces";

export const useTraderCashFlowStore = defineStore("cash-flow", () => {
  const store = ref({
    list: [] as ICashFlow[],
    total: 0,
    item: {} as ICashFlow,
    meta: {} as PaginationInterface,
    selectList: [] as ISelect[],
    addrList: [] as IAddr[],
    addrTotal: 0,
  })

  const getList = computed(() => store.value.list)
  const getTotal = computed(() => store.value.total)
  const getAddrList = computed(() => store.value.addrList)
  const getAddrTotal = computed(() => store.value.addrTotal)
  const getItem = computed(() => store.value.item)
  const pagination = computed(() => store.value.meta)
  const getSelectList = computed(() => store.value.selectList)
  async function list(filterData: IFilterData, id: string) {
    try {
      if (filterData && Object.keys(filterData).length > 0) {
        store.value.list = []
        const resp = await axios.get(`api/trader/cash-flow-statement/${id}`, {params: filterData})
        store.value.list = resp.data.data
        store.value.total = resp.data.total_invoices
        store.value.meta = resp.data
      } else {
        store.value.list = [] as ICashFlow[]
        store.value.meta = {} as PaginationInterface
        store.value.total = 0
      }
    } catch (error: unknown) {
      if(isAxiosError(error)) {
        throw error.response
      }
      throw error
    }
  }
  async function addrList(filterData: IFilterData, id: string) {
    try {
      store.value.addrList = []
      const resp = await axios.get(`api/trader/cash-flow-statement/addr/${id}`, {params: filterData})
      store.value.addrList = resp.data.data
      store.value.addrTotal = resp.data.total
    } catch (error: unknown) {
      if(isAxiosError(error)) {
        throw error.response
      }
      throw error
    }
  }

  async function selectList() {
    try {
      const resp = await axios.get(`api/trader/cash-flow-statement/statuses/list`)
      store.value.selectList = resp.data.data
      return resp.data
    } catch (error: unknown) {
      if(isAxiosError(error)) {
        throw error.response
      }
      throw error
    }
  }

  return {
    list,
    getList,
    getTotal,
    pagination,
    getItem,
    selectList,
    getSelectList,
    getAddrList,
    getAddrTotal,
    addrList
  };
});
