import { defineStore } from "pinia";
import axios from "@/axios";
import { AxiosError, isAxiosError } from "axios";
import {computed, ref} from "vue";
import {PaginationInterface} from "@/components/Pagination/interfaces";
import {IFinancialIndicator} from "@/stores/trader/interfaces";
import {IFilterData, ISelect} from "@/utils/interfaces";

export const useTraderFinancialIndicatorsStore = defineStore("financial-indicators", () => {
  const store = ref({
    list: [] as IFinancialIndicator[],
    trader: {} as IFinancialIndicator,
    meta: {} as PaginationInterface,
    selectList: [] as ISelect[],
  })

  const getList = computed(() => store.value.list)
  const getTrader = computed(() => store.value.trader)
  const pagination = computed(() => store.value.meta)
  const getSelectMerchantList = computed(() => store.value.selectList)
  async function list(filterData: IFilterData, id: string) {
    try {
      store.value.list = []
      store.value.trader = {} as IFinancialIndicator
      const resp = await axios.get(`api/trader/financial-indicators/${id}`, {params: filterData})
      store.value.list = resp.data.data.merchants.data
      store.value.trader = resp.data.data.trader
      store.value.meta = resp.data.data.merchants
    } catch (error: unknown) {
      if(isAxiosError(error)) {
        throw error.response
      }
      throw error
    }
  }
  async function selectMerchantList(id: string) {
    try {
      const resp = await axios.get(`api/trader/financial-indicators/merchants/list/${id}`)
      store.value.selectList = resp.data.data
      return resp.data
    } catch (error: unknown) {
      if(isAxiosError(error)) {
        throw error.response
      }
      throw error
    }
  }

  return { list, getList, pagination, getSelectMerchantList, selectMerchantList, getTrader };
});
