import {IPayportMerchant} from "@/pages/products/interfaces";
import { IServiceProvider, IServiceProviderCurrencySettingForm } from "@/stores/service_providers/interfaces";
import { IUserShort } from "@/pages/users/interfaces";
import { IContactable } from "@/utils/interfaces";
import { ITelegramChats } from "../telegram_chats/interfaces";

interface ITrader extends IContactable {
  id: number,
  id_payport: number,
  id_payport_sand: number,
  name: string,
  status: string,
  email: string,
  telegram: string,
  inputFiats: string,
  outputFiats: string,
  created_at: string,
  service_provider: IServiceProvider,
  available_balances: ITraderBalanceRow[],
  phone: string,
  ads_hidden: string,
  environment_type: string,
  locale: string,
  agent_id: string,
  service_provider_id: string,
  payport_agent_id: string,
  payport_service_provider_id: string,
  responsible_user_ids: Array<string>,
  responsible_users: Array<IUserShort>,
  chats: Array<ITelegramChats> | null,
  sp_currency_settings_ids?: Array<string>,
  // payment_system: ITraderPaymentSystem
}

interface ITraderForm {
  name: string,
  status: string,
  email: string,
  phone: string,
  telegram: string,
  ads_hidden: string,
  environment_type: string,
  locale: string,
  payport_agent_id: string,
  payport_service_provider_id: string,
  service_provider_id?: string,
  responsible_user_ids: Array<string>,
  sp_currency_settings_ids?: Array<string>,
  old_sp_currency_settings_ids?: Array<string>,
  sp_currency_settings?: Array<IServiceProviderCurrencySettingForm>,
}

interface ITraderBalanceRow {
    amount: number,
    currency: string,
}

interface ITraderMerchant {
  name: string,
  email?: string,
  status: number,
  status_name: string,
  product_payport_merchant: IPayportMerchant[]
}

interface ITraderFiat {
    id: number,
    asset: string,
    name: string,
    status: number,
    precision?: number,
    pusdt_address_view?: boolean,
    rate: ITraderRate,
}

interface ITraderRate {
    source: ItraderRateSource,
}

interface ItraderRateSource {
    name: string,
}

interface ITraderPaymentSystem {
    id: number,
    name: string,
    status: number,
    available_payment_types: PaymentSystemType [],
}

interface PaymentSystemType {
    id: number,
    name: string,
    obj_name: string,
}

interface IAdvert {
    id: number,
    type: string,
    ad_status?: string,
    email: string,
    telegram: string,
    inputFiats: string,
    min_amount: number,
    max_amount: number,
    rate: number,
    ad_rate_type: number,
    rate_id: number,
    fiat?: ITraderFiat,
    trader?: ITrader,
    payment_system?: ITraderPaymentSystem,
    owner_name?: string,
    card_number?: string,
    ad_type?: string,
    payment_attributes?: object,
    created_at?: string,
    updated_at?: string,
}

interface ICashFlow {
    id: number,
    type: string,
    amount?: string,
    address: string,
    created_at: string,
}

interface IAddr {
    address: string,
    amount: string,
    first_created_at: string,
    last_created_at: string,
}

interface IFinancialIndicator {
    name: string,
    withdrawal_sum?: string,
    input_sum?: string,
    balance?: string,
}

interface IMerchant {
    id?: number;
    name?: string;
    email?: string;
    balance?: IMerchantBalance
}

interface IMerchantBalance {
    id: number;
    merchant_id: number;
    amount: string;
    created_at: string;
    updated_at: string;
}

interface IPaymentSystem {
    id: number;
    name?: string;
    bg_color: string
    color: string
}

interface IPaymentAdditionInfo {
    ad: {
      coin: string,
    },
    contact: {
      cancellation_reason: string | null,
      payment_completed_at: string | null,
      payment_attributes: IPaymentAttributes,
    }
}

interface IPaymentAttributes {
    client_name?: string,
    client_email?: string,
    invoice_type?: number,
}

interface ITransaction {
    id: number,
    created_at: string,
    expired_at: string,
    input_rate: string,
    fiat_rate: string,
    completed_at: string | null,
    usdt_amount: string,
    usdt_amount2pay?: string,
    usdt_amount2grow?: string,
    usdt_amount2service?: string,
    usdt_amount2agent?: string,
    usdt_amount2service_agents?: string,
    usdt_amount2markup_payport?: string,
    usdt_amount2markup_agents?: string,
    merchant_id?: number,
    merchant_order_id?: string,
    api_type: number,
    status: number,
    fiat_currency: string,
    fiat_amount: string,
    invoice_type: number,
    payment_id?: string,
    service_provider_id?: number,
    payment_system_id?: number,
    type?: number,
    comment?: string,
    trader_id?: number,
    trader_name?: string,
    deal_status?: number,
    amount2agent_selected?: string,
    amount2service_agent_selected?: string,
    serviceAgentCommision?: number,
    agentCommision?: number,
    cancellation_reason_id?: number,
    merchant?: IMerchant,
    payment_system?: IPaymentSystem,
    service_provider?: IServiceProvider,
    addition_info?: IPaymentAdditionInfo,
    payment_attributes?: IPaymentAttributes
    check?: number,
    card_number?: string,
    first_paid_time?: string,
    owner_name?: string,
    trader_reaction_time?: string,
    first_paid_at?: string,
}

interface ITransactionTotal {
    invoice_count: number,
    usdt_amount: number,
    volume: number,
    usdt_amount2pay: number,
    usdt_amount2grow: number,
    usdt_amount2service: number,
    usdt_amount2agent: number,
    usdt_amount2service_agents: number,
    usdt_amount2agent_selected: number,
    usdt_amount2service_agent_selected: number,
    usdt_amount2markup_payport: number,
    usdt_amount2markup_agents: number,
    fiat_amount: boolean | string
}

export type {
  ITrader,
  ITraderForm,
  IServiceProvider,
  ITraderMerchant,
  IAdvert,
  PaymentSystemType,
  ICashFlow,
  IAddr,
  IFinancialIndicator,
  ITransaction,
  ITransactionTotal,
  ITraderBalanceRow
};
