import { defineStore } from "pinia";
import axios from "@/axios";
import { AxiosError, isAxiosError } from "axios";
import {computed, ref} from "vue";
import {PaginationInterface} from "@/components/Pagination/interfaces";
import {ITraderMerchant} from "@/stores/trader/interfaces";
import {IFilterData} from "@/utils/interfaces";

export const useTraderMerchantsStore = defineStore("trader_merchants", () => {
  const store = ref({
    list: [] as ITraderMerchant[],
    item: {} as ITraderMerchant,
    meta: {} as PaginationInterface,
  })

  const getList = computed(() => store.value.list)
  const getItem = computed(() => store.value.item)
  const pagination = computed(() => store.value.meta)
  async function list(filterData: IFilterData, id: string) {
    try {
      store.value.list = []
      const resp = await axios.get(`api/traders/merchants/${id}`, {params: filterData})
      store.value.list = resp.data.data
      store.value.meta = resp.data
    } catch (error: unknown) {
      if(isAxiosError(error)) {
        throw error.response
      }
      throw error
    }
  }

  return { list, getList, pagination, getItem };
});
