import { defineStore } from 'pinia'
import axios from '../../axios'
import { ref, computed } from 'vue'
import { IModelLog } from "@/stores/client_log/interfaces";
import { IPage } from "@/utils/interfaces";

export const useTraderLogStore = defineStore('trader-log', () => {
  const store = ref({
    traderLog: {} as IPage<IModelLog>,
    traderCommunicationsLog: {} as IPage<IModelLog>,
    traderContactPersonLog: {} as IPage<IModelLog>,
  })

  const getTraderLog = computed(() => store.value.traderLog.data)
  const getTraderCommunicationsLog = computed(() => store.value.traderCommunicationsLog.data)
  const getTraderContactPersonLog = computed(() => store.value.traderContactPersonLog.data)

  async function traderLog(id: number) {
    try {
      let url = `api/log/traders/${id}`
      if(store.value.traderLog.data && store.value.traderLog.next_page_url === null) {
        return
      }
      if(store.value.traderLog.next_page_url) {
        url = store.value.traderLog.next_page_url
      }

      const resp = await axios.get(url)
      if(store.value.traderLog.data) {
        resp.data.data.data.forEach(function(item: IModelLog) {
          store.value.traderLog.data.push(item)
        });
        store.value.traderLog.next_page_url = resp.data.data.next_page_url
        store.value.traderLog.next_cursor = resp.data.data.next_cursor
      } else {
        store.value.traderLog = resp.data.data
      }

    } catch (error: any) {
      console.log(error)
      throw error.response
    }
  }
  async function traderCommunicationsLog(id: number) {
    try {
      let url = `api/log/traders/communications/${id}`
      if(store.value.traderCommunicationsLog.data && store.value.traderCommunicationsLog.next_page_url === null) {
        return
      }
      if(store.value.traderCommunicationsLog.next_page_url) {
        url = store.value.traderCommunicationsLog.next_page_url
      }
      const resp = await axios.get(url)
      if(store.value.traderCommunicationsLog.data) {
        resp.data.data.data.forEach(function(item: IModelLog) {
          store.value.traderCommunicationsLog.data.push(item)
        });
        store.value.traderCommunicationsLog.next_page_url = resp.data.data.next_page_url
        store.value.traderCommunicationsLog.next_cursor = resp.data.data.next_cursor
      } else {
        store.value.traderCommunicationsLog = resp.data.data
      }
    } catch (error: any) {
      throw error.response
    }
  }
  async function traderContactPersonLog(id: number) {
    try {
      let url = `api/log/traders/contact-persons/${id}`
      if(store.value.traderContactPersonLog.data && store.value.traderContactPersonLog.next_page_url === null) {
        return
      }
      if(store.value.traderContactPersonLog.next_page_url) {
        url = store.value.traderContactPersonLog.next_page_url
      }
      const resp = await axios.get(url)
      if(store.value.traderContactPersonLog.data) {
        resp.data.data.data.forEach(function(item: IModelLog) {
          store.value.traderContactPersonLog.data.push(item)
        });
        store.value.traderContactPersonLog.next_page_url = resp.data.data.next_page_url
        store.value.traderContactPersonLog.next_cursor = resp.data.data.next_cursor
      } else {
        store.value.traderContactPersonLog = resp.data.data
      }
    } catch (error: any) {
      throw error.response
    }
  }

  function clear() {
    store.value.traderLog = {}  as IPage<IModelLog>
    store.value.traderCommunicationsLog = {} as IPage<IModelLog>
    store.value.traderContactPersonLog = {} as IPage<IModelLog>
  }

  return {
    store,
    getTraderLog,
    getTraderCommunicationsLog,
    traderLog,
    traderCommunicationsLog,
    traderContactPersonLog,
    getTraderContactPersonLog,
    clear
  }
})
