import { defineStore } from "pinia";
import axios from "@/axios";
import { AxiosError, isAxiosError } from "axios";
import {computed, ref} from "vue";
import {PaginationInterface} from "@/components/Pagination/interfaces";
import {ITransaction, ITransactionTotal} from "@/stores/trader/interfaces";
import {IFilterData, ISelect} from "@/utils/interfaces";

export const useTraderTransactionsStore = defineStore("transactions", () => {
  const store = ref({
    list: [] as ITransaction[],
    sum: {} as ITransactionTotal,
    meta: {} as PaginationInterface,
    fiatsFilter: [] as ISelect[],
    selectInvoiceTypesList: [] as ISelect[],
  })

  const getList = computed(() => store.value.list)
  const getSum = computed(() => store.value.sum)
  const pagination = computed(() => store.value.meta)
  const getFiatsFilter = computed(() => store.value.fiatsFilter)
  const getSelectInvoiceTypesList = computed(() => store.value.selectInvoiceTypesList)

  async function list(filterData: IFilterData, id: string) {
    try {
      store.value.list = []
      const resp = await axios.get(`api/trader/transactions/${id}`, {params: filterData})
      store.value.list = resp.data.deals.data
      store.value.sum = resp.data.sum
      store.value.meta = resp.data.deals
    } catch (error: unknown) {
      if(isAxiosError(error)) {
        throw error.response
      }
      throw error
    }
  }

  async function fiatsFilter ()
  {
    try {
      const resp = await axios.get(`/api/trader/get-fiats-filter`);
      store.value.fiatsFilter = resp.data.data
      return resp.data
    } catch (error: unknown) {
      if(isAxiosError(error)) {
        throw error.response
      }
      throw error
    }
  }

  async function selectInvoiceTypesList() {
    try {
      const resp = await axios.get(`api/trader/invoice-types/list`)
      store.value.selectInvoiceTypesList = resp.data.data
      return resp.data
    } catch (error: unknown) {
      if(isAxiosError(error)) {
        throw error.response
      }
      throw error
    }
  }

  return { list, getList, pagination, getSum, selectInvoiceTypesList, getSelectInvoiceTypesList, fiatsFilter, getFiatsFilter };
});
