import { defineStore } from "pinia";
import axios from "@/axios";
import { AxiosError, isAxiosError } from "axios";
import {computed, ref, Ref} from "vue";
import {PaginationInterface} from "@/components/Pagination/interfaces";
import {IFilterData, ISelect} from "@/utils/interfaces";
import { IUserShort } from "@/pages/users/interfaces";
import { IPage } from "@/utils/interfaces";
import { useI18n } from "vue-i18n";
import {ITraderAdminForm, ITraderAdmins, ITraderAdminsRoles} from "@/stores/trader_admins/interfaces";
import {ITrader, ITraderForm} from "@/stores/trader/interfaces";

export const useTraderAdminStore = defineStore("trader-admin", () => {
  const { t } = useI18n();

  const environmentsList: Ref<ISelect[]> = ref([
    { text: t("New"), value: "0", disabled: false },
    // { text: t("Sandbox"), value: "1", disabled: false },
    { text: t("Production"), value: "2", disabled: false },
  ]);

  const statusesList = [
    { text: t("Inactive status"), value: "0" },
    { text: t("Active status"), value: "1" },
  ];

  const yesNoList = [
    { text: t("No"), value: "0" },
    { text: t("Yes"), value: "1" },
  ];

  const languagesList = [
    { text: t("Russian"), value: "ru" },
    { text: t("English"), value: "en" },
  ];

  const store = ref({
    list: [] as ITraderAdmins[],
    item: {} as ITraderAdmins,
    meta: {} as PaginationInterface,
    roles: [] as Array<string>,
    environmentsList: environmentsList,
    statusesList: statusesList,
    yesNoList: yesNoList,
    languagesList: languagesList,
    available_providers_ids: [] as Array<string>,
    selectList: [] as ISelect[],
  })

  const getList = computed(() => store.value.list)
  const getSelectList = computed(() => store.value.selectList)
  const getItem = computed(() => store.value.item)
  const pagination = computed(() => store.value.meta)

  async function list(filterData: IFilterData): Promise<IPage<ITraderAdmins>> {
    try {
      store.value.list = []
      const resp = await axios.get(`api/trader-admins`, {params: filterData})
      store.value.list = resp.data.data
      store.value.meta = resp.data
      return resp.data
    } catch (error: unknown) {
      if(isAxiosError(error)) {
        throw error.response
      }
      throw error
    }
  }

  async function getAvailableTraders(service_providers: Array<string>): Promise<Array<ITrader>> {
    try {
      const resp = await axios.get(`api/trader-admins/available-traders`, {params: {available_providers_ids: service_providers}})
      return resp.data
    } catch (error: unknown) {
      if(isAxiosError(error)) {
        throw error.response
      }
      throw error
    }
  }
  async function show(id: string) {
    // if (Number(id) === store.value.item?.id) return
    try {
      const resp = await axios.get(`api/trader-admins/${id}`)
      store.value.item = resp.data
      return resp.data
    } catch (error: unknown) {
      if(isAxiosError(error)) {
        throw error.response
      }
      throw error
    }
  }

  async function selectList() {
    try {
      const resp = await axios.get('/api/traders/list')
      store.value.selectList = resp.data.data
    } catch (e) {
      throw e
    }
  }

  async function getTraderAdminsRoles() {
    try {
      const resp = await axios.get('/api/trader-admins/roles')
      return resp.data;
    } catch (e) {
      throw e
    }
  }
  async function createTraderAdmin(data: ITraderAdminForm) {
    try {
      await axios.post("/api/trader-admins", data);
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function updateTraderAdmin(id: number|string|null, data: ITraderAdminForm) {
    try {
      await axios.put("/api/trader-admins/" + id, data);
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  return { store, show, list, getList, pagination, getItem,  selectList, getSelectList, getTraderAdminsRoles, createTraderAdmin, updateTraderAdmin, getAvailableTraders};
});
