import {ISelect} from "@/utils/interfaces";
import {IPayportMerchant} from "@/pages/products/interfaces";
import {ITelegramChats} from "@/stores/telegram_chats/interfaces";
import {IClient} from "@/pages/clients/interfaces";

interface ITransactionFilter {
  status?: Array<ISelect>,
  invoice_types?: Array<ISelect>,
  withdrawal_types?: Array<ISelect>,
  fiats?: Array<ISelect>,
  payment_systems?: Array<ISelect>,
  service_providers?: Array<ISelect>,
  invoice_type: Array<ISelect>,
  merchants?: Array<ISelect>,
  traders?: Array<ISelect>,
  cancellation_reasons?: Array<ISelect>,
  deal_arbitrage_items?: Array<ISelect>,
  payment_system_attributes?: Array<ISelect>
}

interface ITransactionTotal {
  invoice_count: number,
  usdt_amount: number,
  volume: number,
  usdt_amount2pay: number,
  usdt_amount2grow: number,
  usdt_amount2service: number,
  usdt_amount2agent: number,
  usdt_amount2service_agents: number,
  usdt_amount2agent_selected: number,
  usdt_amount2service_agent_selected: number,
  usdt_amount2markup_payport: number,
  usdt_amount2markup_agents: number,
  fiat_amount: boolean | string
}
interface IDealData {
    id?: string;
    trader_id?: string;
    trader?: string;
    type?: string;
    status?: string;
    is_cancelled?: boolean;
    cancellation_reason?: string;
    rate?: string;
    fiat_amount?: string;
    card_number?: string;
    payment_info?: string;
    created_at?: string;
    life_time_at_funded?: string;
    first_paid_at?: string;
    first_paid_time?: string;
    fiat_id?: string;
    sp_transaction_id?: string;
    amount?: string;
    actual_paid_amount?: string;
    sp_status?: string;
    payment_attributes?: string;
    address?: string;
    scan_url?: string;
    address_amount?: string;
    unformatted?: string;
    expired_at?: string;
    amount_currency?: string;
}
interface IProductPayportMerchantExtended extends IPayportMerchant{
  chats: Array<ITelegramChats> | null,
  client?: IClient
}

interface ITransaction {
  id: number;
  created_at: string;
  expired_at: string;
  input_rate: string;
  invoice_rate: string;
  fiat_rate: string;
  bin: string;
  blocked_operation: string;
  is_blocked_customer: boolean;
  is_casino_scheme: boolean;
  is_moneybox: boolean;
  completed_at: string | null;
  usdt_amount: string;
  usdt_amount2pay?: string;
  usdt_amount2grow?: string;
  usdt_amount2service?: string;
  usdt_amount2agent?: string;
  usdt_amount2service_agents?: string;
  usdt_amount2markup_payport?: string;
  usdt_amount2markup_agents?: string;
  merchant_id?: number;
  merchant_order_id?: string;
  api_type: number;
  status: number;
  fiat_currency: string;
  fiat_amount: string;
  invoice_type: number;
  payment_id?: string;
  service_provider_id?: number;
  payment_system_id?: number;
  type?: number;
  comment?: string;
  trader_id?: number;
  trader_name?: string;
  deal_status?: number;
  amount2agent_selected?: string;
  amount2service_agent_selected?: string;
  serviceAgentCommision?: number;
  agentCommision?: number;
  cancellation_reason_id?: number;
  merchant?: IMerchant;
  merchant_order_desc?: string;
  merchant_agreement?: string;
  payment_system?: IPaymentSystem;
  service_provider?: IServiceProvider;
  addition_info?: IPaymentAdditionInfo;
  payment_attributes?: IPaymentAttributes;
  service_provider_type?: string;
  dealData?: IDealData;
  type_amount?: string;
  product_merchant?: IProductPayportMerchantExtended;
  input_request?: {
      [key: string]:{ label: string; value: string }
  },
  attachments?: Array<{id:string, url:string}>
  trader_agreements?: string;
  ad?: {
      id: number;
      bank_name?: string;
      card_number?: string;
      owner_name?: string;
      min_amount?: string;
      max_amount?: string;
      temp_price?: string;
  }
  agentCommissions?: Array<{
      id: number,
      commission_value: string,
      agent_type_name: string,
      agent: {
          id: number,
          name: string
      }
  }>,
  usdt_amount2trader?: string,
  cancellation_reasons?: {
      message: string,
      contacts: string,
      files: Array<{id: string, name: string}>,
      cancellation_reasons: Array<{id: number, name: string}>
  }
}

interface IPaymentAdditionInfo {
  ad: {
    coin: string,
    //
  },
  contact: {
    cancellation_reason: string | null,
    payment_completed_at: string | null,
    payment_attributes: IPaymentAttributes,
  }
}

interface IPaymentAttributes {
  client_name?: string,
  client_email?: string,
  invoice_type?: number,
}

interface IServiceProvider {
  id?: number;
  name?: string;
  status?: number;
  created_at?: Date;
  updated_at?: Date;
  type?: string;
  chat_name?: string;
}

interface IPaymentSystem {
  id: number;
  name?: string;
  bg_color: string
  color: string
}

interface IMerchant {
  id?: number;
  name?: string;
  email?: string;
  balance?: IMerchantBalance
}

interface IMerchantBalance {
  id: number;
  merchant_id: number;
  amount: string;
  created_at: string;
  updated_at: string;
}

interface ISearchableTransaction {
  id: number
  payment_id: number
  invoice_type: InvoiceTypes,
  amount: string
}

interface IDealHistory {
    id: number
    created_at: string
    status: string,
    description: string,
    customer_id: string,
    customer_name: string,
    customer_type: string
}

interface ITransactionShow {
  id: number
  payment_id: string
  created_at: string
  fiat_currency: string | null
  fiat_amount: string
  merchant_id: number
  merchant_name: string
  merchant_email: string
  service_provider_id: number
  service_provider_name: string
  trader_id: number
  trader_name: string
  invoice_type: InvoiceTypes,
  trader_email: string
  usdt_amount: string
  amount: string
}

interface InvoiceHistory {
    id: number;
    invoice_id: number;
    invoice_type: number;
    event_id: number;
    event: string;
    status: string;
    source_request?: string;
    source_response?: string;
    additional_info?: string;
    instance?: string;
    comment?: string;
    created_at: string;
    updated_at?: string;
}

enum InvoiceTypes {
  INPUT,
  WITHDRAWAL,
}

export type {
  ITransactionFilter,
  ITransaction,
  IMerchant,
  IServiceProvider,
  IPaymentAdditionInfo,
  IPaymentAttributes,
  ITransactionTotal,
  ISearchableTransaction,
  ITransactionShow,
  InvoiceHistory,
  IDealHistory,
}

export {
  InvoiceTypes,
}
