import {IFilterData, IPage} from "@/utils/interfaces";
import {IClientsApi, IClientsApiUpdateForm} from "@/pages/ts/clients_api/interfaces";
import {ClientsApi} from "@/pages/ts/clients_api/classes";
import {defineStore} from "pinia";
import axios from "@/axios";
import {AxiosError} from "axios";

const URL = "/api/ts/clients_api";

export const useClientsApiStore = defineStore("clients_api", () => {
  async function getRows(params: IFilterData = {}): Promise<IPage<IClientsApi>> {
    try {
      const res = await axios.get(URL, {params});
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getRowsShort(params: IFilterData = {}): Promise<Array<IClientsApi>> {
    try {
      const res = await axios.get(URL, {params});
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getOneRow(id: number | string | null): Promise<IClientsApi> {
    try {
      const res = await axios.get(URL + "/" + id + "/edit");
      return new ClientsApi(res.data);
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function createRow(params: IClientsApiUpdateForm): Promise<IClientsApi> {
    try {
      const res = await axios.post(URL, params);
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function updateRow(id: number | string | null, data: IClientsApiUpdateForm): Promise<IClientsApi> {
    try {
      const res = await axios.put(URL + "/" + id, data);
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  return {getRows, getRowsShort, getOneRow, createRow, updateRow};
});
