import {IFilterData, IPage} from "@/utils/interfaces";
import {IDynamicField, IDynamicFieldForList, IDynamicFieldUpdateForm} from "@/pages/ts/dynamic_fields/interfaces";
import {DynamicField} from "@/pages/ts/dynamic_fields/classes";
import {defineStore} from "pinia";
import axios from "@/axios";
import {AxiosError} from "axios";

const URL = "/api/ts/dynamic_fields";

export const useDynamicFieldStore = defineStore("dynamic_fields", () => {
  async function getAllRows(): Promise<Array<IDynamicField>> {
    try {
      const res = await axios.get(URL + "/all");
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getRows(params: IFilterData = {}): Promise<IPage<IDynamicFieldForList>> {
    try {
      const res = await axios.get(URL, {params});
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getOneRow(id: number | string | null): Promise<IDynamicField> {
    try {
      const res = await axios.get(URL + "/" + id + "/edit");
      return new DynamicField(res.data);
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function createRow(params: IDynamicFieldUpdateForm): Promise<IDynamicField> {
    try {
      const res = await axios.post(URL, params);
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function updateRow(id: number | string | null, data: IDynamicFieldUpdateForm): Promise<IDynamicField> {
    try {
      const res = await axios.put(URL + "/" + id, data);
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  return {getAllRows, getRows, getOneRow, createRow, updateRow};
});
