import {IFilterData, IPage} from "@/utils/interfaces";
import {IEscalation, IEscalationForList, IEscalationUpdateForm} from "@/pages/ts/escalation/interfaces";
import {Escalation} from "@/pages/ts/escalation/classes";
import {defineStore} from "pinia";
import axios from "@/axios";
import {AxiosError} from "axios";

const URL = "/api/ts/escalation";

export const useEscalationStore = defineStore("escalation", () => {
  async function getAllRows(): Promise<Array<IEscalation>> {
    try {
      const res = await axios.get(URL + "/all");
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getRows(params: IFilterData = {}): Promise<IPage<IEscalationForList>> {
    try {
      const res = await axios.get(URL, {params});
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getOneRow(id: number | string | null): Promise<IEscalation> {
    try {
      const res = await axios.get(URL + "/" + id + "/edit");
      return new Escalation(res.data);
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function createRow(params: IEscalationUpdateForm): Promise<IEscalation> {
    try {
      const res = await axios.post(URL, params);
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function updateRow(id: number | string | null, data: IEscalationUpdateForm): Promise<IEscalation> {
    try {
      const res = await axios.put(URL + "/" + id, data);
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  return {getAllRows, getRows, getOneRow, createRow, updateRow};
});
