import {defineStore} from "pinia";
import {ISaveFilterSettingPayload, ISettingData} from "@/pages/ts/filters/interfaces";
import axios from "@/axios";
import {IPage, ISelect} from "@/utils/interfaces";

const URL = "/api/ts/filters";

export const useFilterPresetStore = defineStore('ticket_filters', () => {

  async function create(payload: ISaveFilterSettingPayload) {
    try {
      await axios.post(URL, payload)
    }
    catch (e) {
      throw e
    }
  }

  async function update(payload: ISaveFilterSettingPayload) {
    try {
      await axios.patch(URL, payload)
    }
    catch (e) {
      throw e
    }
  }

  async function getAllByRole(roleId: number) {
    try {
      const response = await axios.get(URL + '/roles/' + roleId)

      return response.data as IPage<ISettingData>
    }
    catch (e) {
      throw e
    }
  }

  async function getOneById(id: number) {
    try {
      const response = await axios.get(URL + '/' + id)

      return response.data.preset as ISettingData | null
    }
    catch (e) {
      throw e
    }
  }

  async function getRolesByFiltersSelectList() {
    try {
      const response = await axios.get(URL + '/roles-by-filters-select-list')

      return response.data as ISelect[]
    }
    catch (e) {
      throw e
    }
  }

  async function getPresetsByRole(roleId: number) {
    try {
      const response = await axios.get(URL + '/presets-by-role-select-list/' + roleId)

      return response.data as ISelect[]
    }
    catch (e) {
      throw e
    }
  }

  async function remove(presetId: number) {
    try {
      await axios.delete(URL + '/' + presetId)
    }
    catch (e) {
      throw e
    }
  }

  return {
    update,
    create,
    remove,
    getAllByRole,
    getOneById,
    getPresetsByRole,
    getRolesByFiltersSelectList,
  }
})