import {IFilterData, IPage} from "@/utils/interfaces";
import {IMailAccount, IMailAccountForList, IMailAccountUpdateForm} from "@/pages/ts/mail_accounts/interfaces";
import {MailAccount} from "@/pages/ts/mail_accounts/classes";
import {defineStore} from "pinia";
import axios from "@/axios";
import {AxiosError} from "axios";

const URL = "/api/ts/mail_accounts";

export const useMailAccountsStore = defineStore("mail_accounts", () => {
  async function getAllRows(): Promise<Array<IMailAccount>> {
    try {
      const res = await axios.get(URL + "/all");
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getRows(params: IFilterData = {}): Promise<IPage<IMailAccountForList>> {
    try {
      const res = await axios.get(URL, {params});
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getRowsShort(params: IFilterData = {}): Promise<Array<IMailAccountForList>> {
    try {
      const res = await axios.get(URL, {params});
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getOneRow(id: number | string | null): Promise<IMailAccount> {
    try {
      const res = await axios.get(URL + "/" + id + "/edit");
      return new MailAccount(res.data);
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function createRow(params: IMailAccountUpdateForm): Promise<IMailAccount> {
    try {
      const res = await axios.post(URL, params);
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function updateRow(id: number | string | null, data: IMailAccountUpdateForm): Promise<IMailAccount> {
    try {
      const res = await axios.put(URL + "/" + id, data);
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getCountNewMessages(params: IFilterData = {}): Promise<string> {
    try {
      const res = await axios.get(URL + "/count_new", {params});
      return res.data?.message as string;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function runManualInboxParsing(params: IFilterData = {}): Promise<string> {
    try {
      const res = await axios.get(URL + "/run_parsing", {params});
      return res.data?.message as string;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  return {getAllRows, getRows, getRowsShort, getOneRow, createRow, updateRow, getCountNewMessages, runManualInboxParsing};
});
