import {IFilterData, IPage, ISelect} from "@/utils/interfaces";
import {IPriority, IPriorityForList, IPriorityUpdateForm} from "@/pages/ts/priorities/interfaces";
import {Priority} from "@/pages/ts/priorities/classes";
import {defineStore} from "pinia";
import axios from "@/axios";
import {AxiosError} from "axios";

const URL = "/api/ts/priorities";

export const usePriorityStore = defineStore("priorities", () => {
  async function getAllRows(): Promise<Array<IPriority>> {
    try {
      const res = await axios.get(URL + "/all");
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getRows(params: IFilterData = {}): Promise<IPage<IPriorityForList>> {
    try {
      const res = await axios.get(URL, {params});
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getOneRow(id: number | string | null): Promise<IPriority> {
    try {
      const res = await axios.get(URL + "/" + id + "/edit");
      return new Priority(res.data);
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function createRow(params: IPriorityUpdateForm): Promise<IPriority> {
    try {
      const res = await axios.post(URL, params);
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function updateRow(id: number | string | null, data: IPriorityUpdateForm): Promise<IPriority> {
    try {
      const res = await axios.put(URL + "/" + id, data);
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getSelectList(): Promise<ISelect[]> {
    try {
      const res = await axios.get(URL + "/select_list");
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  return {getAllRows, getRows, getOneRow, createRow, updateRow, getSelectList};
});
