import {IFilterData, IPage} from "@/utils/interfaces";
import {
  IQueueRolePermission,
  IQueueRolePermissionType,
  IQueueRolePermissionUpdateForm,
} from "@/pages/ts/queue_role_permissions/interfaces";
import {QueueRolePermission} from "@/pages/ts/queue_role_permissions/classes";
import {defineStore} from "pinia";
import axios from "@/axios";
import {AxiosError} from "axios";

const URL = "/api/ts/queue_role_permissions";

export const useQueueRolePermissionStore = defineStore("queue_role_permissions", () => {
  async function getAllTypes(): Promise<Array<IQueueRolePermissionType>> {
    try {
      const res = await axios.get(URL + "/types");
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function checkAccess(params: IFilterData = {}): Promise<boolean> {
    try {
      const res = await axios.get(URL + "/access", {params});
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getAllRows(): Promise<Array<IQueueRolePermission>> {
    try {
      const res = await axios.get(URL + "/all");
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getRows(params: IFilterData = {}): Promise<Array<IQueueRolePermission>> {
    try {
      const res = await axios.get(URL, {params});
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getOneRow(id: number | string | null): Promise<IQueueRolePermission> {
    try {
      const res = await axios.get(URL + "/" + id + "/edit");
      return new QueueRolePermission(res.data);
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function createRow(params: IQueueRolePermissionUpdateForm): Promise<IQueueRolePermission> {
    try {
      const res = await axios.post(URL, params);
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function updateRow(id: number | string | null, data: IQueueRolePermissionUpdateForm): Promise<IQueueRolePermission> {
    try {
      const res = await axios.put(URL + "/" + id, data);
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function updateRows(data: IQueueRolePermissionUpdateForm) {
    try {
      const res = await axios.put(URL + "/mass", data);
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  return {getAllTypes, checkAccess, getAllRows, getRows, getOneRow, createRow, updateRow, updateRows};
});
