import {IFilterData, IPage} from "@/utils/interfaces";
import {IQueueTopic, IQueueTopicForList, IQueueTopicUpdateForm} from "@/pages/ts/queue_topics/interfaces";
import {QueueTopic} from "@/pages/ts/queue_topics/classes";
import {defineStore} from "pinia";
import axios from "@/axios";
import {AxiosError} from "axios";

const URL = "/api/ts/queue_topics";

export const useQueueTopicStore = defineStore("queue_topics", () => {
  async function getAllRows(): Promise<Array<IQueueTopic>> {
    try {
      const res = await axios.get(URL + "/all");
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getRows(params: IFilterData = {}): Promise<IPage<IQueueTopicForList>> {
    try {
      const res = await axios.get(URL, {params});
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getOneRow(id: number | string | null): Promise<IQueueTopic> {
    try {
      const res = await axios.get(URL + "/" + id + "/edit");
      return new QueueTopic(res.data);
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function createRow(params: IQueueTopicUpdateForm): Promise<IQueueTopic> {
    try {
      const res = await axios.post(URL, params);
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function updateRow(id: number | string | null, data: IQueueTopicUpdateForm): Promise<IQueueTopic> {
    try {
      const res = await axios.put(URL + "/" + id, data);
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  return {getAllRows, getRows, getOneRow, createRow, updateRow};
});
