import {IFilterData, IPage} from "@/utils/interfaces";
import {ISetting, ISettingForList, ISettingUpdateForm} from "@/pages/ts/settings/interfaces";
import {Setting} from "@/pages/ts/settings/classes";
import {defineStore} from "pinia";
import axios from "@/axios";
import {AxiosError} from "axios";

const URL = "/api/ts/settings";

export const useSettingStore = defineStore("settings", () => {
  async function getAllRows(): Promise<Array<ISetting>> {
    try {
      const res = await axios.get(URL + "/all");
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getRows(params: IFilterData = {}): Promise<IPage<ISettingForList>> {
    try {
      const res = await axios.get(URL, {params});
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getOneRow(id: number | string | null): Promise<ISetting> {
    try {
      const res = await axios.get(URL + "/" + id + "/edit");
      return new Setting(res.data);
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function createRow(params: ISettingUpdateForm): Promise<ISetting> {
    try {
      const res = await axios.post(URL, params);
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function updateRow(id: number | string | null, data: ISettingUpdateForm): Promise<ISetting> {
    try {
      const res = await axios.put(URL + "/" + id, data);
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  return {getAllRows, getRows, getOneRow, createRow, updateRow};
});
