import {IFilterData, IPage} from "@/utils/interfaces";
import {ISla, ISlaForList, ISlaUpdateForm} from "@/pages/ts/sla/interfaces";
import {Sla} from "@/pages/ts/sla/classes";
import {defineStore} from "pinia";
import axios from "@/axios";
import {AxiosError} from "axios";

const URL = "/api/ts/sla";

export const useSlaStore = defineStore("sla", () => {
  async function getAllRows(): Promise<Array<ISla>> {
    try {
      const res = await axios.get(URL + "/all");
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getRows(params: IFilterData = {}): Promise<IPage<ISlaForList>> {
    try {
      const res = await axios.get(URL, {params});
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getOneRow(id: number | string | null): Promise<ISla> {
    try {
      const res = await axios.get(URL + "/" + id + "/edit");
      return new Sla(res.data);
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function createRow(params: ISlaUpdateForm): Promise<ISla> {
    try {
      const res = await axios.post(URL, params);
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function updateRow(id: number | string | null, data: ISlaUpdateForm): Promise<ISla> {
    try {
      const res = await axios.put(URL + "/" + id, data);
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  return {getAllRows, getRows, getOneRow, createRow, updateRow};
});
