import {defineStore} from "pinia";
import axios from "@/axios";
import {AxiosError} from "axios";
import {ITicketAutofillByProductStatus, ITicketAutofillRequest} from "@/pages/ts/tickets_autofill/by_product_assignment/interfaces";
import {IFilterData, IPage} from "@/utils/interfaces";

const URL = "/api/ts/ticket_autofill_by_product_status";

export const useTicketAutofillStore = defineStore("ticket_autofill_by_product_status", () => {
  async function getList(params: IFilterData = {}): Promise<IPage<ITicketAutofillByProductStatus>> {
    try {
      const res = await axios.get(URL, {params});
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getOne(id: number | string): Promise<ITicketAutofillByProductStatus> {
    try {
      const res = await axios.get(URL + '/' + id);

      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getByUser(params: IFilterData = {}): Promise<ITicketAutofillByProductStatus[]> {
    try {
      const res = await axios.get(URL + '/by_user_roles', {params});

      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getExistsRoleIds(): Promise<Array<{[key: number]: number[]}>> {
    try {
      const res = await axios.get(URL + '/exists_role_ids');

      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function create(request: ITicketAutofillRequest): Promise<ITicketAutofillByProductStatus> {
    try {
      const res = await axios.post(URL, request);

      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function update(id: number, request: ITicketAutofillRequest): Promise<ITicketAutofillByProductStatus> {
    try {
      const res = await axios.patch(URL + '/' + id, request);

      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function remove(id: string | number): Promise<void> {
    try {
      await axios.delete(URL + '/' + id);
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  return {
    create,
    update,
    remove,
    getOne,
    getList,
    getByUser,
    getExistsRoleIds,
  };
});
