import {ref} from "vue";
import {IFilterData, IPage} from "@/utils/interfaces";
import {
  ITicketComment,
  ITicketCommentCrmCommentBind,
  ITicketCommentCrmCommentBindForm,
  ITicketCommentUpdateForm,
  ITicketCommentUpdatePartForm
} from "@/pages/ts/ticket_comments/interfaces";
import {TicketComment} from "@/pages/ts/ticket_comments/classes";
import {defineStore} from "pinia";
import axios from "@/axios";
import {AxiosError} from "axios";

const URL = "/api/ts/ticket_comments";

export const useTicketCommentStore = defineStore("ticket_comments", () => {
  const showAllComments = ref(false);

  async function getAllRows(): Promise<Array<ITicketComment>> {
    try {
      const res = await axios.get(URL + "/all");
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getRows(params: IFilterData = {}): Promise<IPage<ITicketComment>> {
    try {
      const res = await axios.get(URL, {params});
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getOneRow(id: number | string | null): Promise<ITicketComment> {
    try {
      const res = await axios.get(URL + "/" + id + "/edit");
      return new TicketComment(res.data);
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function createRow(params: Omit<ITicketCommentUpdateForm, 'text'> & {text: string | null}): Promise<ITicketComment> {
    try {
      const res = await axios.post(URL, params);
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function updateRow(id: number | string | null, data: ITicketCommentUpdatePartForm): Promise<ITicketComment> {
    try {
      const res = await axios.put(URL + "/" + id, data);
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function resendEmail(id: number | string | null, data: ITicketCommentUpdatePartForm): Promise<ITicketComment> {
    try {
      const res = await axios.put(URL + "/" + id, data);
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function bindCrmComment(data: ITicketCommentCrmCommentBindForm): Promise<ITicketCommentCrmCommentBind> {
    try {
      const res = await axios.post(URL + "/bind_crm_comment", data);

      return res.data;
    } catch (error) {
      throw error
    }
  }

  return {getAllRows, getRows, getOneRow, createRow, updateRow, resendEmail, bindCrmComment, showAllComments};
});
