import {IFilterData, ISelect} from "@/utils/interfaces";
import {defineStore} from "pinia";
import axios from "@/axios";
import {AxiosError} from "axios";
import {ITicketCustomer, ITicketCustomerAvailableType, ITicketCustomerType} from "@/pages/ts/customers/interfaces";

const URL = "/api/ts/ticket_customers";

export const useTicketCustomerStore = defineStore("ticket_customers", () => {
  async function getCustomerTypes(params: IFilterData = {}): Promise<Array<ITicketCustomerType<ITicketCustomerAvailableType>>> {
    try {
      const res = await axios.get(URL + '/types', {params});
      return res.data;
    } catch (error: any) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getAllRows(params: IFilterData = {}): Promise<Array<ITicketCustomer>> {
    try {
      const res = await axios.get(URL, {params});
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getSelectList(productType: string | number): Promise<ISelect[]> {
    try {
      const res = await axios.get(URL + '/select_list/' + productType);
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  return {getCustomerTypes, getAllRows, getSelectList};
});
