import {defineStore} from "pinia";
import axios from "@/axios";
import {ITransactionShow} from "@/stores/transaction/interfaces";
import {ITicketInvoice} from "@/pages/ts/tickets/interfaces";
import {IFilterData, IPage} from "@/utils/interfaces";

export const TICKET_INVOICES_URL = '/api/ts/ticket-invoices/'

export const useTicketInvoiceStore = defineStore('ticket-invoice', () => {
  async function getAll(params: IFilterData = {}) {
    const response = await axios.get(TICKET_INVOICES_URL, {params})

    return response.data as IPage<ITicketInvoice>
  }

  async function getTotal(params: IFilterData = {}) {
    const response = await axios.get(TICKET_INVOICES_URL + 'total', {params})

    return response.data as {amount: string, fiat_amount: string | null}
  }

  async function store(payload: any) {
    try {
      return await axios.post(TICKET_INVOICES_URL, {...payload, transaction: {...payload.transaction, amount: payload.transaction.usdt_amount} })
    }
    catch (e) {
      throw e
    }
  }

  async function bindCompensation(compensationData: any) {
    await axios.post(TICKET_INVOICES_URL + 'bind-compensation', compensationData)
  }

  async function remove(id: number) {
    try {
      await axios.delete(TICKET_INVOICES_URL + id)
    } catch (e) {
      throw e
    }
  }

  async function importInvoice(payload: {hash: string, field: 'id' | 'payment_id'}) {
    try {
      const res = await axios.post(TICKET_INVOICES_URL + 'import', payload)

      return res.data as {data: ITransactionShow[], notFound: number[] | string[], invalid: number[] | string[]}
    }
    catch (e) {
      throw e
    }
  }

  async function getUniqueCount(params: IFilterData = {}) {
    try {
      const res = await axios.get(TICKET_INVOICES_URL + 'ticket-invoice-count', {params})

      return res.data as number
    }
    catch (e) {
      throw e
    }
  }

  return {
    store,
    remove,

    getAll,
    getTotal,
    getUniqueCount,

    importInvoice,
    bindCompensation,
  }
})
