import {IFilterData, IPage} from "@/utils/interfaces";
import {ITicketTemplate, ITicketTemplateForList, ITicketTemplateUpdateForm} from "@/pages/ts/ticket_templates/interfaces";
import {TicketTemplate} from "@/pages/ts/ticket_templates/classes";
import {defineStore} from "pinia";
import axios from "@/axios";
import {AxiosError} from "axios";

const URL = "/api/ts/ticket_templates";

export const useTicketTemplateStore = defineStore("ticket_templates", () => {
  async function getAllRows(): Promise<Array<ITicketTemplate>> {
    try {
      const res = await axios.get(URL + "/all");
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getRows(params: IFilterData = {}): Promise<IPage<ITicketTemplateForList>> {
    try {
      const res = await axios.get(URL, {params});
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getOneRow(id: number | string | null): Promise<ITicketTemplate> {
    try {
      const res = await axios.get(URL + "/" + id + "/edit");
      return new TicketTemplate(res.data);
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function createRow(params: ITicketTemplateUpdateForm): Promise<ITicketTemplate> {
    try {
      const res = await axios.post(URL, params);
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function updateRow(id: number | string | null, data: ITicketTemplateUpdateForm): Promise<ITicketTemplate> {
    try {
      const res = await axios.put(URL + "/" + id, data);
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  return {getAllRows, getRows, getOneRow, createRow, updateRow};
});
