import {IFilterData, IPage, ISelect} from "@/utils/interfaces";
import {ITicketType, ITicketTypeForList, ITicketTypeUpdateForm} from "@/pages/ts/ticket_types/interfaces";
import {TicketType} from "@/pages/ts/ticket_types/classes";
import {defineStore} from "pinia";
import axios from "@/axios";
import {AxiosError} from "axios";

const URL = "/api/ts/ticket_types";

export const useTicketTypeStore = defineStore("ticket_types", () => {
  async function getAllRows(): Promise<Array<ITicketType>> {
    try {
      const res = await axios.get(URL + "/all");
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getRows(params: IFilterData = {}): Promise<IPage<ITicketTypeForList>> {
    try {
      const res = await axios.get(URL, {params});
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getOneRow(id: number | string | null): Promise<ITicketType> {
    try {
      const res = await axios.get(URL + "/" + id + "/edit");
      return new TicketType(res.data);
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function createRow(params: ITicketTypeUpdateForm): Promise<ITicketType> {
    try {
      const res = await axios.post(URL, params);
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function updateRow(id: number | string | null, data: ITicketTypeUpdateForm): Promise<ITicketType> {
    try {
      const res = await axios.put(URL + "/" + id, data);
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getSelectList(): Promise<ISelect[]> {
    try {
      const res = await axios.get(URL + "/select_list");
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  return {getAllRows, getRows, getOneRow, createRow, updateRow, getSelectList};
});
