import {IFilterData, IPage} from "@/utils/interfaces";
import {ITicketWatcher, ITicketWatcherUpdateForm} from "@/pages/ts/ticket_watchers/interfaces";
import {TicketWatcher} from "@/pages/ts/ticket_watchers/classes";
import {defineStore} from "pinia";
import axios from "@/axios";
import {AxiosError} from "axios";

const URL = "/api/ts/ticket_watchers";

export const useTicketWatcherStore = defineStore("ticket_watchers", () => {
  async function getRows(params: IFilterData = {}): Promise<IPage<ITicketWatcher>> {
    try {
      const res = await axios.get(URL, {params});
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getOneRow(id: number | string | null): Promise<ITicketWatcher> {
    try {
      const res = await axios.get(URL + "/" + id + "/edit");
      return new TicketWatcher(res.data);
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function createRow(params: ITicketWatcherUpdateForm): Promise<Array<ITicketWatcher>> {
    try {
      const res = await axios.post(URL, params);
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function updateRow(id: number | string | null, data: ITicketWatcherUpdateForm): Promise<ITicketWatcher> {
    try {
      const res = await axios.put(URL + "/" + id, data);
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function removeRow(id: number): Promise<ITicketWatcher> {
    try {
      const res = await axios.delete(URL + "/" + id);
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  return {getRows, getOneRow, createRow, updateRow, removeRow};
});
