import {IFilterData, IPage, ISelect} from "@/utils/interfaces";
import {ITopic, ITopicForList, ITopicUpdateForm} from "@/pages/ts/topics/interfaces";
import {Topic} from "@/pages/ts/topics/classes";
import {defineStore} from "pinia";
import axios from "@/axios";
import {AxiosError} from "axios";

const URL = "/api/ts/topics";

export const useTopicStore = defineStore("topics", () => {
  async function getAllRows(): Promise<Array<ITopic>> {
    try {
      const res = await axios.get(URL + "/all");
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getRows(params: IFilterData = {}): Promise<IPage<ITopicForList>> {
    try {
      const res = await axios.get(URL, {params});
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getRowsShort(params: IFilterData = {}): Promise<Array<ITopicForList>> {
    try {
      const res = await axios.get(URL, {params});
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getOneRow(id: number | string | null): Promise<ITopic> {
    try {
      const res = await axios.get(URL + "/" + id + "/edit");
      return new Topic(res.data);
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function createRow(params: ITopicUpdateForm): Promise<ITopic> {
    try {
      const res = await axios.post(URL, params);
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function updateRow(id: number | string | null, data: ITopicUpdateForm): Promise<ITopic> {
    try {
      const res = await axios.put(URL + "/" + id, data);
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getSelectList(): Promise<ISelect[]> {
    try {
      const res = await axios.get(URL + "/select_list");
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  return {getAllRows, getRows, getRowsShort, getOneRow, createRow, updateRow, getSelectList};
});
