import { ref } from "vue";
import { defineStore } from "pinia";
import axios from "@/axios";
import { AxiosError } from "axios";
import {IFilterData, IPage} from "@/utils/interfaces";
import {IUser, ICreateUserForm, IUpdateUserForm, IUserStatusEnum} from "@/pages/users/interfaces";

export const useUserProfilesStore = defineStore("userProfiles", () => {
  const store = ref({
    list: [] as Array<IUser>
  });

  async function getAllUsers(params?: {
    ids?: Array<string>,
    status?: IUserStatusEnum,
    departments?: Array<string|number> | null,
    has_permission?: string | null,
  }, toStore = true): Promise<Array<IUser>> {
    try {
      const res = await axios.get("/api/users/all", { params });
      if (toStore) store.value.list = res.data;
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getUser (id: number|string): Promise<IUser> {
    try {
      const res = await axios.get("/api/users/" + id);
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getUsersPaginated (params: IFilterData = {}): Promise<IPage<IUser>>
  {
    try {
      const res = await axios.get("/api/users", { params });
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }

  }

  async function createUser (userParams: ICreateUserForm) {
    try {
      await axios.post("/api/users", userParams);
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function updateUser (id: number|string, userParams: IUpdateUserForm) {
    try {
      await axios.put("/api/users/" + id, userParams);
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function deleteUser (id: number|string) {
    try {
      await axios.delete("/api/users/" + id);
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  return {
    store,
    getAllUsers,
    getUser,
    getUsersPaginated,
    createUser,
    updateUser,
    deleteUser
  };
});
