import { defineStore } from 'pinia'
import axios from '@/axios'
import {computed, ref} from 'vue'
import {IpassswordResetForm} from "@/stores/user/interfaces";
export const usePasswordResetStore = defineStore('password-reset', () => {
  const passwordReset = ref({
    current_password: '',
    password: '',
    password_confirmation: '',
    email: '',
    token: '',
  } as IpassswordResetForm)

  const getPassword = computed(() => passwordReset.value.password)
  async function changePassword () {
    try {
      await axios.put(`api/forty/user/password`, {
        current_password: passwordReset.value.current_password,
        password: passwordReset.value.password,
        password_confirmation: passwordReset.value.password_confirmation,
      })
    } catch (error: any) {
      throw error.response
    } finally {
      resetStore()
    }
  }

  const resetStore = () => {
    passwordReset.value.current_password = ''
    passwordReset.value.password = ''
    passwordReset.value.password_confirmation = ''
    passwordReset.value.email = ''
    passwordReset.value.token = ''
  }

  async function resetPassword (token: string, email: string) {
    try {
      await axios.post(`api/forty/reset-password`, {
        email: email,
        token: token,
        password: passwordReset.value.password,
        password_confirmation: passwordReset.value.password_confirmation,
      })
    } catch (error: any) {
      throw error.response
    }
  }



  return { changePassword, passwordReset, getPassword, resetPassword, resetStore }
})
