import { defineStore } from 'pinia'
import axios from '../../axios'
import { ref, computed } from 'vue'
import { IModelLog } from "@/stores/client_log/interfaces";
import { IPage } from "@/utils/interfaces";
import { IFilterData } from "@/utils/interfaces";

export const useUserLogStore = defineStore('user-log', () => {
  const store = ref({
    userLog: {} as IPage<IModelLog>,
    userLogLoading: false as boolean,
    userLogShowMoreLoading: false as boolean,
  })

  const getUserLog = computed(() => store.value.userLog.data)

  async function userLog(params: IFilterData, showMoreLoading = false) {
    try {
      let url = `api/log/user`
      if(store.value.userLog.data && store.value.userLog.next_page_url === null) {
        return
      }
      if(store.value.userLog.next_page_url) {
        url = store.value.userLog.next_page_url
      }
      if (showMoreLoading) {
        store.value.userLogShowMoreLoading = false
      } else {
        store.value.userLogLoading = false
      }
      const resp = await axios.get(url, {params})
      if (showMoreLoading) {
        store.value.userLogShowMoreLoading = true
      } else {
        store.value.userLogLoading = true
        store.value.userLogShowMoreLoading = true
      }
      if(store.value.userLog.data) {
        resp.data.data.data.forEach(function(item: IModelLog) {
          store.value.userLog.data.push(item)
        });
        store.value.userLog.next_page_url = resp.data.data.next_page_url
        store.value.userLog.next_cursor = resp.data.data.next_cursor
      } else {
        store.value.userLog = resp.data.data
      }

    } catch (error: any) {
      console.log(error)
      throw error.response
    }
  }

  function clear() {
    store.value.userLog = {}  as IPage<IModelLog>
  }

  return {
    store,
    getUserLog,
    userLog,
    clear
  }
})
