import {IFilterData} from "@/utils/interfaces";
import {defineStore} from "pinia";
import axios from "@/axios";
import {AxiosError} from "axios";
import {IUserNote, IUserNoteUpdateForm} from "@/pages/user_notes/interfaces";
import {UserNote} from "@/pages/user_notes/classes";

const URL = "/api/user_notes";

export const useUserNoteStore = defineStore("user_notes", () => {
  async function getRows(params: IFilterData = {}): Promise<Array<IUserNote>> {
    try {
      const res = await axios.get(URL, {params});
      return res.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function getOneRow(id: number | string | null): Promise<IUserNote> {
    try {
      const res = await axios.get(URL + "/" + id + "/edit");
      return new UserNote(res.data);
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function createRow(params: IUserNoteUpdateForm): Promise<IUserNote> {
    try {
      const res = await axios.post(URL, params);
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function updateRow(id: number | string | null, data: IUserNoteUpdateForm): Promise<IUserNote> {
    try {
      const res = await axios.put(URL + "/" + id, data);
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  async function deleteRow(id: number | string) {
    try {
      const res = await axios.delete(URL + "/" + id);
      return res.data.data;
    } catch (error) {
      const err = error as AxiosError;
      throw err.response;
    }
  }

  return {getRows, getOneRow, createRow, updateRow, deleteRow};
});
