import { defineStore } from "pinia";
import axios, { AxiosError } from "axios";

import { ICollectable } from "@/components/ElementCollection/interfaces";

const URL = "/api/websites/";

export const useWebsiteStore = defineStore("websites", () => {
  async function getWebsites (websitable_type: string, websitable_id: string | number): Promise<Array<ICollectable>> {
    try {
      const res = await axios.get(URL, {
        params: {
          websitable_type,
          websitable_id,
        }
      });
      return res.data;
    } catch (err) {
      const error = err as AxiosError;
      throw error.response;
    }
  }

  async function createWebsite (websitable_type: string, websitable_id: string | number, value: string): Promise<ICollectable> {
    try {
      const res = await axios.post(URL, {
        websitable_type,
        websitable_id,
        value,
      });
      return res.data;
    } catch (err) {
      const error = err as AxiosError;
      throw error.response;
    }
  }

  async function updateWebsite (id: number | string, value: string): Promise<void> {
    try {
      await axios.put(URL + id, { value });
    } catch (err) {
      const error = err as AxiosError;
      throw error.response;
    }
  }

  async function deleteWebsite (id: number | string): Promise<void> {
    try {
      await axios.delete(URL + id);
    } catch (err) {
      const error = err as AxiosError;
      throw error.response;
    }
  }

  return {
    getWebsites,
    createWebsite,
    updateWebsite,
    deleteWebsite,
  };

});
