
const scrollIntervalIdList: Array<any> = [];
const scrollIntervalDelay = 10;
const scrollPxStep = 5;
const scrollBooster = 1.03;

const scrollFixedTopDesktop = 85;
const scrollFixedTopMobile = 70;

function scrollLeftBtnDown() {
  const scrollOverflowElList: NodeListOf<HTMLElement> = document.querySelectorAll('.custom_scroll_overflow');

  scrollOverflowElList.forEach((scrollOverflowEl: HTMLElement) => {
    let scrollPxStepCalc = scrollPxStep;

    const scrollIntervalId = setInterval(() => {
      scrollPxStepCalc *= scrollBooster;
      if (scrollOverflowEl) {
        if (scrollOverflowEl.scrollLeft <= 0) {
          clearInterval(scrollIntervalId);
        } else {
          scrollOverflowEl.scrollLeft -= scrollPxStepCalc;
        }
      }
      scrollDraw();
    }, scrollIntervalDelay);

    scrollIntervalIdList.push(scrollIntervalId)
  });
}

function scrollRightBtnDown() {
  const scrollOverflowElList: NodeListOf<HTMLElement> = document.querySelectorAll('.custom_scroll_overflow');
  const scrollContentEl: HTMLElement | null = document.querySelector('.custom_scroll_content');

  scrollOverflowElList.forEach((scrollOverflowEl: HTMLElement) => {
    let scrollPxStepCalc = scrollPxStep;

    const scrollIntervalId = setInterval(() => {
      scrollPxStepCalc *= scrollBooster;
      if (scrollOverflowEl && scrollContentEl) {
        if ((scrollOverflowEl.scrollLeft + scrollOverflowEl.offsetWidth) >= scrollContentEl.offsetWidth) {
          clearInterval(scrollIntervalId);
        } else {
          scrollOverflowEl.scrollLeft += scrollPxStepCalc;
        }
      }
      scrollDraw();
    }, scrollIntervalDelay);

    scrollIntervalIdList.push(scrollIntervalId)
  });
}

function scrollDraw() {
  const scrollOverflowEl: HTMLElement | null = document.querySelector('.custom_scroll_overflow');
  const scrollContentEl: HTMLElement | null = document.querySelector('.custom_scroll_content');
  const scrollLeftBtnElList: NodeListOf<HTMLElement> = document.querySelectorAll('.custom_scroll_left_btn');
  const scrollRightBtnElList: NodeListOf<HTMLElement> = document.querySelectorAll('.custom_scroll_right_btn');
  const scrollContainerThFixedEl: HTMLElement | null = document.querySelector('.custom_scroll_container_thead_fixed');
  const scrollFixedTop = scrollFixedTopCalc();

  // Show \ Hide left btn
  scrollLeftBtnElList.forEach((scrollLeftBtnEl: HTMLElement) => {
    if (scrollOverflowEl && scrollLeftBtnEl) {
      if (scrollOverflowEl.scrollLeft) {
        scrollLeftBtnEl.style.display = 'block';
      } else {
        scrollLeftBtnEl.style.display = 'none';
      }
    }
  });

  // Show \ Hide right btn
  scrollRightBtnElList.forEach((scrollRightBtnEl: HTMLElement) => {
    if (scrollOverflowEl && scrollContentEl && scrollRightBtnEl) {
      if ((scrollOverflowEl.scrollLeft + scrollOverflowEl.offsetWidth) < scrollContentEl.offsetWidth) {
        scrollRightBtnEl.style.display = 'block';
      } else {
        scrollRightBtnEl.style.display = 'none';
      }
    }
  });

  // Update position top for fixed block
  if (scrollContainerThFixedEl && scrollContainerThFixedEl.offsetTop != scrollFixedTop) {
    scrollContainerThFixedEl.style.top = scrollFixedTop + 'px';
  }

  scrollFixedWidthSync()
}

function scrollFixedWidthSync() {
  const scrollContainerElList:  NodeListOf<HTMLElement> = document.querySelectorAll('.custom_scroll_container');
  const scrollContainerFixedTrElList:  NodeListOf<HTMLElement> = document.querySelectorAll('.custom_scroll_container_thead_fixed thead tr');

  if (scrollContainerElList[1] !== undefined) {
    // Set new width for fixed block container
    scrollContainerElList[1].style.width = scrollContainerElList[0].offsetWidth + 'px'

    // Set new width for fixed block columns
    scrollContainerFixedTrElList.forEach((scrollContainerFixedTrEl: HTMLElement, trKey) => {
      const scrollContainerFixedThElList:  NodeListOf<HTMLElement> = scrollContainerFixedTrEl.querySelectorAll('th');
      const scrollContainerMainThElList:  NodeListOf<HTMLElement> = document.querySelectorAll('.custom_scroll_container_thead tr:nth-child(' + (trKey + 1) + ') th');

      if (scrollContainerFixedThElList.length == scrollContainerMainThElList.length) {
        scrollContainerFixedThElList.forEach((scrollContainerFixedThEl: HTMLElement, thKey) => {
          scrollContainerFixedThEl.style.minWidth = scrollContainerMainThElList[thKey].offsetWidth + 'px'
        });
      }
    });
  }
}

function scrollFixedTopCalc() {
  return window.innerWidth < 768 ? scrollFixedTopMobile : scrollFixedTopDesktop;
}

function scrollСlear() {
  scrollIntervalIdList.forEach((el: any) => {
    clearInterval(el);
  });
}

function scrollResizeWindowDraw() {
  window.addEventListener("resize", () => {
    scrollDraw();
  })
}

function scrollScrollWindowDraw() {
  window.addEventListener("scroll", () => {
    const scrollContainerThEl: HTMLElement | null = document.querySelector('.custom_scroll_container_thead');
    const scrollContainerThFixedEl: HTMLElement | null = document.querySelector('.custom_scroll_container_thead_fixed');
    const scrollContainerMainEl: HTMLElement | null | undefined = scrollContainerThEl?.closest('.custom_scroll_container');
    const scrollContainerMainLeftBtnEl: NodeListOf<HTMLElement> | undefined = scrollContainerMainEl?.querySelectorAll('.custom_scroll_left_btn');
    const scrollContainerMainRightBtnEl: NodeListOf<HTMLElement> | undefined = scrollContainerMainEl?.querySelectorAll('.custom_scroll_right_btn');
    const scrollOverflowElList: NodeListOf<HTMLElement> = document.querySelectorAll('.custom_scroll_overflow');
    const scrollFixedTop = scrollFixedTopCalc();

    if (scrollOverflowElList.length == 2) {
      // Sync 'scrollLeft' for fixed block
      scrollOverflowElList[1].scrollLeft = scrollOverflowElList[0].scrollLeft;
    }

    if (scrollContainerThEl && scrollContainerThFixedEl) {
      if (scrollContainerThFixedEl.offsetTop != scrollFixedTop) {
        // Update fixed top (desktop or mobile)
        scrollContainerThFixedEl.style.top = scrollFixedTop + 'px';
      }

      if (scrollContainerThEl.getBoundingClientRect().top < scrollFixedTopCalc()) {
        // Show fixed block
        scrollContainerThFixedEl.style.display = 'block';

        if (scrollContainerMainLeftBtnEl && scrollContainerMainRightBtnEl) {
          // Hide main scroll btns
          scrollContainerMainLeftBtnEl[0].style.visibility = 'hidden';
          scrollContainerMainRightBtnEl[0].style.visibility = 'hidden';
        }
      } else {
        // Hide fixed block
        scrollContainerThFixedEl.style.display = 'none';

        if (scrollContainerMainLeftBtnEl && scrollContainerMainRightBtnEl) {
          // Show main scroll btns
          scrollContainerMainLeftBtnEl[0].style.visibility = 'visible';
          scrollContainerMainRightBtnEl[0].style.visibility = 'visible';
        }
      }
    }

    scrollFixedWidthSync()
  })
}

export {
  scrollLeftBtnDown,
  scrollRightBtnDown,
  scrollDraw,
  scrollСlear,
  scrollResizeWindowDraw,
  scrollScrollWindowDraw,
};
