import {Plugin} from 'vite'

type Options = {
  include: string[]
  env: {
    [key: string]: boolean
  }
}

export default function conditionalBuild(options: Options): Plugin {
  return {
    name: 'vite-plugin-conditional-build',
    enforce: 'pre',
    transform(code: string, id: string) {
      if (!options.include.some((path) => id.endsWith(path))) {
        return null
      }

      const {env} = options
      let transformedCode = code

      // Regular expression for finding #if, #else, #endif blocks
      const conditionalBlockRegex = /\/\/ #if\[(\w+)]\s*([\s\S]*?)\s*\/\/ #else\s*([\s\S]*?)\s*\/\/ #endif/g

      transformedCode = transformedCode.replace(
        conditionalBlockRegex,
        (match, condition, ifBlock, elseBlock) => {
          if (env[condition]) {
            return ifBlock.trim()
          } else {
            return elseBlock.trim()
          }
        })

      return {
        code: transformedCode,
        map: null,
      }
    },
  }
}
