// @ts-nocheck
import {Component} from "vue"
import {RouteRecord} from "vue-router"
import {StoreDefinition} from "pinia"
import {forEach} from "lodash"

/** BEGIN: Conditional erp packages imports */
// #if[DOCS_ENABLED]
//import Docs from "@erp-npm-packages/docs"
// #else
const Docs = null
// #endif

// #if[EDUCATION_ENABLED]
//import Education from "@erp-npm-packages/education"
// #else
const Education = null
// #endif

// #if[PAYPORT_ENABLED]
import Payport from "../../../erp-npm-packages/payport"
// #else
const Payport = null
// #endif

// #if[PROJECT_ENABLED]
//import Project from "../../../erp-npm-packages/project"
// #else
const Project = null
// #endif

// #if[TAGS_ENABLED]
//import Tags from "@erp-npm-packages/tags"
// #else
const Tags = null
// #endif
/** END: Conditional erp packages imports */

type ErpPackage = {
  routes: RouteRecord[],
  components?: {
    [key: string]: Component
  },
  stores?: {
    [key: string]: StoreDefinition
  }
}

/** BEGIN: erp packages */
const erpPackages: {
  [key: string]: ErpPackage | null
} = {
  //docs: Docs,
  //education: Education,
  payport: Payport,
  //project: Project,
  //tags: Tags,
}
/** END: erp packages */

export const getErpPackageRoutes = (): RouteRecord[] => {
  const routes: RouteRecord[] = []

  forEach(erpPackages, (erpPackage) => {
    if (erpPackage !== null) {
      routes.push(...erpPackage.routes)
    }
  })

  return routes
}

export const getErpPackageComponent = (packageName: string, componentName: string): Component | null => {
  const erpPackage = erpPackages[packageName]

  if (erpPackage === null || erpPackage?.components === undefined) {
    return null
  }

  return erpPackage.components[componentName] ?? null
}

export const getErpPackageStore = (packageName: string, storeName: string): StoreDefinition | null => {
  const erpPackage = erpPackages[packageName]

  if (erpPackage === null || erpPackage.stores === undefined) {
    return null
  }

  return erpPackage.stores[storeName] ?? null
}
