import axios from "axios";

declare global{
  interface Navigator{
    msSaveBlob:(blob: Blob,fileName:string) => boolean
  }
}

interface IDownloadAttrs {
  data: string | ArrayBuffer | ArrayBufferView | Blob,
  filename: string,
  mime?: string,
  bom?: string
}

interface  ILoadingAttrs {
  url: string,
  filename: string,
}

export const download = async (
  url: ILoadingAttrs['url'],
  filename: ILoadingAttrs['filename'],
  params?: object
) => {
  const response = await axios.get(url, {
    responseType: 'blob',
    params,
  });

  save(response.data, filename)
}

export const save = (
  data: IDownloadAttrs['data'],
  filename: IDownloadAttrs['filename'],
  mime?: IDownloadAttrs['mime'],
  bom?: IDownloadAttrs['bom'],
) => {
  const blobData = (typeof bom !== 'undefined') ? [bom, data] : [data]
  const blob = new Blob(blobData, {type: mime || 'application/octet-stream'});

  if (typeof window.navigator.msSaveBlob !== 'undefined') {
    window.navigator.msSaveBlob(blob, filename);
  } else {
    const blobURL = (window.URL && window.URL.createObjectURL) ? window.URL.createObjectURL(blob) : window.webkitURL.createObjectURL(blob);
    const tempLink = document.createElement('a');

    tempLink.style.display = 'none';
    tempLink.href = blobURL;
    tempLink.setAttribute('download', filename);

    if (typeof tempLink.download === 'undefined') {
      tempLink.setAttribute('target', '_blank');
    }

    document.body.appendChild(tempLink);
    tempLink.click();

    // Fixes "webkit blob resource error 1"
    setTimeout(function() {
      document.body.removeChild(tempLink);
      window.URL.revokeObjectURL(blobURL);
    }, 200)
  }
}
