import { ContactPerson as IContact } from "@/stores/contact_person/interfaces";
import { IFile } from "@/stores/file/interfaces";
import { LocationQueryValue } from "vue-router";

interface ILink {
  url: string | null,
  label: string,
  active: boolean
}

interface IPage<T> {
  current_page: number,
  data: Array<T>,
  first_page_url: string,
  from: number,
  last_page: number,
  last_page_url: string,
  links: Array<ILink>,
  next_page_url: string | undefined,
  path: string,
  perPage: number,
  per_page: number,
  prev_page_url: string | undefined,
  to: number,
  total: number,
  next_cursor?: string,
  totals?: any,
  data_ranges?: any,
}

interface IBackendErrors {
  [key: string]: {
    $error: boolean,
    $errors: Array<{
      $message: string,
    }>,
  }
}

interface IComment {
  id: number,
  comment: string | null,
  output_with_smart_links: string,
  user: import("@/pages/users/interfaces").IUserShort,
  created_at: string,
  files: Array<IFile>,
  is_pinned: boolean,
  pinned_at: string | null,
  file_relations_with_documents?: {
    [fileId: number]: {
      id: number,
      title: string,
      status: string,
      statusName: string,
      modelId: number,
      modelType: string,
      relationModelId: number,
      relationModelType: string,
      modelPermissions: string[],
      hasPermissions: boolean,
    }[]
  }
}

interface INewComment {
  comment: string,
  commentable_id: number,
  commentable_type: string
}

interface ICommentWithTags {
  newComment: string,
  tags: Array<string>,
}

interface ICommentable {
  id: number,

  getComments(params?: {
    page?: number | string,
    perPage?: number | string,
    orderBy?: string,
    orderDir?: string,
    is_pinned?: 0 | 1,
  }): Promise<IPage<IComment>>,
  addNewComment(comment: string | null): Promise<IComment>,
}

interface IContactable {
  contacts: Array<IContact>
}

interface IFilterData {
  [key: string]: LocationQueryValue | LocationQueryValue[] | string | number
}

interface ISelect {
  text: string,
  value: string | number
}

interface ISelect {
  text: string,
  value: string | number,
  disabled?: boolean,
}

enum CommentableType {
  ServiceProvider = "App\\Models\\ServiceProvider",
  Lead = "App\\Models\\Lead",
  Client = "App\\Models\\Client",
  Trader = "App\\Models\\Trader",
}

enum RequestCommentableType {
  CLIENT = 'Client',
  LEAD = 'Lead',
  TRADER = 'Trader',
  SERVICE_PROVIDER = 'ServiceProvider',
}

export type {
  ILink,
  IPage,
  IFilterData,
  IBackendErrors,
  IComment,
  IContactable,
  INewComment,
  ICommentable,
  ISelect,
  ICommentWithTags,
};

export { CommentableType, RequestCommentableType };
