import { Ref } from "vue"
import dayjs from "dayjs";
import customParseFormat from "dayjs/plugin/customParseFormat";
import isSameOrBefore from "dayjs/plugin/isSameOrBefore";
import isSameOrAfter from "dayjs/plugin/isSameOrAfter";

dayjs.extend(customParseFormat);
dayjs.extend(isSameOrBefore);
dayjs.extend(isSameOrAfter);

export const minDate = (minDate: Ref<string>) => {
  return {
    $validator: (value: string) => {
      const selectedDay: dayjs.Dayjs = dayjs(value, "DD.MM.YYYY");
      if (!selectedDay.isValid()) {
        return false;
      }
      return selectedDay.startOf("day").isSameOrAfter(dayjs(minDate.value as string, "DD.MM.YYYY").startOf("day"));
    },
    $message: "The date is invalid or too small.",
  };
};

export const maxDate = (maxDate: Ref<string>) => {
  return {
    $validator: (value: string) => {
      const selectedDay: dayjs.Dayjs = dayjs(value, "DD.MM.YYYY");
      if (!selectedDay.isValid()) {
        return false;
      }
      return selectedDay.startOf("day").isSameOrBefore(dayjs(maxDate.value, "DD.MM.YYYY").startOf("day"));
    },
    $message: "The date is invalid or too big.",
  };
};

export const hexColor = (value: string) => {
  return !!value.match(/^\#\w{6}$/g);
};

export const isNotTrue = (other: Ref<boolean>) => {
  return {
    $validator: (value: boolean) => {
      return value || other.value;
    }
  }
};

/* eslint-disable @typescript-eslint/no-unused-vars */
export const alwaysTrue = (_1: string) => {
  return true;
}
