import { defineConfig, loadEnv } from 'vite'
import vue from '@vitejs/plugin-vue'
import { resolve } from "path";
import { hash } from './src/utils/functions'
import conditionalBuild from "./src/utils/erp-integration/conditional-build-vite-plugin";

// https://vitejs.dev/config/
export default defineConfig(({mode}) => {
  const env = loadEnv(mode, process.cwd());

  return {
    build: {
      commonjsOptions: {
        include: ["tailwind.config.js", "node_modules/**"],
      },
      rollupOptions: {
        output: {
          entryFileNames: `[name]` + hash + `.js`,
          chunkFileNames: `[name]` + hash + `.js`,
          assetFileNames: `[name]` + hash + `.[ext]`
        },
      },
    },
    optimizeDeps: {
      include: ["tailwind-config"],
    },
    plugins: [
      vue(),
      conditionalBuild({
        include: ['src/utils/erp-integration/resolver.ts'],
        env: {
          DOCS_ENABLED: env.VITE_DOCS_ENABLED === '1',
          EDUCATION_ENABLED: env.VITE_EDUCATION_ENABLED === '1',
          PAYPORT_ENABLED: env.VITE_PAYPORT_ENABLED === '1',
          PROJECT_ENABLED: env.VITE_PROJECT_ENABLED === '1',
          TAGS_ENABLED: env.VITE_TAGS_ENABLED === '1',
        }
      })
    ],
    resolve: {
      alias: {
        "tailwind-config": resolve(resolve(__dirname), "./tailwind.config.js"),
        "@": resolve(resolve(__dirname), "src"),
        "@node_modules": resolve(resolve(__dirname), "node_modules"),
        "@erp": resolve(resolve(__dirname), "erp-npm-packages")
      },
    },
  }
})
